@@ -1,23 +1,7 @@
-// $Id: CommandLine.cpp,v 1.130 2008-06-05 11:52:49 samtech Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <string.h>
 #include <stdlib.h>
@@ -185,9 +169,11 @@ void Get_Options(int argc, char *argv[])
   // the parser, and so we can load files for -convert
   GModel *dummy = new GModel();
 
+#if !defined(HAVE_NO_PARSER)
   // Parse session and option files
   ParseFile(CTX.session_filename_fullpath, 1);
   ParseFile(CTX.options_filename_fullpath, 1);
+#endif
 
   // Get command line options
   int i = 1;
