@@ -1,25 +1,11 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _CONTEXT_H_
 #define _CONTEXT_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include <vector>
 #include <string>
 
@@ -116,7 +102,8 @@ class Context_T {
   double shine, shine_exponent; // material specular reflection parameters
   int render_mode; // GMSH_RENDER, GMSH_SELECT, GMSH_FEEDBACK 
   int clip[6]; // status of clip planes (bit arrays)
-  double clip_plane[6][4]; // clip planes 
+  double clip_plane[6][4]; // clipping planes 
+  int clip_whole_elements, clip_only_draw_intersecting_volume, clip_only_volume; // clip options
   int polygon_offset, polygon_offset_always; // polygon offset control
   double polygon_offset_factor, polygon_offset_units; // params for glPolygonOffset
   double pixel_equiv_x, pixel_equiv_y; // approx equiv model length of a pixel 
@@ -178,12 +165,6 @@ class Context_T {
     int min_circ_points, min_curv_points;
     double normals, tangents, explode;
     int color_carousel;
-    int use_cut_plane, cut_plane_draw_intersect, cut_plane_only_volume;
-    double cut_planea, cut_planeb, cut_planec, cut_planed;
-    double evalCutPlane (double x, double y, double z)
-    {
-      return cut_planea * x + cut_planeb * y + cut_planec * z + cut_planed; 
-    }
     int save_all, save_groups_of_nodes, stl_binary, msh_binary, bdf_field_format;
     int smooth_normals, reverse_all_normals;
     double angle_smooth_normals;
