@@ -1,24 +1,11 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _DEFAULT_OPTIONS_H_
 #define _DEFAULT_OPTIONS_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 // USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include "GmshDefines.h"
 #include "Options.h"
 
@@ -534,10 +521,17 @@ StringXNumber GeneralOptions_Number[] = {
     "Fourth coefficient in equation for clipping plane 5" },
   { F,   "ClipFactor" , opt_general_clip_factor , 5.0 , 
     "Near and far clipping plane distance factor (decrease value for better z-buffer resolution)" },
+  { F|O, "ClipOnlyDrawIntersectingVolume" , opt_general_clip_only_draw_intersecting_volume , 0. , 
+    "Only draw layer of elements that intersect the clipping plane" },
+  { F|O, "ClipOnlyVolume" , opt_general_clip_only_volume , 0. , 
+    "Only clip volume elements" },
   { F|S, "ClipPositionX" , opt_general_clip_position0 , 650. , 
     "Horizontal position (in pixels) of the upper left corner of the clipping planes window" }, 
   { F|S, "ClipPositionY" , opt_general_clip_position1 , 150. , 
     "Vertical position (in pixels) of the upper left corner of the clipping planes window" }, 
+  { F|O, "ClipWholeElements" , opt_general_clip_whole_elements , 0. , 
+    "Clip whole elements" },
+
   { F|O, "ColorScheme", opt_general_color_scheme , 1. ,
     "Default color scheme (0=dark, 1=light or 2=grayscale)" },
   { F|O, "ConfirmOverwrite" , opt_general_confirm_overwrite, 1. , 
@@ -767,12 +761,7 @@ StringXNumber GeneralOptions_Number[] = {
   { F|S, "SystemMenuBar" , opt_general_system_menu_bar , 1. , 
     "Use the system menu bar on Mac OS X?" }, 
 
-  { F|O, "Terminal" , opt_general_terminal , 
-#if defined(HAVE_FLTK)
-    0. ,
-#else                 
-    1. ,
-#endif
+  { F|O, "Terminal" , opt_general_terminal , 0. ,
     "Should information be printed on the terminal (if available)?" },
   { F|O, "Tooltips" , opt_general_tooltips , 1. ,
     "Show tooltips in the user interface" },
@@ -861,7 +850,7 @@ StringXNumber GeometryOptions_Number[] = {
   { F|O, "PointSize" , opt_geometry_point_size , 4. , 
     "Display size of points (in pixels)" },
   { F|O, "PointType" , opt_geometry_point_type , 0. , 
-    "Display points as solid color dots (0), 3D spheres (1) or scaled spheres (2)" },
+    "Display points as solid color dots (0) or 3D spheres (1)" },
 
   { F|O, "ScalingFactor" , opt_geometry_scaling_factor , 1.0 , 
     "Global geometry scaling factor" },
@@ -927,20 +916,6 @@ StringXNumber MeshOptions_Number[] = {
     "Mesh coloring (0=by element type, 1=by elementary entity, 2=by physical entity, 3=by partition)" },
   { F,   "CpuTime" , opt_mesh_cpu_time , 0. , 
     "CPU time (in seconds) for the generation of the current mesh (read-only)" },
-  { F,   "CutPlane" , opt_mesh_use_cut_plane , 0 ,
-    "Enable mesh cut plane" },
-  { F,   "CutPlaneDrawIntersect" , opt_mesh_cut_plane_draw_intersect , 0 ,
-    "Draw only the volume elements that intersect with the cut plane" },
-  { F,   "CutPlaneOnlyVolume" , opt_mesh_cut_plane_only_volume , 0 ,
-    "Cut only the volume elements" },
-  { F,   "CutPlaneA" , opt_mesh_cut_planea , 1.0 , 
-    "First cut plane equation coefficient (`A' in `AX+BY+CZ+D=0')" },
-  { F,   "CutPlaneB" , opt_mesh_cut_planeb , 0.0 , 
-    "Second cut plane equation coefficient (`B' in `AX+BY+CZ+D=0')" },
-  { F,   "CutPlaneC" , opt_mesh_cut_planec , 0.0 , 
-    "Third cut plane equation coefficient (`C' in `AX+BY+CZ+D=0')" },
-  { F,   "CutPlaneD" , opt_mesh_cut_planed , 0.0 , 
-    "Fourth cut plane equation coefficient (`D' in `AX+BY+CZ+D=0')" },
 
   { F|O, "DrawSkinOnly" , opt_mesh_draw_skin_only , 0. ,
     "Draw only the skin of 3D meshes?" },
@@ -1333,7 +1308,7 @@ StringXNumber ViewOptions_Number[] = {
   { F|O, "PointSize" , opt_view_point_size , 3. , 
     "Display size of points (in pixels)" },
   { F|O, "PointType" , opt_view_point_type , 0. , 
-    "Display points as solid color dots (0) or 3D spheres (1)" },
+    "Display points as solid color dots (0), 3D spheres (1), scaled dots (2) or scaled spheres (3)" },
   { F|O, "PositionX" , opt_view_position0 , 100. , 
     "Horizontal position (in pixels) of the upper left corner of the scale or 2D plot" }, 
   { F|O, "PositionY" , opt_view_position1 , 50. , 
@@ -1396,7 +1371,7 @@ StringXNumber ViewOptions_Number[] = {
     "Use generalized raise?" },
 
   { F|O, "VectorType" , opt_view_vector_type , 4 ,
-    "Vector display type (1=segment, 2=arrow, 3=pyramid, 4=3D arrow, 5=displacement)" },
+    "Vector display type (1=segment, 2=arrow, 3=pyramid, 4=3D arrow, 5=displacement, 6=comet)" },
   { F,   "Visible" , opt_view_visible , 1. ,
     "Is the view visible?" },
 
