@@ -1,29 +1,12 @@
-// $Id: Gmsh.cpp,v 1.6 2008-05-04 08:31:11 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <string>
 #include "GmshDefines.h"
 #include "GModel.h"
 #include "Message.h"
-#include "Parser.h"
 #include "OpenFile.h"
 #include "CreateFile.h"
 #include "Options.h"
@@ -34,20 +17,26 @@
 #include "Field.h"
 #include "Context.h"
 
+#if !defined(HAVE_NO_PARSER)
+#include "Parser.h"
+#endif
+
 #if !defined(HAVE_NO_POST)
 #include "PluginManager.h"
 #endif
 
-Context_T CTX;
+extern Context_T CTX;
 
 int GmshInitialize(int argc, char **argv)
 {
   // Initialize messages (parallel stuff, etc.)
   Msg::Init(argc, argv);
 
+#if !defined(HAVE_NO_POST)
   // Initialize the symbol tree that will hold variable names in the
   // parser
   InitSymbols();
+#endif
   
   // Load default options
   Init_Options(0);
@@ -68,6 +57,26 @@ int GmshInitialize(int argc, char **argv)
   return 1;
 }
 
+int GmshSetMessageHandler(GmshMessage *callback)
+{
+  Msg::SetCallback(callback);
+  return 1;
+}
+
+int GmshSetOption(std::string category, std::string name, std::string value, int index)
+{
+  if(StringOption(GMSH_SET, category.c_str(), index, name.c_str(), value.c_str()))
+    return 1;
+  return 0;
+}
+
+int GmshSetOption(std::string category, std::string name, double value, int index)
+{
+  if(NumberOption(GMSH_SET, category.c_str(), index, name.c_str(), value))
+    return 1;
+  return 0;
+}
+
 int GmshFinalize()
 {
   return 1;
