@@ -1,24 +1,11 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _GMSH_DEFINES_H_
 #define _GMSH_DEFINES_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 // USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 // IO file formats
 #define FORMAT_MSH           1
 #define FORMAT_UNV           2
@@ -82,6 +69,8 @@
 #define MSH_TET_20 29
 #define MSH_TET_35 30
 #define MSH_TET_56 31
+#define MSH_TET_34 32
+#define MSH_TET_52 33
 
 // Geometric entities
 #define ENT_NONE     0
@@ -104,7 +93,9 @@
 #define ALGO_3D_NETGEN             4
 #define ALGO_3D_TETGEN             5 // unused
 
-#define TRANSFINI 1
-#define LIBRE     2
+// Meshing methods
+#define MESH_NONE         0
+#define MESH_TRANSFINITE  1
+#define MESH_UNSTRUCTURED 2
 
 #endif
