@@ -1,30 +1,18 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _MESSAGE_H_
 #define _MESSAGE_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include <map>
 #include <vector>
 #include <string>
 #include <stdarg.h>
 
+class GmshMessage;
+
 // a class to manage messages
 class Message {
  private:
@@ -38,6 +26,8 @@ class Message {
   static std::map<std::string, double> _timers;
   // counters
   static int _warningCount, _errorCount;
+  // callback
+  static GmshMessage *_callback;
  public:
   Message() {}
   static void Init(int argc, char **argv);
@@ -46,6 +36,7 @@ class Message {
   static int GetCommSize(){ return _commSize; }
   static void SetCommRank(int val){ _commRank = val; }
   static void SetCommSize(int val){ _commSize = val; }
+  static void SetCallback(GmshMessage *callback){ _callback = callback; }
   static void Barrier();
   static int GetNumThreads();
   static int GetMaxThreads();
