@@ -1,25 +1,11 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _OPTIONS_H_
 #define _OPTIONS_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include "ColorTable.h"
 
 #define GMSH_SET       (1<<0)
@@ -366,6 +352,9 @@ double opt_general_clip5a(OPT_ARGS_NUM);
 double opt_general_clip5b(OPT_ARGS_NUM);
 double opt_general_clip5c(OPT_ARGS_NUM);
 double opt_general_clip5d(OPT_ARGS_NUM);
+double opt_general_clip_whole_elements(OPT_ARGS_NUM);
+double opt_general_clip_only_draw_intersecting_volume(OPT_ARGS_NUM);
+double opt_general_clip_only_volume(OPT_ARGS_NUM);
 double opt_general_light0(OPT_ARGS_NUM);
 double opt_general_light00(OPT_ARGS_NUM);
 double opt_general_light01(OPT_ARGS_NUM);
@@ -497,13 +486,6 @@ double opt_mesh_second_order_linear(OPT_ARGS_NUM);
 double opt_mesh_second_order_incomplete(OPT_ARGS_NUM);
 double opt_mesh_dual(OPT_ARGS_NUM);
 double opt_mesh_draw_skin_only(OPT_ARGS_NUM);
-double opt_mesh_use_cut_plane(OPT_ARGS_NUM);
-double opt_mesh_cut_plane_draw_intersect(OPT_ARGS_NUM);
-double opt_mesh_cut_plane_only_volume(OPT_ARGS_NUM);
-double opt_mesh_cut_planea(OPT_ARGS_NUM);
-double opt_mesh_cut_planeb(OPT_ARGS_NUM);
-double opt_mesh_cut_planec(OPT_ARGS_NUM);
-double opt_mesh_cut_planed(OPT_ARGS_NUM);
 double opt_mesh_save_all(OPT_ARGS_NUM);
 double opt_mesh_save_groups_of_nodes(OPT_ARGS_NUM);
 double opt_mesh_color_carousel(OPT_ARGS_NUM);
@@ -753,30 +735,30 @@ typedef struct {
 
 typedef struct {
   int level;
-  const char *str ;
-  const char * (*function)(int num, int action, const char *val) ;
-  const char *def ;
-  const char *help ;
-} StringXString ;
+  const char *str;
+  const char * (*function)(int num, int action, const char *val);
+  const char *def;
+  const char *help;
+} StringXString;
 
 typedef struct {
   int level;
   const char *str;
-  double (*function)(int num, int action, double val) ;
+  double (*function)(int num, int action, double val);
   double def ;
-  const char *help ;
-} StringXNumber ;
+  const char *help;
+} StringXNumber;
 
 typedef struct {
   int level;
-  const char *str ; 
-  unsigned int (*function)(int num, int action, unsigned int val) ;
+  const char *str;
+  unsigned int (*function)(int num, int action, unsigned int val);
   // the defaults are stored in individual bytes so that we can initialize
   // them statically independently of the machine endianness. They will be
   // packed into unsigned ints at runtime
-  unsigned char def1[4], def2[4], def3[4] ;
-  const char *help ;
-} StringXColor ;
+  unsigned char def1[4], def2[4], def3[4];
+  const char *help;
+} StringXColor;
 
 void Init_Options(int num);
 void Init_Options_GUI(int num);
@@ -784,57 +766,13 @@ void ReInit_Options(int num);
 void Print_Options(int num, int level, int diff, int help, const char *filename);
 void Print_OptionsDoc();
 
-StringXString *Get_StringOptionCategory(const char *cat);
-StringXNumber *Get_NumberOptionCategory(const char *cat);
-StringXColor *Get_ColorOptionCategory(const char *cat);
-
-void Set_DefaultStringOptions(int num, StringXString s[]);
-void Set_DefaultNumberOptions(int num, StringXNumber s[]);
-void Set_DefaultColorOptions(int num, StringXColor s[]);
-
-void Set_StringOptions_GUI(int num, StringXString s[]);
-void Set_NumberOptions_GUI(int num, StringXNumber s[]);
-void Set_ColorOptions_GUI(int num, StringXColor s[]);
-
-void * Get_StringOption(const char *str, StringXString s[]);
-void * Get_NumberOption(const char *str, StringXNumber s[]);
-void * Get_ColorOption(const char *str, StringXColor s[]);
-
-void Print_StringOptions(int num, int level, int diff, int help,
-                         StringXString s[], const char *prefix, FILE *file);
-void Print_NumberOptions(int num, int level, int diff, int help,
-                         StringXNumber s[], const char *prefix, FILE *file);
-void Print_ColorOptions(int num, int level, int diff, int help,
-                        StringXColor s[], const char *prefix, FILE *file);
-
-void Print_StringOptionsDoc(StringXString s[], const char *prefix, FILE * file);
-void Print_NumberOptionsDoc(StringXNumber s[], const char *prefix, FILE * file);
-void Print_ColorOptionsDoc(StringXColor s[], const char *prefix, FILE * file);
+bool StringOption(int action, const char *category, int num, 
+		  const char *name, const char *val);
+bool NumberOption(int action, const char *category, int num, 
+		  const char *name, double &val);
+bool ColorOption(int action, const char *category, int num, 
+		 const char *name, unsigned int &val);
 
 GmshColorTable *Get_ColorTable(int num);
 
-extern StringXString GeneralOptions_String[] ;
-extern StringXString GeometryOptions_String[] ;
-extern StringXString MeshOptions_String[] ;
-extern StringXString SolverOptions_String[] ;
-extern StringXString PostProcessingOptions_String[] ;
-extern StringXString ViewOptions_String[] ;
-extern StringXString PrintOptions_String[] ;
-
-extern StringXNumber GeneralOptions_Number[] ;
-extern StringXNumber GeometryOptions_Number[] ;
-extern StringXNumber MeshOptions_Number[] ;
-extern StringXNumber SolverOptions_Number[] ;
-extern StringXNumber PostProcessingOptions_Number[] ;
-extern StringXNumber ViewOptions_Number[] ;
-extern StringXNumber PrintOptions_Number[] ;
-
-extern StringXColor GeneralOptions_Color[] ;
-extern StringXColor GeometryOptions_Color[] ;
-extern StringXColor MeshOptions_Color[] ;
-extern StringXColor SolverOptions_Color[] ;
-extern StringXColor PostProcessingOptions_Color[] ;
-extern StringXColor ViewOptions_Color[] ;
-extern StringXColor PrintOptions_Color[] ;
-
 #endif
