@@ -1,23 +1,7 @@
-// $Id: SmoothData.cpp,v 1.7 2008-06-05 11:52:49 samtech Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <stdio.h>
 #include "SmoothData.h"
@@ -67,9 +51,8 @@ void xyzv::update(int n, double *v)
     nbvals = n;
     nboccurences = 0;
   }
-  else if(nbvals != n) {
-    throw n;
-  }
+  else if(nbvals != n)
+    return; // error
   double x1 = (double)(nboccurences) / (double)(nboccurences + 1);
   double x2 = 1. / (double)(nboccurences + 1);
   for(int i = 0; i < nbvals; i++)
@@ -158,7 +141,7 @@ float xyzn::angle(int i, char nx, char ny, char nz)
   prosca(a, b, &cosc);
   double sinc = sqrt(c[0] * c[0] + c[1] * c[1] + c[2] * c[2]);
   double angplan = myatan2(sinc, cosc);
-  return (float)(angplan * 180. / Pi);
+  return (float)(angplan * 180. / M_PI);
 }
 
 void xyzn::update(char nx, char ny, char nz, float tol)
