@@ -1,9 +1,13 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 #include "GModelIO_Fourier.h"
 #include "MElement.h"
 #include "Draw.h"
 #include "Options.h"
 #include "Context.h"
-#include "OpenFile.h"
+#include "StringUtils.h"
 #include "SelectBuffer.h"
 #include "GUI_Projection.h"
 #include "GUI_Extras.h"
