@@ -1,23 +1,7 @@
-// $Id: Opengl_Window.cpp,v 1.85 2008-05-06 21:11:47 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GmshUI.h"
 #include "GmshDefines.h"
@@ -68,7 +52,7 @@ void lasso_zoom(MousePosition &click1, MousePosition &click2)
 
   CTX.s[0] *= (double)CTX.viewport[2] / (click2.win[0] - click1.win[0]);
   CTX.s[1] *= (double)CTX.viewport[3] / (click2.win[1] - click1.win[1]);
-  CTX.s[2] = MIN(CTX.s[0], CTX.s[1]); // bof...
+  CTX.s[2] = std::min(CTX.s[0], CTX.s[1]); // bof...
   
   // recenter around the center of the lasso rectangle
   MousePosition tmp(click1);
