@@ -1,23 +1,7 @@
-// $Id: GEdge.cpp,v 1.49 2008-05-04 08:31:13 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-//
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <algorithm>
 #include "GModel.h"
@@ -67,7 +51,7 @@ MElement *GEdge::getMeshElement(unsigned int index)
 
 void GEdge::resetMeshAttributes()
 {
-  meshAttributes.Method = LIBRE;
+  meshAttributes.Method = MESH_UNSTRUCTURED;
   meshAttributes.coeffTransfinite = 0.;
   meshAttributes.nbPointsTransfinite = 0;
   meshAttributes.typeTransfinite = 0;
@@ -142,7 +126,7 @@ GPoint GEdge::closestPoint(const SPoint3 & queryPoint) const
   return GPoint(0, 0, 0);
 }
 
-int GEdge::containsParam(double pt) const
+bool GEdge::containsParam(double pt) const
 {
   Range<double> rg = parBounds(0);
   return (pt >= rg.low() && pt <= rg.high());
