@@ -1,23 +1,7 @@
-// $Id: GEdgeLoop.cpp,v 1.15 2008-06-05 11:52:49 samtech Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <algorithm>
 #include <functional>
@@ -32,7 +16,7 @@
 void GEdgeSigned::print() const
 {
   Msg::Info("GEdgeSigned : Edge %d sign %d Ordered Vertices %d,%d",
-      ge->tag(), _sign, getBeginVertex()->tag(), getEndVertex()->tag());
+	    ge->tag(), _sign, getBeginVertex()->tag(), getEndVertex()->tag());
 }
 
 int countInList(std::list<GEdge*> &wire, GEdge *ge)
@@ -81,7 +65,7 @@ GEdgeSigned nextOne(GEdgeSigned *thisOne, std::list<GEdge*> &wire)
       GVertex *v2 = ge->getEndVertex();
       if(v1 == gv) return GEdgeSigned(1, ge);   
       if(v2 == gv) return GEdgeSigned(-1, ge);   
-      throw;
+      Msg::Error("Something wrong in edge loop");
     }
     ++it;
   }
@@ -97,7 +81,7 @@ GEdgeSigned nextOne(GEdgeSigned *thisOne, std::list<GEdge*> &wire)
       GVertex *v2 = ge->getEndVertex();
       if(v1 == gv) return GEdgeSigned(1, ge);   
       if(v2 == gv) return GEdgeSigned(-1, ge);
-      throw;
+      Msg::Error("Something wrong in edge loop");
     }   
     ++it;
   }
@@ -124,16 +108,15 @@ GEdgeLoop::GEdgeLoop(const std::list<GEdge*> &cwire)
 
   GEdgeSigned *prevOne = 0;
 
-  //  Msg::Info("Building a wire");
   GEdgeSigned ges(0,0);
   while(wire.size()){
     ges = nextOne(prevOne, wire);
     if(ges.getSign() == 0){ // oops
-      Msg::Warning("Something wrong in edge loop?");
+      Msg::Error("Something wrong in edge loop");
       break;
     }
     prevOne = &ges;
-    //    ges.print();
+    // ges.print();
     loop.push_back(ges);
   }
 }
