@@ -1,23 +1,7 @@
-// $Id: GFace.cpp,v 1.65 2008-06-10 08:37:33 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-//
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GModel.h"
 #include "GFace.h"
@@ -44,6 +28,8 @@ void dsvdcmp(double **a, int m, int n, double w[], double **v);
 
 extern Context_T CTX;
 
+#define SQU(a)      ((a)*(a))
+
 GFace::GFace(GModel *model, int tag)
   : GEntity(model, tag), r1(0), r2(0), va_geom_triangles(0)
 {
@@ -91,7 +77,7 @@ void GFace::resetMeshAttributes()
 {
   meshAttributes.recombine = 0;
   meshAttributes.recombineAngle = 0.;
-  meshAttributes.Method = LIBRE;
+  meshAttributes.Method = MESH_UNSTRUCTURED;
   meshAttributes.transfiniteArrangement = 0;
   meshAttributes.transfiniteSmoothing = -1;
   meshAttributes.extrude = 0;
@@ -172,20 +158,21 @@ std::string GFace::getAdditionalInfoString()
 {
   if(l_edges.empty()) return std::string("");
 
-  char tmp[256];
+  std::string str("{");
   if(l_edges.size() > 10){
-    sprintf(tmp, "{%d, ..., %d}", (*l_edges.begin())->tag(), (*l_edges.end())->tag());
-    return std::string(tmp);
-  }
-
-  std::string str("");
-  std::list<GEdge*>::const_iterator it = l_edges.begin();
-  str += "{";
-  for(; it != l_edges.end(); it++){
-    if(it != l_edges.begin()) str += ",";
-    sprintf(tmp, "%d", (*it)->tag());
+    char tmp[256];
+    sprintf(tmp, "%d, ..., %d", l_edges.front()->tag(), l_edges.back()->tag());
     str += tmp;
   }
+  else{
+    std::list<GEdge*>::const_iterator it = l_edges.begin();
+    for(; it != l_edges.end(); it++){
+      if(it != l_edges.begin()) str += ",";
+      char tmp[256];
+      sprintf(tmp, "%d", (*it)->tag());
+      str += tmp;
+    }
+  }
   str += "}";
   return str;
 }
@@ -333,7 +320,7 @@ void GFace::computeMeanPlane(const std::vector<SPoint3> &points)
     prosca(res, res2, &cosc);
     sinc = sqrt(c[0] * c[0] + c[1] * c[1] + c[2] * c[2]);
     angplan = myatan2(sinc, cosc);
-    angplan = angle_02pi(angplan) * 180. / Pi;
+    angplan = angle_02pi(angplan) * 180. / M_PI;
     if((angplan > 70 && angplan < 110) || (angplan > 260 && angplan < 280)) {
       Msg::Info("SVD failed (angle=%g): using rough algo...", angplan);
       res[0] = res2[0];
@@ -512,7 +499,7 @@ void GFace::XYZtoUV(const double X, const double Y, const double Z,
       iter = 1;
 
       GPoint P = point(U, V);
-      err2 = sqrt(DSQR(X - P.x()) + DSQR(Y - P.y()) + DSQR(Z - P.z()));
+      err2 = sqrt(SQU(X - P.x()) + SQU(Y - P.y()) + SQU(Z - P.z()));
       if (err2 < 1.e-8 * CTX.lc) return;
 
       while(err > Precision && iter < MaxIter) {
@@ -538,8 +525,8 @@ void GFace::XYZtoUV(const double X, const double Y, const double Z,
 
         //if(Unew > umax || Vnew > vmax || Unew < umin || Vnew < vmin) break;
 
-        err = DSQR(Unew - U) + DSQR(Vnew - V);
-        err2 = sqrt(DSQR(X - P.x()) + DSQR(Y - P.y()) + DSQR(Z - P.z()));
+        err = SQU(Unew - U) + SQU(Vnew - V);
+        err2 = sqrt(SQU(X - P.x()) + SQU(Y - P.y()) + SQU(Z - P.z()));
         iter++;
         U = Unew;
         V = Vnew;
@@ -570,7 +557,7 @@ void GFace::XYZtoUV(const double X, const double Y, const double Z,
 
 SPoint2 GFace::parFromPoint(const SPoint3 &p) const
 {
-  double U, V;
+  double U = 0., V = 0.;
   XYZtoUV(p.x(), p.y(), p.z(), U, V, 1.0);
   return SPoint2(U, V);
 }
@@ -581,15 +568,15 @@ GPoint GFace::closestPoint(const SPoint3 & queryPoint, const double initialGuess
   return GPoint(0, 0, 0);
 }
 
-int GFace::containsParam(const SPoint2 &pt) const
+bool GFace::containsParam(const SPoint2 &pt) const
 {
   Range<double> uu = parBounds(0);
   Range<double> vv = parBounds(1);
   if((pt.x() >= uu.low() && pt.x() <= uu.high()) &&
      (pt.y() >= vv.low() && pt.y() <= vv.high()))
-    return 1;
+    return true;
   else
-    return 0;
+    return false;
 }
 
 bool GFace::buildRepresentationCross()
@@ -730,7 +717,21 @@ bool GFace::buildSTLTriangulation()
 // by default we assume that straight lines are geodesics
 SPoint2 GFace::geodesic(const SPoint2 &pt1 , const SPoint2 &pt2 , double t)
 {
-  return pt1 + (pt2 - pt1) * t;
+  if(CTX.mesh.second_order_experimental && geomType() != GEntity::Plane){
+    // FIXME: this is buggy -- remove the CTX option once we do it in
+    // a robust manner
+    GPoint gp1 = point(pt1.x(), pt1.y());
+    GPoint gp2 = point(pt2.x(), pt2.y());
+    SPoint2 guess = pt1 + (pt2 - pt1) * t;
+    GPoint gp = closestPoint(SPoint3(gp1.x() + t * (gp2.x() - gp1.x()),
+				     gp1.y() + t * (gp2.y() - gp1.y()),
+				     gp1.z() + t * (gp2.z() - gp1.z())),
+			     (double*)guess);
+    return SPoint2(gp.u(), gp.v());
+  }
+  else{
+    return pt1 + (pt2 - pt1) * t;
+  }
 }
 
 // length of a curve drawn on a surface
