@@ -1,23 +1,7 @@
-// $Id: GModelIO_Geo.cpp,v 1.25 2008-06-12 09:31:36 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <stdlib.h>
 #include "GModel.h"
@@ -30,9 +14,12 @@
 #include "gmshFace.h"
 #include "gmshEdge.h"
 #include "gmshRegion.h"
-#include "Parser.h" // for Symbol_T
 #include "Field.h"
 
+#if !defined(HAVE_NO_PARSER)
+#include "Parser.h"
+#endif
+
 void GModel::_createGEOInternals()
 {
   _geo_internals = new GEO_Internals;
@@ -419,8 +406,9 @@ int GModel::writeGEO(const std::string &name, bool printLabels)
   std::for_each(firstFace(), lastFace(), writeGFaceGEO(fp));
   std::for_each(firstRegion(), lastRegion(), writeGRegionGEO(fp));
 
-  // get "old-style" labels from parser
   std::map<int, std::string> labels;
+#if !defined(HAVE_NO_PARSER)
+  // get "old-style" labels from parser
   List_T *old = Tree2List(Symbol_T);
   for(int i = 0; i < List_Nbr(old); i++) {
     Symbol *s = (Symbol *)List_Pointer(old, i);
@@ -431,6 +419,7 @@ int GModel::writeGEO(const std::string &name, bool printLabels)
     }
   }
   List_Delete(old);
+#endif
 
   std::map<int, std::vector<GEntity*> > groups[4];
   getPhysicalGroups(groups);
