@@ -1,23 +1,7 @@
-// $Id: GModelIO_Mesh.cpp,v 1.56 2008-06-10 08:37:33 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <stdlib.h>
 #include <string.h>
@@ -140,8 +124,9 @@ static int getNumVerticesForElementTypeMSH(int type)
   case MSH_TET_4  : return 4;
   case MSH_TET_10 : return 4 + 6;
   case MSH_TET_20 : return 4 + 12 + 4;
-  case MSH_TET_35 : return 4 + 16 + 12 + 3;
-  case MSH_TET_56 : return 4 + 20 + 24 + 8;
+  case MSH_TET_35 : return 4 + 18 + 12 + 1;
+  case MSH_TET_52 : return 4 + 24 + 24 + 0;
+  case MSH_TET_56 : return 4 + 24 + 24 + 4;
   case MSH_HEX_8  : return 8;
   case MSH_HEX_20 : return 8 + 12;
   case MSH_HEX_27 : return 8 + 12 + 6 + 1;
@@ -171,6 +156,7 @@ static void createElementMSH(GModel *m, int num, int type, int physical,
   else{
     MElementFactory factory;
     MElement *e = factory.create(type, v, num, part);
+
     if(!e){
       Msg::Error("Unknown type of element %d", type);
       return;
@@ -252,7 +238,7 @@ int GModel::readMSH(const std::string &name)
         int num;
         if(fscanf(fp, "%d", &num) != 1) return 0;
         if(!fgets(str, sizeof(str), fp)) return 0;
-        std::string name = extractDoubleQuotedString(str, 256);
+        std::string name = ExtractDoubleQuotedString(str, 256);
         if(name.size()) setPhysicalName(name, num);
       }
 
@@ -275,9 +261,9 @@ int GModel::readMSH(const std::string &name)
         }
         else{
           if(fread(&num, sizeof(int), 1, fp) != 1) return 0;
-          if(swap) swapBytes((char*)&num, sizeof(int), 1);
+          if(swap) SwapBytes((char*)&num, sizeof(int), 1);
           if(fread(xyz, sizeof(double), 3, fp) != 3) return 0;
-          if(swap) swapBytes((char*)xyz, sizeof(double), 3);
+          if(swap) SwapBytes((char*)xyz, sizeof(double), 3);
         }
         minVertex = std::min(minVertex, num);
         maxVertex = std::max(maxVertex, num);
@@ -333,7 +319,7 @@ int GModel::readMSH(const std::string &name)
             }
             if(!(numVertices = getNumVerticesForElementTypeMSH(type))) return 0;
           }
-          int indices[30];
+          int indices[60];
           for(int j = 0; j < numVertices; j++) fscanf(fp, "%d", &indices[j]);
           std::vector<MVertex*> vertices;
           if(vertexVector.size()){
@@ -353,7 +339,7 @@ int GModel::readMSH(const std::string &name)
         while(numElementsPartial < numElements){
           int header[3];
           if(fread(header, sizeof(int), 3, fp) != 3) return 0;
-          if(swap) swapBytes((char*)header, sizeof(int), 3);
+          if(swap) SwapBytes((char*)header, sizeof(int), 3);
           int type = header[0];
           int numElms = header[1];
           int numTags = header[2];
@@ -362,7 +348,7 @@ int GModel::readMSH(const std::string &name)
           int *data = new int[n];
           for(int i = 0; i < numElms; i++) {
             if(fread(data, sizeof(int), n, fp) != n) return 0;
-            if(swap) swapBytes((char*)data, sizeof(int), n);
+            if(swap) SwapBytes((char*)data, sizeof(int), n);
             int num = data[0];
             int physical = (numTags > 0) ? data[4 - numTags] : 0;
             int elementary = (numTags > 1) ? data[4 - numTags + 1] : 0;
@@ -447,7 +433,7 @@ int GModel::readMSH(const std::string &name)
     storeVerticesInEntities(vertexMap);
 
   // store the physical tags
-  for(int i = 0; i < 4; i++)  
+  for(int i = 0; i < 4; i++)
     storePhysicalTagsInEntities(this, i, physicals[i]);
 
   fclose(fp);
@@ -634,7 +620,7 @@ int GModel::writeMSH(const std::string &name, double version, bool binary,
   for(fiter it = firstFace(); it != lastFace(); ++it)
     writeElementsMSH(fp, (*it)->quadrangles, saveAll, version, binary, num,
                      (*it)->tag(), (*it)->physicals);
-  writeElementHeaderMSH(binary, fp, elements, MSH_TET_4, MSH_TET_10);
+  writeElementHeaderMSH(binary, fp, elements, MSH_TET_4, MSH_TET_10, MSH_TET_20, MSH_TET_35, MSH_TET_56, MSH_TET_52);
   for(riter it = firstRegion(); it != lastRegion(); ++it)
     writeElementsMSH(fp, (*it)->tetrahedra, saveAll, version, binary, num,
                      (*it)->tag(), (*it)->physicals);
@@ -801,7 +787,7 @@ int GModel::readSTL(const std::string &name, double tolerance)
       if(nfacets > 10000000){
         Msg::Info("Swapping bytes from binary file");
         swap = true;
-        swapBytes((char*)&nfacets, sizeof(unsigned int), 1);
+        SwapBytes((char*)&nfacets, sizeof(unsigned int), 1);
       }
       if(ret && nfacets){
         char *data = new char[nfacets * 50 * sizeof(char)];
@@ -809,7 +795,7 @@ int GModel::readSTL(const std::string &name, double tolerance)
         if(ret == nfacets * 50){
           for(unsigned int i = 0; i < nfacets; i++) {
             float *xyz = (float *)&data[i * 50 * sizeof(char)];
-            if(swap) swapBytes((char*)xyz, sizeof(float), 12);
+            if(swap) SwapBytes((char*)xyz, sizeof(float), 12);
             for(int j = 0; j < 3; j++){
               SPoint3 p(xyz[3 + 3 * j], xyz[3 + 3 * j + 1], xyz[3 + 3 * j + 2]);
               points.push_back(p);
@@ -1396,18 +1382,19 @@ int GModel::readMESH(const std::string &name)
   char str[256];
   int format;
   sscanf(buffer, "%s %d", str, &format);
-
   if(format != 1){
     Msg::Error("Medit mesh import only available for ASCII files");
     return 0;
   }
 
   std::vector<MVertex*> vertexVector;
-  std::map<int, std::vector<MElement*> > elements[3];
+  std::map<int, std::vector<MElement*> > elements[4];
+  std::vector<MVertex*> corners,ridges;
 
   while(!feof(fp)) {
-    if(!fgets(buffer, sizeof(buffer), fp)) break;
-    if(buffer[0] != '#'){ // skip comments
+    if(!fgets(buffer, 256, fp)) break;
+    if(buffer[0] != '#'){ // skip comments and empty lines
+      str[0]='\0';
       sscanf(buffer, "%s", str);
       if(!strcmp(str, "Dimension")){
         if(!fgets(buffer, sizeof(buffer), fp)) break;
@@ -1426,6 +1413,21 @@ int GModel::readMESH(const std::string &name)
           vertexVector[i] = new MVertex(x, y, z);
         }
       }
+      else if(!strcmp(str, "Edges")){
+        if(!fgets(buffer, sizeof(buffer), fp)) break;
+        int nbe;
+        sscanf(buffer, "%d", &nbe);
+        Msg::Info("%d edges", nbe);
+        for(int i = 0; i < nbe; i++) {
+          if(!fgets(buffer, sizeof(buffer), fp)) break;
+          int n[2], cl;
+          sscanf(buffer, "%d %d %d", &n[0], &n[1], &cl);
+          for(int j = 0; j < 2; j++) n[j]--;
+          std::vector<MVertex*> vertices;
+          if(!getVertices(2, n, vertexVector, vertices)) return 0;
+          elements[3][cl].push_back(new MLine(vertices));
+        }
+      }
       else if(!strcmp(str, "Triangles")){
         if(!fgets(buffer, sizeof(buffer), fp)) break;
         int nbe;
@@ -1441,6 +1443,36 @@ int GModel::readMESH(const std::string &name)
           elements[0][cl].push_back(new MTriangle(vertices));
         }
       }
+      else if(!strcmp(str, "Corners")){
+        if(!fgets(buffer, sizeof(buffer), fp)) break;
+        int nbe;
+        sscanf(buffer, "%d", &nbe);
+        Msg::Info("%d corners", nbe);
+        for(int i = 0; i < nbe; i++) {
+          if(!fgets(buffer, sizeof(buffer), fp)) break;
+          int  n[1];
+          sscanf(buffer, "%d",&n[0]);
+          for(int j = 0; j < 1; j++) n[j]--;
+	  //          std::vector<MVertex*> vertices;
+	  //          if(!getVertices(1, n, vertexVector, vertices)) return 0;
+	  //          corners.push_back(vertices[0]);
+        }
+      }
+      else if(!strcmp(str, "Ridges")){
+        if(!fgets(buffer, sizeof(buffer), fp)) break;
+        int nbe;
+        sscanf(buffer, "%d", &nbe);
+        Msg::Info("%d ridges", nbe);
+        for(int i = 0; i < nbe; i++) {
+          if(!fgets(buffer, sizeof(buffer), fp)) break;
+          int  n[1];
+          sscanf(buffer, "%d",&n[0]);
+          for(int j = 0; j < 1; j++) n[j]--;
+	  //          std::vector<MVertex*> vertices;
+	  //          if(!getVertices(1, n, vertexVector, vertices)) return 0;
+	  //          ridges.push_back(vertices[0]);
+        }
+      }
       else if(!strcmp(str, "Quadrilaterals")) {
         if(!fgets(buffer, sizeof(buffer), fp)) break;
         int nbe;
