@@ -1,23 +1,7 @@
-// $Id: GModelIO_OCC.cpp,v 1.34 2008-06-03 07:25:07 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GModelIO_OCC.h"
 #include "Message.h"
@@ -26,6 +10,13 @@
 #include "OCCEdge.h"
 #include "OCCFace.h"
 #include "OCCRegion.h"
+#include "MElement.h"
+#include "OpenFile.h"
+
+#if defined(HAVE_OCC_MESH_CONSTRAINTS)
+#include "MeshGmsh_Constrain.hxx"
+#include "MeshGmsh_EdgeConstrain.hxx"
+#endif
 
 extern Context_T CTX;
 
@@ -399,12 +390,6 @@ void OCC_Internals::loadShape(const TopoDS_Shape *s)
 {
   shape = *s;
   BRepTools::Clean(shape);
-  // FIXME should we apply the healing stuff when we import a shape?
-  // healGeometry(CTX.geom.tolerance, 
-  //              CTX.geom.occ_fix_small_edges,
-  //              CTX.geom.occ_fix_small_faces,
-  //              CTX.geom.occ_sew_faces);
-  // BRepTools::Clean(shape);
   buildLists();
 }
 
@@ -443,58 +428,11 @@ void OCC_Internals::buildGModel(GModel *model)
   }
 }
 
-void GModel::_deleteOCCInternals()
-{
-  if(_occ_internals) delete _occ_internals;
-  _occ_internals = 0;
-}
-
-int GModel::readOCCBREP(const std::string &fn)
-{
-  _occ_internals = new OCC_Internals;
-  _occ_internals->loadBREP(fn.c_str());
-  _occ_internals->buildGModel(this);
-  snapVertices();
-  return 1;
-}
-
-int GModel::readOCCIGES(const std::string &fn)
-{
-  _occ_internals = new OCC_Internals;
-  _occ_internals->loadIGES(fn.c_str());
-  _occ_internals->buildGModel(this);
-  return 1;
-}
-
-int GModel::readOCCSTEP(const std::string &fn)
-{
-  _occ_internals = new OCC_Internals;
-  _occ_internals->loadSTEP(fn.c_str());
-  _occ_internals->buildGModel(this);
-  return 1;
-}
-
-int GModel::importOCCShape(const void *shape, const void *options)
-{
-  _occ_internals = new OCC_Internals;
-  _occ_internals->loadShape((TopoDS_Shape*)shape);
-  _occ_internals->buildGModel(this);
-  snapVertices();
-  // FIXME remove this when CL API is done
-  extern void SetBoundingBox();
-  SetBoundingBox();
-  return 1;
-}
-
-// This function has been inspired from SALOME It removes all
-// duplicates from the geometry, starting from vertices, edges, faces,
-// shells and solids This
-
 void OCC_Internals::removeAllDuplicates(const double &tolerance)
 {
 }
 
-void AddSimpleShapes(TopoDS_Shape theShape, TopTools_ListOfShape &theList)
+static void addSimpleShapes(TopoDS_Shape theShape, TopTools_ListOfShape &theList)
 {
   if (theShape.ShapeType() != TopAbs_COMPOUND &&
       theShape.ShapeType() != TopAbs_COMPSOLID) {
@@ -510,7 +448,7 @@ void AddSimpleShapes(TopoDS_Shape theShape, TopTools_ListOfShape &theList)
     if (mapShape.Add(aShape_i)) {
       if (aShape_i.ShapeType() == TopAbs_COMPOUND ||
           aShape_i.ShapeType() == TopAbs_COMPSOLID) {
-        AddSimpleShapes(aShape_i, theList);
+        addSimpleShapes(aShape_i, theList);
       } 
       else {
         theList.Append(aShape_i);
@@ -519,7 +457,7 @@ void AddSimpleShapes(TopoDS_Shape theShape, TopTools_ListOfShape &theList)
   }
 }
 
-void OCC_Internals::applyBooleanOperator(TopoDS_Shape tool,  const BooleanOperator & op)
+void OCC_Internals::applyBooleanOperator(TopoDS_Shape tool, const BooleanOperator &op)
 {
   if (tool.IsNull()) return;
   if (shape.IsNull()) shape = tool;
@@ -532,8 +470,8 @@ void OCC_Internals::applyBooleanOperator(TopoDS_Shape tool,  const BooleanOperat
         TopoDS_Compound C;
         B.MakeCompound(C);
         TopTools_ListOfShape listShape1, listShape2;
-        AddSimpleShapes(shape, listShape1);
-        AddSimpleShapes(tool, listShape2);
+        addSimpleShapes(shape, listShape1);
+        addSimpleShapes(tool, listShape2);
         Standard_Boolean isCompound =
           (listShape1.Extent() > 1 || listShape2.Extent() > 1);
         
@@ -565,7 +503,7 @@ void OCC_Internals::applyBooleanOperator(TopoDS_Shape tool,  const BooleanOperat
         }
         if (isCompound) {
           TopTools_ListOfShape listShapeC;
-          AddSimpleShapes(C, listShapeC);
+          addSimpleShapes(C, listShapeC);
           TopTools_ListIteratorOfListOfShape itSubC (listShapeC);
           bool isOnlySolids = true;
           for (; itSubC.More(); itSubC.Next()) {
@@ -573,31 +511,128 @@ void OCC_Internals::applyBooleanOperator(TopoDS_Shape tool,  const BooleanOperat
             if (aValueC.ShapeType() != TopAbs_SOLID) isOnlySolids = false;
           }
           if (isOnlySolids)
-            throw;
-            //      theNewShape = GEOMImpl_GlueDriver::GlueFaces(C, Precision::Confusion());
-          else
-            theNewShape = C;
+	    Msg::Error("Face gluing not implemented");
+	  //  theNewShape = GEOMImpl_GlueDriver::GlueFaces(C, Precision::Confusion());
+          //else
+	      theNewShape = C;
         }       
       }
       break;
     case OCC_Internals::Cut :
-      {
-      }
     default :
-      throw;
+      Msg::Error("Requested boolean operation not implemented");
+      break;
     }
   }
 }
   
-void OCC_Internals::Sphere(const SPoint3 & center, const double & radius,
-                           const BooleanOperator & op)
+void OCC_Internals::Sphere(const SPoint3 &center, const double &radius,
+                           const BooleanOperator &op)
 {
   // build a sphere
   gp_Pnt aP(center.x(), center.y(), center.z());  
   TopoDS_Shape aShape = BRepPrimAPI_MakeSphere(aP, radius).Shape(); 
   // either add it to the current shape, or use it as a tool and remove the
   // sphere from the current shape
-  applyBooleanOperator(aShape,  op);
+  applyBooleanOperator(aShape, op);
+}
+
+void GModel::_deleteOCCInternals()
+{
+  if(_occ_internals) delete _occ_internals;
+  _occ_internals = 0;
+}
+
+int GModel::readOCCBREP(const std::string &fn)
+{
+  _occ_internals = new OCC_Internals;
+  _occ_internals->loadBREP(fn.c_str());
+  _occ_internals->buildGModel(this);
+  snapVertices();
+  return 1;
+}
+
+int GModel::readOCCIGES(const std::string &fn)
+{
+  _occ_internals = new OCC_Internals;
+  _occ_internals->loadIGES(fn.c_str());
+  _occ_internals->buildGModel(this);
+  return 1;
+}
+
+int GModel::readOCCSTEP(const std::string &fn)
+{
+  _occ_internals = new OCC_Internals;
+  _occ_internals->loadSTEP(fn.c_str());
+  _occ_internals->buildGModel(this);
+  return 1;
+}
+
+static void applyOCCMeshConstraints(GModel *m, const void *constraints)
+{
+#if defined(HAVE_OCC_MESH_CONSTRAINTS)
+  MeshGmsh_Constrain *meshConstraints = (MeshGmsh_Constrain*)constraints;
+
+  // treat mesh constraints (if any) on model edges
+  MeshGmsh_DataMapOfShapeOfEdgeConstrain edgeConstraints;
+  meshConstraints->GetEdgeConstrain(edgeConstraints);
+  for(GModel::eiter it = m->firstEdge(); it != m->lastEdge(); ++it){
+    GEdge *ge = *it;
+    TopoDS_Shape *shape = (TopoDS_Shape*)ge->getNativePtr();
+    if(edgeConstraints.IsBound(*shape)) {
+      Msg::Debug("Applying mesh contraints on edge %d", ge->tag());
+      const MeshGmsh_EdgeConstrain &c(edgeConstraints.Find(*shape));
+      if(c.IsMeshImposed() == Standard_True){
+	TColStd_SequenceOfInteger nodeNum;
+	c.GetNodesNumber(nodeNum);
+	TColStd_SequenceOfReal nodePar;
+	c.GetParameters(nodePar);
+	int n = nodeNum.Length();
+	if(n < 2){
+	  Msg::Error("We need at least two points in the edge constraint");
+	}
+	else if(nodePar.Length() != n){
+	  Msg::Error("Wrong number of parameters in edge constraint: %d != %d",
+		     nodeNum.Length(), nodePar.Length());
+	}
+	else{
+	  // set the mesh as immutable
+	  ge->meshAttributes.Method == MESH_NONE;
+	  // set the correct tags on the boundary vertices
+	  ge->getBeginVertex()->mesh_vertices[0]->setNum(nodeNum(0));
+	  ge->getEndVertex()->mesh_vertices[0]->setNum(nodeNum(n - 1));
+	  // set the mesh on the edge
+	  for(int i = 1; i < n - 1; i++){
+	    double u = nodePar(i);
+	    GPoint p = ge->point(u);
+	    MEdgeVertex *v = new MEdgeVertex(p.x(), p.y(), p.z(), ge, u);
+	    v->setNum(nodeNum(i));
+	    ge->mesh_vertices.push_back(v);
+	  }
+	  for(unsigned int i = 0; i < ge->mesh_vertices.size() + 1; i++){
+	    MVertex *v0 = (i == 0) ? 
+	      ge->getBeginVertex()->mesh_vertices[0] : ge->mesh_vertices[i - 1];
+	    MVertex *v1 = (i == ge->mesh_vertices.size()) ? 
+	      ge->getEndVertex()->mesh_vertices[0] : ge->mesh_vertices[i];
+	    ge->lines.push_back(new MLine(v0, v1));
+	  }
+	}
+      }
+    }
+  }
+#endif
+  
+}
+
+int GModel::importOCCShape(const void *shape, const void *meshConstraints)
+{
+  _occ_internals = new OCC_Internals;
+  _occ_internals->loadShape((TopoDS_Shape*)shape);
+  _occ_internals->buildGModel(this);
+  snapVertices();
+  SetBoundingBox();
+  if(meshConstraints) applyOCCMeshConstraints(this, meshConstraints);
+  return 1;
 }
 
 #else
