@@ -1,23 +1,7 @@
-// $Id: GRegion.cpp,v 1.27 2008-03-20 11:44:05 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-//
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GModel.h"
 #include "GRegion.h"
@@ -79,7 +63,7 @@ MElement *GRegion::getMeshElement(unsigned int index)
 
 void GRegion::resetMeshAttributes()
 {
-  meshAttributes.Method = LIBRE;
+  meshAttributes.Method = MESH_UNSTRUCTURED;
   meshAttributes.extrude = 0;
 }
 
@@ -146,20 +130,21 @@ std::string GRegion::getAdditionalInfoString()
 {
   if(l_faces.empty()) return std::string("");
 
-  char tmp[256];
+  std::string str("{");
   if(l_faces.size() > 10){
-    sprintf(tmp, "{%d, ..., %d}", (*l_faces.begin())->tag(), (*l_faces.end())->tag());
-    return std::string(tmp);
-  }
-
-  std::string str("");
-  std::list<GFace*>::const_iterator it = l_faces.begin();
-  str += "{";
-  for(; it != l_faces.end(); it++){
-    if(it != l_faces.begin()) str += ",";
-    sprintf(tmp, "%d", (*it)->tag());
+    char tmp[256];
+    sprintf(tmp, "%d, ..., %d", l_faces.front()->tag(), l_faces.back()->tag());
     str += tmp;
   }
+  else{
+    std::list<GFace*>::const_iterator it = l_faces.begin();
+    for(; it != l_faces.end(); it++){
+      if(it != l_faces.begin()) str += ",";
+      char tmp[256];
+      sprintf(tmp, "%d", (*it)->tag());
+      str += tmp;
+    }
+  }
   str += "}";
   return str;
 }
