@@ -1,23 +1,7 @@
-// $Id: Geo.cpp,v 1.117 2008-06-20 16:25:38 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <string.h>
 #include "Message.h"
@@ -26,40 +10,15 @@
 #include "Geo.h"
 #include "GModel.h"
 #include "GeoInterpolation.h"
-#include "Parser.h"
 #include "Field.h"
 #include "Context.h"
 
+#define SQU(a)      ((a)*(a))
+
 extern Context_T CTX;
 
 static List_T *ListOfTransformedPoints = NULL;
 
-void GEO_Internals::alloc_all()
-{
-  MaxPointNum = MaxLineNum = MaxLineLoopNum = MaxSurfaceNum = 0;
-  MaxSurfaceLoopNum = MaxVolumeNum = MaxPhysicalNum = 0;
-  Points = Tree_Create(sizeof(Vertex *), compareVertex);
-  Curves = Tree_Create(sizeof(Curve *), compareCurve);
-  EdgeLoops = Tree_Create(sizeof(EdgeLoop *), compareEdgeLoop);
-  Surfaces = Tree_Create(sizeof(Surface *), compareSurface);
-  SurfaceLoops = Tree_Create(sizeof(SurfaceLoop *), compareSurfaceLoop);
-  Volumes = Tree_Create(sizeof(Volume *), compareVolume);
-  PhysicalGroups = List_Create(5, 5, sizeof(PhysicalGroup *));
-}
-
-void GEO_Internals::free_all()
-{
-  MaxPointNum = MaxLineNum = MaxLineLoopNum = MaxSurfaceNum = 0;
-  MaxSurfaceLoopNum = MaxVolumeNum = MaxPhysicalNum = 0;
-  Tree_Action(Points, Free_Vertex); Tree_Delete(Points);
-  Tree_Action(Curves, Free_Curve); Tree_Delete(Curves);
-  Tree_Action(EdgeLoops, Free_EdgeLoop); Tree_Delete(EdgeLoops);
-  Tree_Action(Surfaces, Free_Surface); Tree_Delete(Surfaces);
-  Tree_Action(SurfaceLoops, Free_SurfaceLoop); Tree_Delete(SurfaceLoops);
-  Tree_Action(Volumes, Free_Volume); Tree_Delete(Volumes);
-  List_Action(PhysicalGroups, Free_PhysicalGroup); List_Delete(PhysicalGroups);
-}
-
 // Comparison routines
 
 int compareVertex(const void *a, const void *b)
@@ -69,7 +28,7 @@ int compareVertex(const void *a, const void *b)
   return abs(q->Num) - abs(w->Num);
 }
 
-int comparePosition(const void *a, const void *b)
+static int comparePosition(const void *a, const void *b)
 {
   Vertex *q = *(Vertex **)a;
   Vertex *w = *(Vertex **)b;
@@ -86,42 +45,42 @@ int comparePosition(const void *a, const void *b)
   return 0;
 }
 
-int compareSurfaceLoop(const void *a, const void *b)
+static int compareSurfaceLoop(const void *a, const void *b)
 {
   SurfaceLoop *q = *(SurfaceLoop **)a;
   SurfaceLoop *w = *(SurfaceLoop **)b;
   return q->Num - w->Num;
 }
 
-int compareEdgeLoop(const void *a, const void *b)
+static int compareEdgeLoop(const void *a, const void *b)
 {
   EdgeLoop *q = *(EdgeLoop **)a;
   EdgeLoop *w = *(EdgeLoop **)b;
   return q->Num - w->Num;
 }
 
-int compareCurve(const void *a, const void *b)
+static int compareCurve(const void *a, const void *b)
 {
   Curve *q = *(Curve **)a;
   Curve *w = *(Curve **)b;
   return q->Num - w->Num;
 }
 
-int compareSurface(const void *a, const void *b)
+static int compareSurface(const void *a, const void *b)
 {
   Surface *q = *(Surface **)a;
   Surface *w = *(Surface **)b;
   return q->Num - w->Num;
 }
 
-int compareVolume(const void *a, const void *b)
+static int compareVolume(const void *a, const void *b)
 {
   Volume *q = *(Volume **)a;
   Volume *w = *(Volume **)b;
   return q->Num - w->Num;
 }
 
-int comparePhysicalGroup(const void *a, const void *b)
+static int comparePhysicalGroup(const void *a, const void *b)
 {
   PhysicalGroup *q = *(PhysicalGroup **)a;
   PhysicalGroup *w = *(PhysicalGroup **)b;
@@ -132,6 +91,16 @@ int comparePhysicalGroup(const void *a, const void *b)
     return q->Num - w->Num;
 }
 
+void Projette(Vertex *v, double mat[3][3])
+{
+  double X = v->Pos.X * mat[0][0] + v->Pos.Y * mat[0][1] + v->Pos.Z * mat[0][2];
+  double Y = v->Pos.X * mat[1][0] + v->Pos.Y * mat[1][1] + v->Pos.Z * mat[1][2];
+  double Z = v->Pos.X * mat[2][0] + v->Pos.Y * mat[2][1] + v->Pos.Z * mat[2][2];
+  v->Pos.X = X;
+  v->Pos.Y = Y;
+  v->Pos.Z = Z;
+}
+
 // Basic entity creation/deletion functions
 
 Vertex *Create_Vertex(int Num, double X, double Y, double Z, double lc, double u)
@@ -140,7 +109,7 @@ Vertex *Create_Vertex(int Num, double X, double Y, double Z, double lc, double u
   pV->w = 1.0;
   pV->Num = Num;
   GModel::current()->getGEOInternals()->MaxPointNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxPointNum, Num);
+    std::max(GModel::current()->getGEOInternals()->MaxPointNum, Num);
   pV->u = u;
   pV->geometry = 0;
   return pV;
@@ -153,14 +122,14 @@ Vertex *Create_Vertex(int Num, double u, double v, gmshSurface *surf, double lc)
   pV->w = 1.0;
   pV->Num = Num;
   GModel::current()->getGEOInternals()->MaxPointNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxPointNum, Num);
+    std::max(GModel::current()->getGEOInternals()->MaxPointNum, Num);
   pV->u = u;
   pV->geometry = surf;
   pV->pntOnGeometry = SPoint2(u,v);
   return pV;
 }
 
-void Free_Vertex(void *a, void *b)
+static void Free_Vertex(void *a, void *b)
 {
   Vertex *v = *(Vertex **)a;
   if(v) {
@@ -175,7 +144,7 @@ PhysicalGroup *Create_PhysicalGroup(int Num, int typ, List_T *intlist)
   p->Entities = List_Create(List_Nbr(intlist), 1, sizeof(int));
   p->Num = Num;
   GModel::current()->getGEOInternals()->MaxPhysicalNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxPhysicalNum, Num);
+    std::max(GModel::current()->getGEOInternals()->MaxPhysicalNum, Num);
   p->Typ = typ;
   p->Visible = 1;
   for(int i = 0; i < List_Nbr(intlist); i++) {
@@ -186,7 +155,7 @@ PhysicalGroup *Create_PhysicalGroup(int Num, int typ, List_T *intlist)
   return p;
 }
 
-void Free_PhysicalGroup(void *a, void *b)
+static void Free_PhysicalGroup(void *a, void *b)
 {
   PhysicalGroup *p = *(PhysicalGroup **)a;
   if(p) {
@@ -202,7 +171,7 @@ EdgeLoop *Create_EdgeLoop(int Num, List_T *intlist)
   l->Curves = List_Create(List_Nbr(intlist), 1, sizeof(int));
   l->Num = Num;
   GModel::current()->getGEOInternals()->MaxLineLoopNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxLineLoopNum, Num);
+    std::max(GModel::current()->getGEOInternals()->MaxLineLoopNum, Num);
   for(int i = 0; i < List_Nbr(intlist); i++) {
     int j;
     List_Read(intlist, i, &j);
@@ -211,7 +180,7 @@ EdgeLoop *Create_EdgeLoop(int Num, List_T *intlist)
   return l;
 }
 
-void Free_EdgeLoop(void *a, void *b)
+static void Free_EdgeLoop(void *a, void *b)
 {
   EdgeLoop *l = *(EdgeLoop **)a;
   if(l) {
@@ -227,7 +196,7 @@ SurfaceLoop *Create_SurfaceLoop(int Num, List_T *intlist)
   l->Surfaces = List_Create(List_Nbr(intlist), 1, sizeof(int));
   l->Num = Num;
   GModel::current()->getGEOInternals()->MaxSurfaceLoopNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxSurfaceLoopNum, Num);
+    std::max(GModel::current()->getGEOInternals()->MaxSurfaceLoopNum, Num);
   for(int i = 0; i < List_Nbr(intlist); i++) {
     int j;
     List_Read(intlist, i, &j);
@@ -236,7 +205,7 @@ SurfaceLoop *Create_SurfaceLoop(int Num, List_T *intlist)
   return l;
 }
 
-void Free_SurfaceLoop(void *a, void *b)
+static void Free_SurfaceLoop(void *a, void *b)
 {
   SurfaceLoop *l = *(SurfaceLoop **)a;
   if(l) {
@@ -414,11 +383,11 @@ void End_Curve(Curve *c)
         // sur y1/f2 ou y3/f2, qui peuvent legerement etre hors de
         // [-1,1]
         if(x1 < 0)
-          A1 = -myasin(y1 / f2) + A4 + Pi;
+          A1 = -myasin(y1 / f2) + A4 + M_PI;
         else
           A1 = myasin(y1 / f2) + A4;
         if(x3 < 0)
-          A3 = -myasin(y3 / f2) + A4 + Pi;
+          A3 = -myasin(y3 / f2) + A4 + M_PI;
         else
           A3 = myasin(y3 / f2) + A4;
       }
@@ -433,7 +402,7 @@ void End_Curve(Curve *c)
     A1 = angle_02pi(A1);
     A3 = angle_02pi(A3);
     if(A1 >= A3)
-      A3 += 2 * Pi;
+      A3 += 2 * M_PI;
 
     c->Circle.t1 = A1;
     c->Circle.t2 = A3;
@@ -444,7 +413,7 @@ void End_Curve(Curve *c)
     for(int i = 0; i < 4; i++)
       c->Circle.v[i] = v[i];
 
-    if(!CTX.expert_mode && c->Num > 0 && A3 - A1 > 1.01 * Pi){
+    if(!CTX.expert_mode && c->Num > 0 && A3 - A1 > 1.01 * M_PI){
       Msg::Error("Circle or ellipse arc %d greater than Pi (angle=%g)", c->Num, A3-A1);
       Msg::Error("(If you understand what this implies, you can disable this error");
       Msg::Error("message by selecting `Enable expert mode' in the option dialog.");
@@ -496,8 +465,8 @@ Curve *Create_Curve(int Num, int Typ, int Order, List_T *Liste,
   pC->Typ = Typ;
   pC->Num = Num;
   GModel::current()->getGEOInternals()->MaxLineNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxLineNum, Num);
-  pC->Method = LIBRE;
+    std::max(GModel::current()->getGEOInternals()->MaxLineNum, Num);
+  pC->Method = MESH_UNSTRUCTURED;
   pC->degre = Order;
   pC->Circle.n[0] = 0.0;
   pC->Circle.n[1] = 0.0;
@@ -589,7 +558,7 @@ Curve *Create_Curve(int Num, int Typ, int Order, List_T *Liste,
   return pC;
 }
 
-void Free_Curve(void *a, void *b)
+static void Free_Curve(void *a, void *b)
 {
   Curve *pC = *(Curve **)a;
   if(pC) {
@@ -610,9 +579,9 @@ Surface *Create_Surface(int Num, int Typ)
   pS->RuledSurfaceOptions = 0;
 
   GModel::current()->getGEOInternals()->MaxSurfaceNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxSurfaceNum, Num);
+    std::max(GModel::current()->getGEOInternals()->MaxSurfaceNum, Num);
   pS->Typ = Typ;
-  pS->Method = LIBRE;
+  pS->Method = MESH_UNSTRUCTURED;
   pS->Recombine = 0;
   pS->Recombine_Dir = -1;
   pS->RecombineAngle = 45;
@@ -626,7 +595,7 @@ Surface *Create_Surface(int Num, int Typ)
   return (pS);
 }
 
-void Free_Surface(void *a, void *b)
+static void Free_Surface(void *a, void *b)
 {
   Surface *pS = *(Surface **)a;
   if(pS) {
@@ -646,9 +615,9 @@ Volume *Create_Volume(int Num, int Typ)
   pV->Visible = 1;
   pV->Num = Num;
   GModel::current()->getGEOInternals()->MaxVolumeNum = 
-    IMAX(GModel::current()->getGEOInternals()->MaxVolumeNum, Num);
+    std::max(GModel::current()->getGEOInternals()->MaxVolumeNum, Num);
   pV->Typ = Typ;
-  pV->Method = LIBRE;
+  pV->Method = MESH_UNSTRUCTURED;
   pV->TrsfPoints = List_Create(6, 6, sizeof(Vertex *));
   pV->Surfaces = List_Create(1, 2, sizeof(Surface *));
   pV->SurfacesOrientations = List_Create(1, 2, sizeof(int));
@@ -657,7 +626,7 @@ Volume *Create_Volume(int Num, int Typ)
   return pV;
 }
 
-void Free_Volume(void *a, void *b)
+static void Free_Volume(void *a, void *b)
 {
   Volume *pV = *(Volume **)a;
   if(pV) {
@@ -730,17 +699,17 @@ int NEWPHYSICAL(void)
 
 int NEWREG(void)
 {
-  return (IMAX(GModel::current()->getGEOInternals()->MaxLineNum,
-               IMAX(GModel::current()->getGEOInternals()->MaxLineLoopNum,
-                    IMAX(GModel::current()->getGEOInternals()->MaxSurfaceNum,
-                         IMAX(GModel::current()->getGEOInternals()->MaxSurfaceLoopNum,
-                              IMAX(GModel::current()->getGEOInternals()->MaxVolumeNum,
-                                   GModel::current()->getGEOInternals()->MaxPhysicalNum)))))
+  return (std::max(GModel::current()->getGEOInternals()->MaxLineNum,
+            std::max(GModel::current()->getGEOInternals()->MaxLineLoopNum,
+              std::max(GModel::current()->getGEOInternals()->MaxSurfaceNum,
+                std::max(GModel::current()->getGEOInternals()->MaxSurfaceLoopNum,
+                  std::max(GModel::current()->getGEOInternals()->MaxVolumeNum,
+                           GModel::current()->getGEOInternals()->MaxPhysicalNum)))))
           + 1);
 }
 
-int compare2Lists(List_T *List1, List_T *List2,
-                  int (*fcmp) (const void *a, const void *b))
+static int compare2Lists(List_T *List1, List_T *List2,
+			 int (*fcmp) (const void *a, const void *b))
 {
   int i, found;
 
@@ -851,7 +820,7 @@ PhysicalGroup *FindPhysicalGroup(int num, int type)
   return NULL;
 }
 
-void CopyVertex(Vertex *v, Vertex *vv)
+static void CopyVertex(Vertex *v, Vertex *vv)
 {
   vv->lc = v->lc;
   vv->u = v->u;
@@ -860,7 +829,7 @@ void CopyVertex(Vertex *v, Vertex *vv)
   vv->Pos.Z = v->Pos.Z;
 }
 
-Vertex *DuplicateVertex(Vertex *v)
+static Vertex *DuplicateVertex(Vertex *v)
 {
   if(!v) return NULL;
   Vertex *pv = Create_Vertex(NEWPOINT(), 0, 0, 0, 0, 0);
@@ -869,14 +838,14 @@ Vertex *DuplicateVertex(Vertex *v)
   return pv;
 }
 
-int compareAbsCurve(const void *a, const void *b)
+static int compareAbsCurve(const void *a, const void *b)
 {
   Curve *q = *(Curve **)a;
   Curve *w = *(Curve **)b;
   return abs(q->Num) - abs(w->Num);
 }
 
-void CopyCurve(Curve *c, Curve *cc)
+static void CopyCurve(Curve *c, Curve *cc)
 {
   int i, j;
   cc->Typ = c->Typ;
@@ -906,7 +875,7 @@ void CopyCurve(Curve *c, Curve *cc)
   Tree_Insert(GModel::current()->getGEOInternals()->Curves, &cc);
 }
 
-Curve *DuplicateCurve(Curve *c)
+static Curve *DuplicateCurve(Curve *c)
 {
   Curve *pc;
   Vertex *v, *newv;
@@ -924,7 +893,7 @@ Curve *DuplicateCurve(Curve *c)
   return pc;
 }
 
-void CopySurface(Surface *s, Surface *ss)
+static void CopySurface(Surface *s, Surface *ss)
 {
   int i, j;
   ss->Typ = s->Typ;
@@ -947,11 +916,10 @@ void CopySurface(Surface *s, Surface *ss)
   Tree_Insert(GModel::current()->getGEOInternals()->Surfaces, &ss);
 }
 
-Surface *DuplicateSurface(Surface *s)
+static Surface *DuplicateSurface(Surface *s)
 {
   Surface *ps;
   Curve *c, *newc;
-  int i;
 
   ps = Create_Surface(NEWSURFACE(), 0);
   CopySurface(s, ps);
@@ -963,9 +931,8 @@ Surface *DuplicateSurface(Surface *s)
   return ps;
 }
 
-void CopyVolume(Volume *v, Volume *vv)
+static void CopyVolume(Volume *v, Volume *vv)
 {
-  int i, j;
   vv->Typ = v->Typ;
   // We should not copy the meshing method (or the recombination
   // status): if the meshes are to be copied, the meshing algorithm
@@ -976,7 +943,7 @@ void CopyVolume(Volume *v, Volume *vv)
   Tree_Insert(GModel::current()->getGEOInternals()->Volumes, &vv);
 }
 
-Volume *DuplicateVolume(Volume *v)
+static Volume *DuplicateVolume(Volume *v)
 {
   Volume *pv;
   Surface *s, *news;
@@ -1048,7 +1015,7 @@ void CopyShape(int Type, int Num, int *New)
   }
 }
 
-void DeletePoint(int ip)
+static void DeletePoint(int ip)
 {
   Vertex *v = FindPoint(ip);
   if(!v)
@@ -1071,7 +1038,7 @@ void DeletePoint(int ip)
   Free_Vertex(&v, NULL);
 }
 
-void DeleteCurve(int ip)
+static void DeleteCurve(int ip)
 {
   Curve *c = FindCurve(ip);
   if(!c)
@@ -1094,7 +1061,7 @@ void DeleteCurve(int ip)
   Free_Curve(&c, NULL);
 }
 
-void DeleteSurface(int is)
+static void DeleteSurface(int is)
 {
   Surface *s = FindSurface(is);
   if(!s)
@@ -1117,7 +1084,7 @@ void DeleteSurface(int is)
   Free_Surface(&s, NULL);
 }
 
-void DeleteVolume(int iv)
+static void DeleteVolume(int iv)
 {
   Volume *v = FindVolume(iv);
   if(!v)
@@ -1167,7 +1134,7 @@ void DeleteShape(int Type, int Num)
   }
 }
 
-void ColorCurve(int ip, unsigned int col)
+static void ColorCurve(int ip, unsigned int col)
 {
   Curve *c = FindCurve(ip);
   if(!c)
@@ -1176,7 +1143,7 @@ void ColorCurve(int ip, unsigned int col)
   c->Color.mesh = c->Color.geom = col;
 }
 
-void ColorSurface(int is, unsigned int col)
+static void ColorSurface(int is, unsigned int col)
 {
   Surface *s = FindSurface(is);
   if(!s)
@@ -1185,7 +1152,7 @@ void ColorSurface(int is, unsigned int col)
   s->Color.mesh = s->Color.geom = col;
 }
 
-void ColorVolume(int iv, unsigned int col)
+static void ColorVolume(int iv, unsigned int col)
 {
   Volume *v = FindVolume(iv);
   if(!v)
@@ -1422,7 +1389,7 @@ int recognize_surfloop(List_T *liste, int *loop)
 
 // Linear applications
 
-void SetTranslationMatrix(double matrix[4][4], double T[3])
+static void SetTranslationMatrix(double matrix[4][4], double T[3])
 {
   int i, j;
 
@@ -1435,8 +1402,8 @@ void SetTranslationMatrix(double matrix[4][4], double T[3])
     matrix[i][3] = T[i];
 }
 
-void SetSymmetryMatrix(double matrix[4][4], double A, double B, double C,
-                       double D)
+static void SetSymmetryMatrix(double matrix[4][4], double A, double B, double C,
+			      double D)
 {
   double F = -2.0 / (A * A + B * B + C * C);
   matrix[0][0] = 1. + A * A * F;
@@ -1457,7 +1424,7 @@ void SetSymmetryMatrix(double matrix[4][4], double A, double B, double C,
   matrix[3][3] = 1.0;
 }
 
-void SetDilatationMatrix(double matrix[4][4], double T[3], double A)
+static void SetDilatationMatrix(double matrix[4][4], double T[3], double A)
 {
   matrix[0][0] = A;
   matrix[0][1] = 0.0;
@@ -1490,7 +1457,7 @@ static void GramSchmidt(double v1[3], double v2[3], double v3[3])
   norme(v3);
 }
 
-void SetRotationMatrix(double matrix[4][4], double Axe[3], double alpha)
+static void SetRotationMatrix(double matrix[4][4], double Axe[3], double alpha)
 {
   double t1[3], t2[3];
   if(Axe[0] != 0.0) {
@@ -1570,7 +1537,7 @@ static void vecmat4x4(double mat[4][4], double vec[4], double res[4])
   }
 }
 
-void printCurve(Curve *c)
+static void printCurve(Curve *c)
 {
   Vertex *v;
   int N = List_Nbr(c->Control_Points);
@@ -1582,7 +1549,7 @@ void printCurve(Curve *c)
   }
 }
 
-void printSurface(Surface *s)
+static void printSurface(Surface *s)
 {
   Curve *c;
   int N = List_Nbr(s->Generatrices);
@@ -1594,8 +1561,8 @@ void printSurface(Surface *s)
   }
 }
 
-void ApplyTransformationToPoint(double matrix[4][4], Vertex *v,
-                                bool end_curve_surface=false)
+static void ApplyTransformationToPoint(double matrix[4][4], Vertex *v,
+				       bool end_curve_surface=false)
 {
   double pos[4], vec[4];
 
@@ -1641,7 +1608,7 @@ void ApplyTransformationToPoint(double matrix[4][4], Vertex *v,
   }
 }
 
-void ApplyTransformationToCurve(double matrix[4][4], Curve *c)
+static void ApplyTransformationToCurve(double matrix[4][4], Curve *c)
 {
   if(!c->beg || !c->end){
     Msg::Error("Cannot transform curve with no begin/end points");
@@ -1659,7 +1626,7 @@ void ApplyTransformationToCurve(double matrix[4][4], Curve *c)
   End_Curve(c);
 }
 
-void ApplyTransformationToSurface(double matrix[4][4], Surface *s)
+static void ApplyTransformationToSurface(double matrix[4][4], Surface *s)
 {
   for(int i = 0; i < List_Nbr(s->Generatrices); i++) {
     Curve *c;
@@ -1670,7 +1637,7 @@ void ApplyTransformationToSurface(double matrix[4][4], Surface *s)
   End_Surface(s);
 }
 
-void ApplyTransformationToVolume(double matrix[4][4], Volume *v)
+static void ApplyTransformationToVolume(double matrix[4][4], Volume *v)
 {
   for(int i = 0; i < List_Nbr(v->Surfaces); i++) {
     Surface *s;
@@ -1679,7 +1646,7 @@ void ApplyTransformationToVolume(double matrix[4][4], Volume *v)
   }
 }
 
-void ApplicationOnShapes(double matrix[4][4], List_T *shapes)
+static void ApplicationOnShapes(double matrix[4][4], List_T *shapes)
 {
   Vertex *v;
   Curve *c;
@@ -1927,12 +1894,12 @@ void ProtudeXYZ(double &x, double &y, double &z, ExtrudeParams *e)
   List_Reset(ListOfTransformedPoints);
 }
 
-int Extrude_ProtudePoint(int type, int ip,
-                         double T0, double T1, double T2,
-                         double A0, double A1, double A2,
-                         double X0, double X1, double X2, double alpha,
-                         Curve **pc, Curve **prc, int final, 
-                         ExtrudeParams *e)
+static int Extrude_ProtudePoint(int type, int ip,
+				double T0, double T1, double T2,
+				double A0, double A1, double A2,
+				double X0, double X1, double X2, double alpha,
+				Curve **pc, Curve **prc, int final, 
+				ExtrudeParams *e)
 {
   double matrix[4][4], T[3], Ax[3], d;
   Vertex V, *pv, *newp, *chapeau;
@@ -2091,12 +2058,12 @@ int Extrude_ProtudePoint(int type, int ip,
   return chapeau->Num;
 }
 
-int Extrude_ProtudeCurve(int type, int ic,
-                         double T0, double T1, double T2,
-                         double A0, double A1, double A2,
-                         double X0, double X1, double X2, double alpha,
-                         Surface **ps, int final, 
-                         ExtrudeParams *e)
+static int Extrude_ProtudeCurve(int type, int ic,
+				double T0, double T1, double T2,
+				double A0, double A1, double A2,
+				double X0, double X1, double X2, double alpha,
+				Surface **ps, int final, 
+				ExtrudeParams *e)
 {
   double matrix[4][4], T[3], Ax[3];
   Curve *CurveBeg, *CurveEnd;
@@ -2251,11 +2218,11 @@ int Extrude_ProtudeCurve(int type, int ic,
   return chapeau->Num;
 }
 
-int Extrude_ProtudeSurface(int type, int is,
-                           double T0, double T1, double T2,
-                           double A0, double A1, double A2,
-                           double X0, double X1, double X2, double alpha,
-                           Volume **pv, ExtrudeParams *e)
+static int Extrude_ProtudeSurface(int type, int is,
+				  double T0, double T1, double T2,
+				  double A0, double A1, double A2,
+				  double X0, double X1, double X2, double alpha,
+				  Volume **pv, ExtrudeParams *e)
 {
   double matrix[4][4], T[3], Ax[3];
   Curve *c, *c2;
@@ -2554,7 +2521,7 @@ void ExtrudeShapes(int type, List_T *list_in,
 
 // Duplicate removal
 
-int compareTwoPoints(const void *a, const void *b)
+static int compareTwoPoints(const void *a, const void *b)
 {
   Vertex *q = *(Vertex **)a;
   Vertex *w = *(Vertex **)b;
@@ -2564,7 +2531,7 @@ int compareTwoPoints(const void *a, const void *b)
   return comparePosition(a, b);
 }
 
-int compareTwoCurves(const void *a, const void *b)
+static int compareTwoCurves(const void *a, const void *b)
 {
   Curve *c1 = *(Curve **)a;
   Curve *c2 = *(Curve **)b;
@@ -2610,7 +2577,7 @@ int compareTwoCurves(const void *a, const void *b)
   return 0;
 }
 
-int compareTwoSurfaces(const void *a, const void *b)
+static int compareTwoSurfaces(const void *a, const void *b)
 {
   Surface *s1 = *(Surface **)a;
   Surface *s2 = *(Surface **)b;
@@ -2630,28 +2597,28 @@ int compareTwoSurfaces(const void *a, const void *b)
   return compare2Lists(s1->Generatrices, s2->Generatrices, compareAbsCurve);
 }
 
-void MaxNumPoint(void *a, void *b)
+static void MaxNumPoint(void *a, void *b)
 {
   Vertex *v = *(Vertex **)a;
   GModel::current()->getGEOInternals()->MaxPointNum = 
-    MAX(GModel::current()->getGEOInternals()->MaxPointNum, v->Num);
+    std::max(GModel::current()->getGEOInternals()->MaxPointNum, v->Num);
 }
 
-void MaxNumCurve(void *a, void *b)
+static void MaxNumCurve(void *a, void *b)
 {
   Curve *c = *(Curve **)a;
   GModel::current()->getGEOInternals()->MaxLineNum = 
-    MAX(GModel::current()->getGEOInternals()->MaxLineNum, c->Num);
+    std::max(GModel::current()->getGEOInternals()->MaxLineNum, c->Num);
 }
 
-void MaxNumSurface(void *a, void *b)
+static void MaxNumSurface(void *a, void *b)
 {
   Surface *s = *(Surface **)a;
   GModel::current()->getGEOInternals()->MaxSurfaceNum =
-    MAX(GModel::current()->getGEOInternals()->MaxSurfaceNum, s->Num);
+    std::max(GModel::current()->getGEOInternals()->MaxSurfaceNum, s->Num);
 }
 
-void ReplaceDuplicatePoints()
+static void ReplaceDuplicatePoints()
 {
   List_T *All;
   Tree_T *allNonDuplicatedPoints;
@@ -2754,7 +2721,7 @@ void ReplaceDuplicatePoints()
   List_Delete(points2delete);
 }
 
-void ReplaceDuplicateCurves()
+static void ReplaceDuplicateCurves()
 {
   List_T *All;
   Tree_T *allNonDuplicatedCurves;
@@ -2828,7 +2795,7 @@ void ReplaceDuplicateCurves()
   Tree_Delete(allNonDuplicatedCurves);
 }
 
-void ReplaceDuplicateSurfaces()
+static void ReplaceDuplicateSurfaces()
 {
   List_T *All;
   Tree_T *allNonDuplicatedSurfaces;
@@ -2901,7 +2868,7 @@ static Curve *CURVE;
 static Surface *SURFACE;
 static Vertex *VERTEX;
 
-double min1d(double (*funct) (double), double *xmin)
+static double min1d(double (*funct) (double), double *xmin)
 {
   // we should think about the tolerance more carefully...
   double ax = 1.e-15, bx = 1.e-12, cx = 1.e-11, fa, fb, fx, tol = 1.e-4;
@@ -2934,9 +2901,9 @@ static double projectPC(double u)
   if(u < CURVE->ubeg)
     u = CURVE->ubeg;
   Vertex c = InterpolateCurve(CURVE, u, 0);
-  return sqrt(DSQR(c.Pos.X - VERTEX->Pos.X) +
-              DSQR(c.Pos.Y - VERTEX->Pos.Y) + 
-              DSQR(c.Pos.Z - VERTEX->Pos.Z));
+  return sqrt(SQU(c.Pos.X - VERTEX->Pos.X) +
+              SQU(c.Pos.Y - VERTEX->Pos.Y) + 
+              SQU(c.Pos.Z - VERTEX->Pos.Z));
 }
 
 bool ProjectPointOnCurve(Curve *c, Vertex *v, Vertex *RES, Vertex *DER)
@@ -2983,16 +2950,6 @@ bool ProjectPointOnSurface(Surface *s, Vertex &p, double u[2])
   return true;
 }
 
-void Projette(Vertex *v, double mat[3][3])
-{
-  double X = v->Pos.X * mat[0][0] + v->Pos.Y * mat[0][1] + v->Pos.Z * mat[0][2];
-  double Y = v->Pos.X * mat[1][0] + v->Pos.Y * mat[1][1] + v->Pos.Z * mat[1][2];
-  double Z = v->Pos.X * mat[2][0] + v->Pos.Y * mat[2][1] + v->Pos.Z * mat[2][2];
-  v->Pos.X = X;
-  v->Pos.Y = Y;
-  v->Pos.Z = Z;
-}
-
 // Intersect a curve with a surface
 
 static void intersectCS(int N, double x[], double res[])
@@ -3005,7 +2962,7 @@ static void intersectCS(int N, double x[], double res[])
   res[3] = s.Pos.Z - c.Pos.Z;
 }
 
-bool IntersectCurveSurface(Curve *c, Surface *s, double x[4])
+static bool IntersectCurveSurface(Curve *c, Surface *s, double x[4])
 {
   int check;
   SURFACE = s;
@@ -3224,3 +3181,37 @@ void setVolumeSurfaces(Volume *v, List_T *loops)
     }
   }
 }
+
+// GEO_Internals routines
+
+void GEO_Internals::alloc_all()
+{
+  MaxPointNum = MaxLineNum = MaxLineLoopNum = MaxSurfaceNum = 0;
+  MaxSurfaceLoopNum = MaxVolumeNum = MaxPhysicalNum = 0;
+  Points = Tree_Create(sizeof(Vertex *), compareVertex);
+  Curves = Tree_Create(sizeof(Curve *), compareCurve);
+  EdgeLoops = Tree_Create(sizeof(EdgeLoop *), compareEdgeLoop);
+  Surfaces = Tree_Create(sizeof(Surface *), compareSurface);
+  SurfaceLoops = Tree_Create(sizeof(SurfaceLoop *), compareSurfaceLoop);
+  Volumes = Tree_Create(sizeof(Volume *), compareVolume);
+  PhysicalGroups = List_Create(5, 5, sizeof(PhysicalGroup *));
+}
+
+void GEO_Internals::free_all()
+{
+  MaxPointNum = MaxLineNum = MaxLineLoopNum = MaxSurfaceNum = 0;
+  MaxSurfaceLoopNum = MaxVolumeNum = MaxPhysicalNum = 0;
+  Tree_Action(Points, Free_Vertex); Tree_Delete(Points);
+  Tree_Action(Curves, Free_Curve); Tree_Delete(Curves);
+  Tree_Action(EdgeLoops, Free_EdgeLoop); Tree_Delete(EdgeLoops);
+  Tree_Action(Surfaces, Free_Surface); Tree_Delete(Surfaces);
+  Tree_Action(SurfaceLoops, Free_SurfaceLoop); Tree_Delete(SurfaceLoops);
+  Tree_Action(Volumes, Free_Volume); Tree_Delete(Volumes);
+  List_Action(PhysicalGroups, Free_PhysicalGroup); List_Delete(PhysicalGroups);
+}
+
+void GEO_Internals::reset_physicals()
+{
+  List_Action(PhysicalGroups, Free_PhysicalGroup); 
+  List_Reset(PhysicalGroups);
+}
