@@ -1,25 +1,11 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _GEO_H_
 #define _GEO_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include <map>
 #include <math.h>
 #include "GmshDefines.h"
@@ -215,6 +201,7 @@ class GEO_Internals{
   GEO_Internals(){ alloc_all(); }
   ~GEO_Internals(){ free_all(); }
   void destroy(){ free_all(); alloc_all(); }
+  void reset_physicals();
 };
 
 typedef struct {
@@ -222,14 +209,9 @@ typedef struct {
   int Num;
 } Shape;
 
-int comparePosition(const void *a, const void *b);
 int compareVertex(const void *a, const void *b);
-int compareCurve(const void *a, const void *b);
-int compareEdgeLoop(const void *a, const void *b);
-int compareSurface(const void *a, const void *b);
-int compareSurfaceLoop(const void *a, const void *b);
-int compareVolume(const void *a, const void *b);
-int comparePhysicalGroup(const void *a, const void *b);
+
+void Projette(Vertex * v, double mat[3][3]);
 
 Vertex *Create_Vertex(int Num, double X, double Y, double Z, double lc, double u);
 Vertex *Create_Vertex(int Num, double u, double v, gmshSurface *s, double lc);
@@ -245,14 +227,6 @@ PhysicalGroup *Create_PhysicalGroup(int Num, int typ, List_T * intlist);
 void End_Curve(Curve * c);
 void End_Surface(Surface * s);
 
-void Free_Vertex (void *a, void *b);
-void Free_Curve(void *a, void *b);
-void Free_EdgeLoop(void *a, void *b);
-void Free_Surface(void *a, void *b);
-void Free_SurfaceLoop(void *a, void *b);
-void Free_Volume(void *a, void *b);
-void Free_PhysicalGroup(void *a, void *b);
-
 int NEWPOINT(void);
 int NEWLINE(void);
 int NEWLINELOOP(void);
@@ -308,8 +282,6 @@ int recognize_seg(int typ, List_T *liste, int *seg);
 int recognize_loop(List_T *liste, int *loop);
 int recognize_surfloop(List_T *liste, int *loop);
 
-void Projette(Vertex * v, double mat[3][3]);
-
 void sortEdgesInLoop(int num, List_T *edges);
 void setSurfaceGeneratrices(Surface *s, List_T *loops);
 void setVolumeSurfaces(Volume *v, List_T * loops);
