@@ -1,23 +1,7 @@
-// $Id: GeoInterpolation.cpp,v 1.37 2008-06-10 12:59:12 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "Message.h"
 #include "Geo.h"
@@ -25,10 +9,12 @@
 #include "GeoStringInterface.h"
 #include "Numeric.h"
 
+#define SQU(a)      ((a)*(a))
+
 // Curves
 
-Vertex InterpolateCubicSpline(Vertex *v[4], double t, double mat[4][4],
-                              int derivee, double t1, double t2)
+static Vertex InterpolateCubicSpline(Vertex *v[4], double t, double mat[4][4],
+				     int derivee, double t1, double t2)
 {
   Vertex V;
   int i, j;
@@ -101,14 +87,12 @@ Vertex InterpolateCubicSpline(Vertex *v[4], double t, double mat[4][4],
 
 // interpolation in the parametric space !
 SPoint2 InterpolateCubicSpline(Vertex *v[4], double t, double mat[4][4],
-                              int derivee, double t1, double t2, gmshSurface *s)
+			       double t1, double t2, gmshSurface *s)
 {
   Vertex V;
   int i, j;
   double T[4];
 
-  if(derivee) throw;
-
   T[3] = 1.;
   T[2] = t;
   T[1] = t * t;
@@ -129,7 +113,7 @@ SPoint2 InterpolateCubicSpline(Vertex *v[4], double t, double mat[4][4],
 }
 
 // Uniform BSplines
-Vertex InterpolateUBS(Curve *Curve, double u, int derivee) 
+static Vertex InterpolateUBS(Curve *Curve, double u, int derivee) 
 {
   bool periodic = (Curve->end == Curve->beg);
   int NbControlPoints = List_Nbr(Curve->Control_Points);
@@ -148,7 +132,7 @@ Vertex InterpolateUBS(Curve *Curve, double u, int derivee)
   }
 
   if(Curve->geometry){
-    SPoint2 pp = InterpolateCubicSpline(v, t, Curve->mat, 0, t1, t2, Curve->geometry);
+    SPoint2 pp = InterpolateCubicSpline(v, t, Curve->mat, t1, t2, Curve->geometry);
     SPoint3 pt = Curve->geometry->point(pp);
     Vertex V;
     V.Pos.X = pt.x();
@@ -182,7 +166,7 @@ int findSpan(double u, int deg, int n, float *U)
   return mid;
 }
 
-void basisFuns(double u, int i, int deg, float *U, double *N)
+static void basisFuns(double u, int i, int deg, float *U, double *N)
 {
   double left[1000];
   double *right = &left[deg + 1];
@@ -203,7 +187,7 @@ void basisFuns(double u, int i, int deg, float *U, double *N)
   }
 }
 
-Vertex InterpolateNurbs(Curve *Curve, double u, int derivee)
+static Vertex InterpolateNurbs(Curve *Curve, double u, int derivee)
 {
   static double Nb[1000];
   int span = findSpan(u, Curve->degre, List_Nbr(Curve->Control_Points), Curve->k);
@@ -366,7 +350,7 @@ Vertex InterpolateCurve(Curve *c, double u, int derivee)
       List_Read(c->Control_Points, i + 2, &v[3]);
     }
     if(c->geometry){
-      SPoint2 pp = InterpolateCubicSpline(v, t, c->mat, 0, t1, t2,c->geometry);
+      SPoint2 pp = InterpolateCubicSpline(v, t, c->mat, t1, t2,c->geometry);
       SPoint3 pt = c->geometry->point(pp);
       V.Pos.X = pt.x();
       V.Pos.Y = pt.y();
@@ -400,9 +384,9 @@ Vertex InterpolateCurve(Curve *c, double u, int derivee)
 #define TRAN_QUA(c1,c2,c3,c4,s1,s2,s3,s4,u,v) \
    (1.-u)*c4+u*c2+(1.-v)*c1+v*c3-((1.-u)*(1.-v)*s1+u*(1.-v)*s2+u*v*s3+(1.-u)*v*s4)
 
-Vertex TransfiniteQua(Vertex c1, Vertex c2, Vertex c3, Vertex c4,
-                      Vertex s1, Vertex s2, Vertex s3, Vertex s4,
-                      double u, double v)
+static Vertex TransfiniteQua(Vertex c1, Vertex c2, Vertex c3, Vertex c4,
+			     Vertex s1, Vertex s2, Vertex s3, Vertex s4,
+			     double u, double v)
 {
   Vertex V;
 
@@ -423,8 +407,8 @@ Vertex TransfiniteQua(Vertex c1, Vertex c2, Vertex c3, Vertex c4,
 
 #define TRAN_TRI(c1,c2,c3,s1,s2,s3,u,v) u*c2+(1.-v)*c1+v*c3-(u*(1.-v)*s2+u*v*s3);
 
-Vertex TransfiniteTri(Vertex c1, Vertex c2, Vertex c3,
-                      Vertex s1, Vertex s2, Vertex s3, double u, double v)
+static Vertex TransfiniteTri(Vertex c1, Vertex c2, Vertex c3,
+			     Vertex s1, Vertex s2, Vertex s3, double u, double v)
 {
   Vertex V;
   V.lc = TRAN_TRI(c1.lc, c2.lc, c3.lc, s1.lc, s2.lc, s3.lc, u, v);
@@ -438,13 +422,13 @@ Vertex TransfiniteTri(Vertex c1, Vertex c2, Vertex c3,
   return V;
 }
 
-void TransfiniteSph(Vertex S, Vertex center, Vertex *T)
+static void TransfiniteSph(Vertex S, Vertex center, Vertex *T)
 {
-  double r = sqrt(DSQR(S.Pos.X - center.Pos.X) + DSQR(S.Pos.Y - center.Pos.Y)
-                  + DSQR(S.Pos.Z - center.Pos.Z));
+  double r = sqrt(SQU(S.Pos.X - center.Pos.X) + SQU(S.Pos.Y - center.Pos.Y)
+                  + SQU(S.Pos.Z - center.Pos.Z));
 
-  double s = sqrt(DSQR(T->Pos.X - center.Pos.X) + DSQR(T->Pos.Y - center.Pos.Y)
-                  + DSQR(T->Pos.Z - center.Pos.Z));
+  double s = sqrt(SQU(T->Pos.X - center.Pos.X) + SQU(T->Pos.Y - center.Pos.Y)
+                  + SQU(T->Pos.Z - center.Pos.Z));
 
   double dirx = (T->Pos.X - center.Pos.X) / s;
   double diry = (T->Pos.Y - center.Pos.Y) / s;
@@ -455,7 +439,8 @@ void TransfiniteSph(Vertex S, Vertex center, Vertex *T)
   T->Pos.Z = center.Pos.Z + r * dirz;
 }
 
-bool iSRuledSurfaceASphere(Surface *s, SPoint3 &center, double &radius){
+bool iSRuledSurfaceASphere(Surface *s, SPoint3 &center, double &radius)
+{
   if(s->Typ != MSH_SURF_REGL && s->Typ != MSH_SURF_TRIC)return false;
 
   bool isSphere = true;
@@ -503,8 +488,7 @@ bool iSRuledSurfaceASphere(Surface *s, SPoint3 &center, double &radius){
   return isSphere;
 }
 
-
-Vertex InterpolateRuledSurface(Surface *s, double u, double v)
+static Vertex InterpolateRuledSurface(Surface *s, double u, double v)
 {
   Curve *C[4] = {0, 0, 0, 0};
 
@@ -582,7 +566,7 @@ Vertex InterpolateRuledSurface(Surface *s, double u, double v)
   return T;
 }
 
-Vertex InterpolateExtrudedSurface(Surface *s, double u, double v)
+static Vertex InterpolateExtrudedSurface(Surface *s, double u, double v)
 {
   Curve *c = FindCurve(s->Extrude->geo.Source);
 
@@ -660,11 +644,14 @@ Vertex InterpolateSurface(Surface *s, double u, double v, int derivee, int u_v)
     return T;
   }
 
-  // use the exact extrusion formula if the surface is extruded
+  // FIXME: WARNING -- this is a major hack: we use the exact
+  // extrusion formula if the surface is extruded, so that we create
+  // exact surfaces of revolution. But this WILL fail if the extruded
+  // surface is transformed after the extrusion!
   if(s->Extrude && s->Extrude->geo.Mode == EXTRUDED_ENTITY && 
      s->Typ != MSH_SURF_PLAN)
     return InterpolateExtrudedSurface(s, u, v);
-  
+
   switch (s->Typ) {
   case MSH_SURF_REGL:
   case MSH_SURF_TRIC: 
