@@ -1,36 +1,24 @@
-// $Id: GeoStringInterface.cpp,v 1.24 2008-06-19 15:58:41 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <string.h>
 #include <sstream>
 #include "Message.h"
 #include "Numeric.h"
 #include "MallocUtils.h"
+#include "StringUtils.h"
 #include "Geo.h"
 #include "GeoStringInterface.h"
-#include "Parser.h"
 #include "OpenFile.h"
 #include "Context.h"
 #include "GModel.h"
 
+#if !defined(HAVE_NO_PARSER)
+#include "Parser.h"
+#endif
+
 extern Context_T CTX;
 
 #define BUFFSIZE 128000
@@ -38,7 +26,7 @@ extern Context_T CTX;
 // Some old systems don't have snprintf... Just call sprintf instead.
 
 #if defined(HAVE_NO_SNPRINTF)
-int snprintf(char *str, size_t size, const char* fmt, ...)
+static int snprintf(char *str, size_t size, const char* fmt, ...)
 {
   va_list args;
   va_start(args, fmt);
@@ -50,6 +38,10 @@ int snprintf(char *str, size_t size, const char* fmt, ...)
 
 double evaluate_scalarfunction(const char *var, double val, const char *funct)
 {
+#if defined(HAVE_NO_PARSER)
+  Msg::Error("Scalar function evaluation not available without Gmsh parser");
+  return 0.;
+#else
   FILE *tempf;
   tempf = gmsh_yyin;
 
@@ -79,10 +71,14 @@ double evaluate_scalarfunction(const char *var, double val, const char *funct)
   }
   Free(TheSymbol.Name);
   return *(double *)List_Pointer(TheSymbol_P->val, 0);
+#endif
 }
 
 void add_infile(const char *text, const char *fich, bool deleted_something)
 {
+#if defined(HAVE_NO_PARSER)
+  Msg::Error("GEO file creation not available without Gmsh parser");
+#else
   if(!(gmsh_yyin = fopen(CTX.tmp_filename_fullpath, "w"))) {
     Msg::Error("Unable to open temporary file '%s'", CTX.tmp_filename_fullpath);
     return;
@@ -132,6 +128,7 @@ void add_infile(const char *text, const char *fich, bool deleted_something)
 
   fprintf(file, "%s\n", text);
   fclose(file);
+#endif
 }
 
 void coherence(const char *fich)
@@ -139,7 +136,7 @@ void coherence(const char *fich)
   add_infile("Coherence;", fich, true);
 }
 
-void strncat_list(char *text, List_T *list)
+static void strncat_list(char *text, List_T *list)
 {
   char text2[BUFFSIZE];
   for(int i = 0; i < List_Nbr(list); i++){
@@ -243,25 +240,34 @@ void add_point(const char *fich, const char *x, const char *y, const char *z,
   add_infile(text, fich);
 }
 
-void add_field_option(int field_id, const char *option_name, const char *option_value, const char *fich){
-        std::ostringstream sstream;
-        sstream<<"Field["<<field_id<<"]."<<std::string(option_name)<<" = "<<std::string(option_value)<<";";
-        add_infile(sstream.str().c_str(),fich);
+void add_field_option(int field_id, const char *option_name, const char *option_value, 
+		      const char *fich)
+{
+  std::ostringstream sstream;
+  sstream<<"Field["<<field_id<<"]."<<std::string(option_name)<<" = "
+	 <<std::string(option_value)<<";";
+  add_infile(sstream.str().c_str(),fich);
 }
-void add_field(int field_id, const char *type_name, const char *fich){
-        std::ostringstream sstream;
-        sstream<<"Field["<<field_id<<"] = "<<std::string(type_name)<<";";
-        add_infile(sstream.str().c_str(),fich);
+
+void add_field(int field_id, const char *type_name, const char *fich)
+{
+  std::ostringstream sstream;
+  sstream<<"Field["<<field_id<<"] = "<<std::string(type_name)<<";";
+  add_infile(sstream.str().c_str(),fich);
 }
-void delete_field(int field_id, const char *fich){
-        std::ostringstream sstream;
-        sstream<<"Delete Field ["<<field_id<<"];";
-        add_infile(sstream.str().c_str(),fich);
+
+void delete_field(int field_id, const char *fich)
+{
+  std::ostringstream sstream;
+  sstream<<"Delete Field ["<<field_id<<"];";
+  add_infile(sstream.str().c_str(),fich);
 }
-void set_background_field(int field_id,const char *fich){
-        std::ostringstream sstream;
-        sstream<<"Background Field = "<<field_id<<";";
-        add_infile(sstream.str().c_str(),fich);
+
+void set_background_field(int field_id,const char *fich)
+{
+  std::ostringstream sstream;
+  sstream<<"Background Field = "<<field_id<<";";
+  add_infile(sstream.str().c_str(),fich);
 }
 
 void add_line(int p1, int p2, const char *fich)
