@@ -1,23 +1,7 @@
-// $Id: MElement.cpp,v 1.74 2008-06-20 16:25:38 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <stdlib.h>
 #include <math.h>
@@ -36,6 +20,8 @@
 #  include "qualityMeasures.h"
 #endif
 
+#define SQU(a)      ((a)*(a))
+
 extern Context_T CTX;
 
 int MElement::_globalNum = 0;
@@ -105,6 +91,11 @@ double MElement::rhoShapeMeasure()
     return 0.;
 }
 
+void MElement::getIntegrationPoints(int pOrder, int *npts, IntPt **pts) const
+{
+  Msg::Error("No integration points defined for this type of element");
+}
+
 double MTriangle::gammaShapeMeasure()
 {
 #if defined(HAVE_GMSH_EMBEDDED)
@@ -255,9 +246,9 @@ double MElement::getJacobian(double u, double v, double w, double jac[3][3])
       prodve(a, b, c);
       jac[2][0] = c[0]; jac[2][1] = c[1]; jac[2][2] = c[2]; 
     }
-    return sqrt(SQR(jac[0][0] * jac[1][1] - jac[0][1] * jac[1][0]) +
-                SQR(jac[0][2] * jac[1][0] - jac[0][0] * jac[1][2]) +
-                SQR(jac[0][1] * jac[1][2] - jac[0][2] * jac[1][1]));
+    return sqrt(SQU(jac[0][0] * jac[1][1] - jac[0][1] * jac[1][0]) +
+                SQU(jac[0][2] * jac[1][0] - jac[0][0] * jac[1][2]) +
+                SQU(jac[0][1] * jac[1][2] - jac[0][2] * jac[1][1]));
   case 1:
     for(int i = 0; i < getNumVertices(); i++) {
       getGradShapeFunction(i, u, v, w, s);
@@ -280,7 +271,7 @@ double MElement::getJacobian(double u, double v, double w, double jac[3][3])
       jac[1][0] = b[0]; jac[1][1] = b[1]; jac[1][2] = b[2]; 
       jac[2][0] = c[0]; jac[2][1] = c[1]; jac[2][2] = c[2]; 
     }
-    return sqrt(SQR(jac[0][0]) + SQR(jac[0][1]) + SQR(jac[0][2]));
+    return sqrt(SQU(jac[0][0]) + SQU(jac[0][1]) + SQU(jac[0][2]));
   default:
     return 1.;
   }
@@ -315,7 +306,7 @@ void MElement::xyz2uvw(double xyz[3], double uvw[3])
       inv[0][1] * (xyz[0] - xn) + inv[1][1] * (xyz[1] - yn) + inv[2][1] * (xyz[2] - zn) ;
     double wn = uvw[2] +
       inv[0][2] * (xyz[0] - xn) + inv[1][2] * (xyz[1] - yn) + inv[2][2] * (xyz[2] - zn) ;
-    error = sqrt(SQR(un - uvw[0]) + SQR(vn - uvw[1]) + SQR(wn - uvw[2]));
+    error = sqrt(SQU(un - uvw[0]) + SQU(vn - uvw[1]) + SQU(wn - uvw[2]));
     uvw[0] = un;
     uvw[1] = vn;
     uvw[2] = wn;
@@ -411,7 +402,7 @@ void MElement::writeMSH(FILE *fp, double version, bool binary, int num,
 
   if(physical < 0) revert();
 
-  int verts[30];
+  int verts[60];
   for(int i = 0; i < n; i++)
     verts[i] = getVertex(i)->getIndex();
 
@@ -546,7 +537,7 @@ void MElement::writeVTK(FILE *fp, bool binary)
 
   int n = getNumVertices();
   if(binary){
-    int verts[30];
+    int verts[60];
     verts[0] = n;
     for(int i = 0; i < n; i++)
       verts[i + 1] = getVertexVTK(i)->getIndex() - 1;
@@ -633,11 +624,10 @@ void MElement::writeBDF(FILE *fp, int format, int elementary)
   }
 }
 
-void MTriangle::jac(int ord, MVertex *vs[], double uu, double vv, double ww, double j[2][3])
+void MTriangle::jac(int ord, MVertex *vs[], double uu, double vv, double ww,
+		    double j[2][3])
 {
-#if defined(HAVE_GMSH_EMBEDDED)
-  return;
-#else
+#if !defined(HAVE_GMSH_EMBEDDED)
   double grads[256][2];
   int nf = getNumFaceVertices();
 
@@ -647,18 +637,18 @@ void MTriangle::jac(int ord, MVertex *vs[], double uu, double vv, double ww, dou
     case 2: gmshFunctionSpaces::find(MSH_TRI_6).df(uu, vv, ww, grads); break;
     case 3: gmshFunctionSpaces::find(MSH_TRI_9).df(uu, vv, ww, grads); break;
     case 4: gmshFunctionSpaces::find(MSH_TRI_12).df(uu, vv, ww, grads); break;
-    case 5: gmshFunctionSpaces::find(MSH_TRI_15I).df(uu, vv,ww, grads); break;
-    default: throw;
+    case 5: gmshFunctionSpaces::find(MSH_TRI_15I).df(uu, vv, ww, grads); break;
+    default: Msg::Error("Order %d triangle jac not implemented", ord); break;
     }
   }
   else{
     switch(ord){
-    case 1: gmshFunctionSpaces::find(MSH_TRI_3).df(uu, vv, ww,grads); break;
-    case 2: gmshFunctionSpaces::find(MSH_TRI_6).df(uu, vv, ww,grads); break;
-    case 3: gmshFunctionSpaces::find(MSH_TRI_10).df(uu, vv, ww,grads); break;
-    case 4: gmshFunctionSpaces::find(MSH_TRI_15).df(uu, vv, ww,grads); break;
-    case 5: gmshFunctionSpaces::find(MSH_TRI_21).df(uu, vv, ww,grads); break;
-    default: throw;
+    case 1: gmshFunctionSpaces::find(MSH_TRI_3).df(uu, vv, ww, grads); break;
+    case 2: gmshFunctionSpaces::find(MSH_TRI_6).df(uu, vv, ww, grads); break;
+    case 3: gmshFunctionSpaces::find(MSH_TRI_10).df(uu, vv, ww, grads); break;
+    case 4: gmshFunctionSpaces::find(MSH_TRI_15).df(uu, vv, ww, grads); break;
+    case 5: gmshFunctionSpaces::find(MSH_TRI_21).df(uu, vv, ww, grads); break;
+    default: Msg::Error("Order %d triangle jac not implemented", ord); break;
     }
   }
   j[0][0] = 0 ; for(int i = 0; i < 3; i++) j[0][0] += grads [i][0] * _v[i]->x();
@@ -679,7 +669,8 @@ void MTriangle::jac(int ord, MVertex *vs[], double uu, double vv, double ww, dou
 #endif
 }
 
-void MTriangle::pnt(int ord, MVertex *vs[], double uu, double vv, double ww, SPoint3 &p)
+void MTriangle::pnt(int ord, MVertex *vs[], double uu, double vv, double ww,
+		    SPoint3 &p)
 {
 #if !defined(HAVE_GMSH_EMBEDDED)
   double sf[256];
@@ -687,25 +678,25 @@ void MTriangle::pnt(int ord, MVertex *vs[], double uu, double vv, double ww, SPo
 
   if (!nf){
     switch(ord){
-    case 1: gmshFunctionSpaces::find(MSH_TRI_3).f(uu, vv, ww,sf); break;
-    case 2: gmshFunctionSpaces::find(MSH_TRI_6).f(uu, vv, ww,sf); break;
-    case 3: gmshFunctionSpaces::find(MSH_TRI_9).f(uu, vv, ww,sf); break;
-    case 4: gmshFunctionSpaces::find(MSH_TRI_12).f(uu, vv, ww,sf); break;
-    case 5: gmshFunctionSpaces::find(MSH_TRI_15I).f(uu, vv, ww,sf); break;
-    default: throw;
+    case 1: gmshFunctionSpaces::find(MSH_TRI_3).f(uu, vv, sf); break;
+    case 2: gmshFunctionSpaces::find(MSH_TRI_6).f(uu, vv, sf); break;
+    case 3: gmshFunctionSpaces::find(MSH_TRI_9).f(uu, vv, sf); break;
+    case 4: gmshFunctionSpaces::find(MSH_TRI_12).f(uu, vv, sf); break;
+    case 5: gmshFunctionSpaces::find(MSH_TRI_15I).f(uu, vv, sf); break;
+    default: Msg::Error("Order %d triangle pnt not implemented", ord); break;
     }
   }
   else{
     switch(ord){
-    case 1: gmshFunctionSpaces::find(MSH_TRI_3).f(uu, vv, ww,sf); break;
-    case 2: gmshFunctionSpaces::find(MSH_TRI_6).f(uu, vv, ww,sf); break;
-    case 3: gmshFunctionSpaces::find(MSH_TRI_10).f(uu, vv, ww,sf); break;
-    case 4: gmshFunctionSpaces::find(MSH_TRI_15).f(uu, vv, ww,sf); break;
-    case 5: gmshFunctionSpaces::find(MSH_TRI_21).f(uu, vv, ww,sf); break;
-    default: throw;
+    case 1: gmshFunctionSpaces::find(MSH_TRI_3).f(uu, vv, sf); break;
+    case 2: gmshFunctionSpaces::find(MSH_TRI_6).f(uu, vv, sf); break;
+    case 3: gmshFunctionSpaces::find(MSH_TRI_10).f(uu, vv, sf); break;
+    case 4: gmshFunctionSpaces::find(MSH_TRI_15).f(uu, vv, sf); break;
+    case 5: gmshFunctionSpaces::find(MSH_TRI_21).f(uu, vv, sf); break;
+    default: Msg::Error("Order %d triangle pnt not implemented", ord); break;
     }
   }
-  
+
   double x = 0 ; for(int i = 0; i < 3; i++) x += sf[i] * _v[i]->x();
   double y = 0 ; for(int i = 0; i < 3; i++) y += sf[i] * _v[i]->y();
   double z = 0 ; for(int i = 0; i < 3; i++) z += sf[i] * _v[i]->z();
@@ -718,17 +709,74 @@ void MTriangle::pnt(int ord, MVertex *vs[], double uu, double vv, double ww, SPo
 #endif
 }
 
-void MTetrahedron::pnt(int ord, MVertex *vs[], double uu, double vv, double ww,SPoint3 &p)
+void MTetrahedron::jac(int ord, MVertex *vs[], double uu, double vv, double ww,
+		       double j[3][3])
+{
+#if !defined(HAVE_GMSH_EMBEDDED)
+  double grads[256][3];
+  switch(ord){
+  case 1: gmshFunctionSpaces::find(MSH_TET_4) .df(uu, vv, ww, grads); break;
+  case 2: gmshFunctionSpaces::find(MSH_TET_10).df(uu, vv, ww, grads); break;
+  case 3: gmshFunctionSpaces::find(MSH_TET_20).df(uu, vv, ww, grads); break;
+  case 4: gmshFunctionSpaces::find(MSH_TET_35).df(uu, vv, ww, grads); break;
+  case 5: gmshFunctionSpaces::find(MSH_TET_56).df(uu, vv, ww, grads); break;
+  default: Msg::Error("Order %d tetrahedron jac not implemented", ord); break;
+  }
+ 
+  j[0][0] = 0 ; for(int i = 0; i < 4; i++) j[0][0] += grads [i][0] * _v[i]->x();
+  j[1][0] = 0 ; for(int i = 0; i < 4; i++) j[1][0] += grads [i][1] * _v[i]->x();
+  j[2][0] = 0 ; for(int i = 0; i < 4; i++) j[2][0] += grads [i][2] * _v[i]->x();
+  
+  j[0][1] = 0 ; for(int i = 0; i < 4; i++) j[0][1] += grads [i][0] * _v[i]->y();
+  j[1][1] = 0 ; for(int i = 0; i < 4; i++) j[1][1] += grads [i][1] * _v[i]->y();
+  j[2][1] = 0 ; for(int i = 0; i < 4; i++) j[2][1] += grads [i][2] * _v[i]->y();
+  
+  j[0][2] = 0 ; for(int i = 0; i < 4; i++) j[0][2] += grads [i][0] * _v[i]->z();
+  j[1][2] = 0 ; for(int i = 0; i < 4; i++) j[1][2] += grads [i][1] * _v[i]->z();
+  j[2][2] = 0 ; for(int i = 0; i < 4; i++) j[2][2] += grads [i][2] * _v[i]->z();
+  
+  if (ord == 1) return;
+
+  const int N = (ord+1)*(ord+2)*(ord+3)/6;
+
+  for(int i = 4; i < N; i++) j[0][0] += grads[i][0] * vs[i - 4]->x();
+  for(int i = 4; i < N; i++) j[1][0] += grads[i][1] * vs[i - 4]->x();
+  for(int i = 4; i < N; i++) j[2][0] += grads[i][2] * vs[i - 4]->x();
+
+  for(int i = 4; i < N; i++) j[0][1] += grads[i][0] * vs[i - 4]->y();
+  for(int i = 4; i < N; i++) j[1][1] += grads[i][1] * vs[i - 4]->y();
+  for(int i = 4; i < N; i++) j[2][1] += grads[i][2] * vs[i - 4]->y();
+
+  for(int i = 4; i < N; i++) j[0][2] += grads[i][0] * vs[i - 4]->z();
+  for(int i = 4; i < N; i++) j[1][2] += grads[i][1] * vs[i - 4]->z();
+  for(int i = 4; i < N; i++) j[2][2] += grads[i][2] * vs[i - 4]->z();
+#endif
+}
+
+void MTetrahedron::pnt(int ord, MVertex *vs[], double uu, double vv, double ww,
+		       SPoint3 &p)
 {
 #if !defined(HAVE_GMSH_EMBEDDED)
   double sf[256];
-  switch(ord){
-  case 1: gmshFunctionSpaces::find(MSH_TET_4).f(uu, vv, ww,sf); break;
-  case 2: gmshFunctionSpaces::find(MSH_TET_10).f(uu, vv, ww,sf); break;
-  case 3: gmshFunctionSpaces::find(MSH_TET_20).f(uu, vv, ww,sf); break;
-  case 4: gmshFunctionSpaces::find(MSH_TET_35).f(uu, vv, ww,sf); break;
-  case 5: gmshFunctionSpaces::find(MSH_TET_56).f(uu, vv, ww,sf); break;
-  default : throw;
+
+  int nv = getNumVolumeVertices();
+
+  if (!nv){
+    switch(ord){
+    case 1: gmshFunctionSpaces::find(MSH_TET_4).f(uu, vv, ww, sf); break;
+    case 2: gmshFunctionSpaces::find(MSH_TET_10).f(uu, vv, ww, sf); break;
+    case 3: gmshFunctionSpaces::find(MSH_TET_20).f(uu, vv, ww, sf); break;
+    case 4: gmshFunctionSpaces::find(MSH_TET_34).f(uu, vv, ww, sf); break;
+    case 5: gmshFunctionSpaces::find(MSH_TET_52).f(uu, vv, ww, sf); break;
+    default: Msg::Error("Order %d tetrahedron pnt not implemented", ord); break;
+    }
+  }
+  else{
+    switch(ord){
+    case 4: gmshFunctionSpaces::find(MSH_TET_35).f(uu, vv, ww, sf); break;
+    case 5: gmshFunctionSpaces::find(MSH_TET_56).f(uu, vv, ww, sf); break;
+    default: Msg::Error("Order %d tetrahedron pnt not implemented", ord); break;
+    }
   }
     
   double x = 0 ; for(int i = 0; i < 4; i++) x += sf[i] * _v[i]->x();
@@ -736,123 +784,79 @@ void MTetrahedron::pnt(int ord, MVertex *vs[], double uu, double vv, double ww,S
   double z = 0 ; for(int i = 0; i < 4; i++) z += sf[i] * _v[i]->z();
 
   const int N = (ord+1)*(ord+2)*(ord+3)/6;
-
-  for(int i = 4; i < N+4; i++) x += sf[i] * vs[i - 4]->x();
-  for(int i = 4; i < N+4; i++) y += sf[i] * vs[i - 4]->y();
-  for(int i = 4; i < N+4; i++) z += sf[i] * vs[i - 4]->z();
+  
+  
+  for(int i = 4; i < N; i++) x += sf[i] * vs[i - 4]->x();
+  for(int i = 4; i < N; i++) y += sf[i] * vs[i - 4]->y();
+  for(int i = 4; i < N; i++) z += sf[i] * vs[i - 4]->z();
 
   p = SPoint3(x,y,z);
 #endif
 }
 
-void MTetrahedron::jac(int ord, MVertex *vs[], double uu, double vv, double ww, double j[3][3])
-{
-#if defined(HAVE_GMSH_EMBEDDED)
-  return;
-#else
-  double grads[256][2];
-  switch(ord){
-  case 1: gmshFunctionSpaces::find(MSH_TET_4).df(uu, vv, ww,grads); break;
-  case 2: gmshFunctionSpaces::find(MSH_TET_10).df(uu, vv, ww, grads); break;
-  case 3: gmshFunctionSpaces::find(MSH_TET_20).df(uu, vv, ww, grads); break;
-  case 4: gmshFunctionSpaces::find(MSH_TET_35).df(uu, vv, ww, grads); break;
-  case 5: gmshFunctionSpaces::find(MSH_TET_56).df(uu, vv, ww, grads); break;
-  default: throw;
-  }
- 
-  j[0][0] = 0 ; for(int i = 0; i < 3; i++) j[0][0] += grads [i][0] * _v[i]->x();
-  j[1][0] = 0 ; for(int i = 0; i < 3; i++) j[1][0] += grads [i][1] * _v[i]->x();
-  j[2][0] = 0 ; for(int i = 0; i < 3; i++) j[2][0] += grads [i][2] * _v[i]->x();
-  j[0][1] = 0 ; for(int i = 0; i < 3; i++) j[0][1] += grads [i][0] * _v[i]->y();
-  j[1][1] = 0 ; for(int i = 0; i < 3; i++) j[1][1] += grads [i][1] * _v[i]->y();
-  j[2][1] = 0 ; for(int i = 0; i < 3; i++) j[2][1] += grads [i][2] * _v[i]->y();
-  j[0][2] = 0 ; for(int i = 0; i < 3; i++) j[0][2] += grads [i][0] * _v[i]->z();
-  j[1][2] = 0 ; for(int i = 0; i < 3; i++) j[1][2] += grads [i][1] * _v[i]->z();
-  j[2][2] = 0 ; for(int i = 0; i < 3; i++) j[2][2] += grads [i][2] * _v[i]->z();
-  
-  if (ord == 1) return;
-
-  const int N = (ord+1)*(ord+2)*(ord+3)/6;
-
-  for(int i = 3; i < N+4; i++) j[0][0] += grads[i][0] * vs[i - 4]->x();
-  for(int i = 3; i < N+4; i++) j[1][0] += grads[i][1] * vs[i - 4]->x();
-  for(int i = 3; i < N+4; i++) j[2][0] += grads[i][2] * vs[i - 4]->x();
-
-  for(int i = 3; i < N+4; i++) j[0][1] += grads[i][0] * vs[i - 4]->y();
-  for(int i = 3; i < N+4; i++) j[1][1] += grads[i][1] * vs[i - 4]->y();
-  for(int i = 3; i < N+4; i++) j[2][1] += grads[i][2] * vs[i - 4]->y();
-
-  for(int i = 3; i < N+4; i++) j[0][2] += grads[i][0] * vs[i - 4]->z();
-  for(int i = 3; i < N+4; i++) j[1][2] += grads[i][1] * vs[i - 4]->z();
-  for(int i = 3; i < N+4; i++) j[2][2] += grads[i][2] * vs[i - 4]->z();
-#endif
-}
-
-const int numSubEdges = 12;
+const int numSubEdges = 6;
 
 int MTriangleN::getNumFacesRep(){ return numSubEdges * numSubEdges; }
 
-void MTriangleN::getFaceRep(int num, double *x, double *y, double *z, SVector3 *n){
-
+void MTriangleN::getFaceRep(int num, double *x, double *y, double *z, SVector3 *n)
+{
   //  on the first layer, we have (numSubEdges-1) * 2 + 1 triangles
   //  on the second layer, we have (numSubEdges-2) * 2 + 1 triangles
   //  on the ith layer, we have (numSubEdges-1-i) * 2 + 1 triangles
-
   int ix, iy;
   int nbt = 0;
-  for (int i=0;i<numSubEdges;i++){
-    int nbl = (numSubEdges-i-1)*2 + 1;
+  for (int i = 0; i < numSubEdges; i++){
+    int nbl = (numSubEdges - i - 1) * 2 + 1;
     nbt += nbl;
     if (nbt > num){
       iy = i;
-      ix = nbl-(nbt-num);
+      ix = nbl - (nbt - num);
       break;
     }
   }
 
-  const double d = 1./numSubEdges;
+  const double d = 1. / numSubEdges;
 
   SPoint3 pnt1, pnt2, pnt3;
-  double J1[2][3],J2[2][3],J3[2][3];
-  if (ix %2 == 0){
-    pnt(ix/2*d, iy*d, 0,pnt1);
-    pnt((ix/2+1)*d, iy*d, 0,pnt2);
-    pnt(ix/2*d, (iy+1)*d, 0,pnt3);
-    jac(ix/2*d, iy*d, 0,J1);
-    jac((ix/2+1)*d, iy*d, 0,J2);
-    jac(ix/2*d, (iy+1)*d, 0,J3);
+  double J1[2][3], J2[2][3], J3[2][3];
+  if (ix % 2 == 0){
+    pnt(ix / 2 * d, iy * d, 0, pnt1);
+    pnt((ix / 2 + 1) * d, iy * d, 0, pnt2);
+    pnt(ix / 2 * d, (iy + 1) * d, 0, pnt3);
+    jac(ix / 2 * d, iy * d, 0, J1);
+    jac((ix / 2 + 1) * d, iy * d, 0, J2);
+    jac(ix / 2 * d, (iy + 1) * d, 0, J3);
   }
   else{
-    pnt((ix/2+1)*d, iy*d, 0,pnt1);
-    pnt((ix/2+1)*d, (iy+1)*d, 0,pnt2);
-    pnt(ix/2*d, (iy+1)*d, 0,pnt3);
-    jac((ix/2+1)*d, iy*d, 0,J1);
-    jac((ix/2+1)*d, (iy+1)*d, 0,J2);
-    jac(ix/2*d, (iy+1)*d, 0,J3);
+    pnt((ix / 2 + 1) * d, iy * d, 0, pnt1);
+    pnt((ix / 2 + 1) * d, (iy + 1) * d, 0, pnt2);
+    pnt(ix / 2 * d, (iy + 1) * d, 0, pnt3);
+    jac((ix / 2 + 1) * d, iy * d, 0, J1);
+    jac((ix / 2 + 1) * d, (iy + 1) * d, 0, J2);
+    jac(ix / 2 * d, (iy + 1) * d, 0, J3);
   }
   {
-    SVector3 d1 (J1[0][0],J1[0][1],J1[0][2]);
-    SVector3 d2 (J1[1][0],J1[1][1],J1[1][2]);
-    n[0] = crossprod(d1,d2);
+    SVector3 d1(J1[0][0], J1[0][1], J1[0][2]);
+    SVector3 d2(J1[1][0], J1[1][1], J1[1][2]);
+    n[0] = crossprod(d1, d2);
     n[0].normalize();
   }
   {
-    SVector3 d1 (J2[0][0],J2[0][1],J2[0][2]);
-    SVector3 d2 (J2[1][0],J2[1][1],J2[1][2]);
-    n[1] = crossprod(d1,d2);
+    SVector3 d1(J2[0][0], J2[0][1], J2[0][2]);
+    SVector3 d2(J2[1][0], J2[1][1], J2[1][2]);
+    n[1] = crossprod(d1, d2);
     n[1].normalize();
   }
   {
-    SVector3 d1 (J3[0][0],J3[0][1],J3[0][2]);
-    SVector3 d2 (J3[1][0],J3[1][1],J3[1][2]);
-    n[2] = crossprod(d1,d2);
+    SVector3 d1(J3[0][0], J3[0][1], J3[0][2]);
+    SVector3 d2(J3[1][0], J3[1][1], J3[1][2]);
+    n[2] = crossprod(d1, d2);
     n[2].normalize();
   }
 
   x[0] = pnt1.x(); x[1] = pnt2.x(); x[2] = pnt3.x();
   y[0] = pnt1.y(); y[1] = pnt2.y(); y[2] = pnt3.y();
   z[0] = pnt1.z(); z[1] = pnt2.z(); z[2] = pnt3.z();
-  
 }
 
 int MTriangleN::getNumEdgesRep(){ return 3 * numSubEdges; }
@@ -864,7 +868,7 @@ void MTriangleN::getEdgeRep(int num, double *x, double *y, double *z, SVector3 *
   if (num < N){
     SPoint3 pnt1, pnt2;
     pnt((double)num / N, 0., 0,pnt1);
-    pnt((double)(num + 1) / N, 0., 0,pnt2);
+    pnt((double)(num + 1) / N, 0., 0, pnt2);
     x[0] = pnt1.x(); x[1] = pnt2.x();
     y[0] = pnt1.y(); y[1] = pnt2.y();
     z[0] = pnt1.z(); z[1] = pnt2.z();
@@ -873,8 +877,8 @@ void MTriangleN::getEdgeRep(int num, double *x, double *y, double *z, SVector3 *
   if (num < 2 * N){
     SPoint3 pnt1, pnt2;
     num -= N;
-    pnt(1. - (double)num / N, (double)num / N, 0,pnt1);
-    pnt(1. - (double)(num + 1) / N, (double)(num + 1) / N, 0,pnt2);
+    pnt(1. - (double)num / N, (double)num / N, 0, pnt1);
+    pnt(1. - (double)(num + 1) / N, (double)(num + 1) / N, 0, pnt2);
     x[0] = pnt1.x(); x[1] = pnt2.x();
     y[0] = pnt1.y(); y[1] = pnt2.y();
     z[0] = pnt1.z(); z[1] = pnt2.z();
@@ -924,7 +928,9 @@ MElement *MElementFactory::create(int type, std::vector<MVertex*> &v,
   case MSH_PYR_13: return new MPyramid13(v, num, part);
   case MSH_PYR_14: return new MPyramid14(v, num, part);
   case MSH_TET_20: return new MTetrahedronN(v, 3, num, part);
+  case MSH_TET_34: return new MTetrahedronN(v, 3, num, part);
   case MSH_TET_35: return new MTetrahedronN(v, 4, num, part);
+  case MSH_TET_52: return new MTetrahedronN(v, 5, num, part);
   case MSH_TET_56: return new MTetrahedronN(v, 5, num, part);
   default:         return 0;
   }
