@@ -1,3 +1,7 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 // Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
 // This program is free software; you can redistribute it and/or modify
@@ -28,6 +32,14 @@
 
 extern Context_T CTX;
 
+MFace::MFace() 
+{ 
+  for(int i = 0; i < 4; i++){
+    _v[i] = 0; 
+    _si[i] = 0;
+  }
+}
+
 MFace::MFace(MVertex *v0, MVertex *v1, MVertex *v2, MVertex *v3) 
 {
   if(CTX.mesh.reverse_all_normals){
