@@ -1,25 +1,11 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _MVERTEX_H_
 #define _MVERTEX_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include <stdio.h>
 #include <set>
 #include "SPoint3.h"
@@ -134,20 +120,18 @@ class MEdgeVertex : public MVertex{
  protected:
   double _u, _lc;
  public :
- MEdgeVertex(double x, double y, double z, GEntity *ge, double u, double lc = -1.0) 
-   : MVertex(x, y, z, ge), _u(u), _lc(lc)
+  MEdgeVertex(double x, double y, double z, GEntity *ge, double u, double lc = -1.0) 
+    : MVertex(x, y, z, ge), _u(u), _lc(lc)
   {
   }
   virtual ~MEdgeVertex(){}
   virtual bool getParameter(int i, double &par) const 
   { 
-    if(i) throw; 
     par = _u; 
     return true; 
   }
   virtual bool setParameter(int i, double par)
   { 
-    if(i) throw; 
     _u = par; 
     return true; 
   }
