@@ -1,23 +1,7 @@
-// $Id: OCCEdge.cpp,v 1.38 2008-05-04 08:31:13 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GModel.h"
 #include "Message.h"
@@ -77,7 +61,7 @@ SPoint2 OCCEdge::reparamOnFace(GFace *face, double epar, int dir) const
   
   if(c2d.IsNull()){
     Msg::Fatal("Reparam on face failed: curve %d is not on surface %d",
-        tag(), face->tag());
+	       tag(), face->tag());
   }
 
   double u, v;
@@ -93,11 +77,11 @@ SPoint2 OCCEdge::reparamOnFace(GFace *face, double epar, int dir) const
   if(sqrt(dx * dx + dy * dy + dz * dz) > 1.e-4 * CTX.lc){
     // return reparamOnFace(face, epar,-1);      
     Msg::Warning("Reparam on face partially failed for curve %d surface %d at point %g",
-        tag(), face->tag(), epar);
+		 tag(), face->tag(), epar);
     Msg::Warning("On the face %d local (%g %g) global (%g %g %g)",
-        face->tag(), u, v, p2.x(), p2.y(), p2.z());
+		 face->tag(), u, v, p2.x(), p2.y(), p2.z());
     Msg::Warning("On the edge %d local (%g) global (%g %g %g)",
-        tag(), epar, p1.x(), p1.y(), p1.z());
+		 tag(), epar, p1.x(), p1.y(), p1.z());
     // GPoint ppp = face->closestPoint(SPoint3(p1.x(), p1.y(), p1.z()));
     // return SPoint2(ppp.u(), ppp.v());
   }
@@ -105,7 +89,7 @@ SPoint2 OCCEdge::reparamOnFace(GFace *face, double epar, int dir) const
 }
 
 // True if the edge is a seam for the given face
-int OCCEdge::isSeam(GFace *face) const
+bool OCCEdge::isSeam(GFace *face) const
 {
   const TopoDS_Face *s = (TopoDS_Face*) face->getNativePtr();
   BRepAdaptor_Surface surface(*s);
@@ -114,7 +98,7 @@ int OCCEdge::isSeam(GFace *face) const
   //  if(surface.IsUPeriodic() || surface.IsVPeriodic()){
   return BRep_Tool::IsClosed(c, *s);
   //  }
-  return 0;
+  // return false;
 }
 
 GPoint OCCEdge::point(double par) const
@@ -145,7 +129,8 @@ SVector3 OCCEdge::firstDer(double par) const
 
 double OCCEdge::parFromPoint(const SPoint3 &pt) const
 {
-  throw;
+  Msg::Error("parFromPoint not implemented for OCCEdge");
+  return 0.;
 }
 
 GEntity::GeomType OCCEdge::geomType() const
