@@ -1,25 +1,11 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _OCC_EDGE_H_
 #define _OCC_EDGE_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include "GEdge.h"
 #include "GModel.h"
 #include "OCCVertex.h"
@@ -54,7 +40,7 @@ class OCCEdge : public GEdge {
   virtual int minimumDrawSegments () const;
   bool is3D() const { return !curve.IsNull(); }
   void setTrimmed(OCCFace *);
-  int isSeam(GFace *) const;
+  bool isSeam(GFace *) const;
 };
 
 #endif
