@@ -1,23 +1,7 @@
-// $Id: OCCFace.cpp,v 1.42 2008-06-10 08:37:34 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GModel.h"
 #include "GEdgeLoop.h"
@@ -46,28 +30,29 @@ OCCFace::OCCFace(GModel *m, TopoDS_Face _s, int num, TopTools_IndexedMapOfShape
   TopExp_Explorer exp0, exp01, exp1, exp2, exp3;
   for(exp2.Init(s, TopAbs_WIRE); exp2.More(); exp2.Next()){
     TopoDS_Shape wire = exp2.Current();
-    Msg::Debug("OCC Face %d - New Wire",num);
+    Msg::Debug("OCC Face %d - New Wire", num);
     std::list<GEdge*> l_wire;
-    std::list<int> l_oris;
     for(exp3.Init(wire, TopAbs_EDGE); exp3.More(); exp3.Next()){          
       TopoDS_Edge edge = TopoDS::Edge(exp3.Current());
       int index = emap.FindIndex(edge);
       GEdge *e = m->getEdgeByTag(index);
-      if(!e) throw;
-      l_wire.push_back(e);
-      l_oris.push_back(edge.Orientation());
-      Msg::Debug("Edge %d ori %d", e->tag(), edge.Orientation());
-      e->addFace(this);
-      if(!e->is3D()){
-        OCCEdge *occe = (OCCEdge*)e;
-        occe->setTrimmed(this);
+      if(e){
+	l_wire.push_back(e);
+	Msg::Debug("Edge %d ori %d", e->tag(), edge.Orientation());
+	e->addFace(this);
+	if(!e->is3D()){
+	  OCCEdge *occe = (OCCEdge*)e;
+	  occe->setTrimmed(this);
+	}
+      }
+      else{
+	Msg::Error("Unknown edge %d in face %d", index, num);
       }
     }      
     
-    //    GEdgeLoop el(l_wire,l_oris);
-    GEdgeLoop el(l_wire);        
+    GEdgeLoop el(l_wire);
 
-    for(GEdgeLoop::citer it = el.begin() ; it != el.end() ; ++it){
+    for(GEdgeLoop::citer it = el.begin(); it != el.end(); ++it){
       l_edges.push_back(it->ge);
       l_dirs.push_back(it->_sign);
       if (el.count() == 2){
@@ -156,7 +141,7 @@ GPoint OCCFace::closestPoint(const SPoint3 & qp, const double initialGuess[2]) c
   double pp[2] = {initialGuess[0],initialGuess[1]};
   proj.LowerDistanceParameters(pp[0], pp[1]);
 
-  Msg::Info("projection lower distance parameters %g %g",pp[0],pp[1]);
+  //  Msg::Info("projection lower distance parameters %g %g",pp[0],pp[1]);
 
   if((pp[0] < umin || umax < pp[0]) || (pp[1]<vmin || vmax<pp[1])){
     Msg::Error("Point projection is out of face bounds");
@@ -214,7 +199,7 @@ double OCCFace::curvature (const SPoint2 &param) const
   return std::max(fabs(prop.MinCurvature()), fabs(prop.MaxCurvature()));
 }
 
-int OCCFace::containsPoint(const SPoint3 &pt) const
+bool OCCFace::containsPoint(const SPoint3 &pt) const
 { 
   if(geomType() == Plane){
     gp_Pln pl = Handle(Geom_Plane)::DownCast(occface)->Pln();
