@@ -1,23 +1,7 @@
-// $Id: OCCVertex.cpp,v 1.15 2008-03-20 11:44:06 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GModel.h"
 #include "OCCVertex.h"
@@ -59,8 +43,8 @@ SPoint2 OCCVertex::reparamOnFace(GFace *gf, int dir) const
 {
   std::list<GEdge*>::const_iterator it = l_edges.begin();
   while(it != l_edges.end()){
-    std::list<GEdge*> l_edges = gf->edges();
-    if(std::find(l_edges.begin(),l_edges.end(),*it) != l_edges.end()){
+    std::list<GEdge*> l = gf->edges();
+    if(std::find(l.begin(), l.end(), *it) != l.end()){
       if((*it)->isSeam(gf)){
         const TopoDS_Face *s = (TopoDS_Face*)gf->getNativePtr();
         const TopoDS_Edge *c = (TopoDS_Edge*)(*it)->getNativePtr();
@@ -76,8 +60,8 @@ SPoint2 OCCVertex::reparamOnFace(GFace *gf, int dir) const
   }  
   it = l_edges.begin();
   while(it != l_edges.end()){
-    std::list<GEdge*> l_edges = gf->edges();
-    if(std::find(l_edges.begin(),l_edges.end(),*it) != l_edges.end()){
+    std::list<GEdge*> l = gf->edges();
+    if(std::find(l.begin(), l.end(), *it) != l.end()){
       const TopoDS_Face *s = (TopoDS_Face*)gf->getNativePtr();
       const TopoDS_Edge *c = (TopoDS_Edge*)(*it)->getNativePtr();
       double s1,s0;
