@@ -1,3 +1,7 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 #include <list>
 #include "fourierVertex.h"
 #include "fourierFace.h"
@@ -39,12 +43,12 @@ SPoint2 fourierFace::parFromPoint(const SPoint3 &p) const
   return SPoint2(u, v);
 }
 
-int fourierFace::containsParam(const SPoint2 &pt) const
+bool fourierFace::containsParam(const SPoint2 &pt) const
 {
   const double tol = 1.e-6;
-  if(pt[0] < 0. - tol || pt[0] > 1. + tol) return 0;
-  if(pt[1] < 0. - tol || pt[1] > 1. + tol) return 0;
-  return 1;
+  if(pt[0] < 0. - tol || pt[0] > 1. + tol) return false;
+  if(pt[1] < 0. - tol || pt[1] > 1. + tol) return false;
+  return true;
 }
 
 SVector3 fourierFace::normal(const SPoint2 &param) const
@@ -59,4 +63,10 @@ GEntity::GeomType fourierFace::geomType() const
   return  GEntity::ParametricSurface;
 }
 
+Pair<SVector3, SVector3> fourierFace::firstDer(const SPoint2 &param) const
+{
+  Msg::Error("First derivative not implemented for fourier face");
+  return Pair<SVector3, SVector3>();
+}
+
 #endif
