@@ -1,23 +1,7 @@
-// $Id: gmshEdge.cpp,v 1.49 2008-05-04 08:31:14 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GModel.h"
 #include "GFace.h"
@@ -111,7 +95,7 @@ int gmshEdge::minimumMeshSegments () const
     np = GEdge::minimumMeshSegments();
   else if(geomType() == Circle || geomType() == Ellipse)
     np = (int)(fabs(c->Circle.t1 - c->Circle.t2) *
-                 (double)CTX.mesh.min_circ_points / Pi) - 1;
+                 (double)CTX.mesh.min_circ_points / M_PI) - 1;
   else
     np = CTX.mesh.min_curv_points - 1;
   return std::max(np, meshAttributes.minimumMeshSegments);
@@ -168,7 +152,7 @@ SPoint2 gmshEdge::reparamOnFace(GFace *face, double epar,int dir) const
             k = periodic ? k - NbControlPoints + 1: NbControlPoints - 1;
           List_Read(c->Control_Points, k, &v[j]);
         }
-        return InterpolateCubicSpline(v, t, c->mat, 0, t1, t2, c->geometry);
+        return InterpolateCubicSpline(v, t, c->mat, t1, t2, c->geometry);
       }
     case MSH_SEGM_SPLN :
       {
@@ -209,10 +193,11 @@ SPoint2 gmshEdge::reparamOnFace(GFace *face, double epar,int dir) const
         else{
           List_Read(c->Control_Points, i + 2, &v[3]);
         }
-        return InterpolateCubicSpline(v, t, c->mat, 0, t1, t2, c->geometry);
+        return InterpolateCubicSpline(v, t, c->mat, t1, t2, c->geometry);
       }
     default:
-      throw;
+      Msg::Error("Unknown edge type in reparamOnFace");
+      return SPoint2();
     }
   }
   
