@@ -1,23 +1,7 @@
-// $Id: gmshSurface.cpp,v 1.15 2008-05-04 08:31:14 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "gmshSurface.h"
 #include "Message.h"
@@ -27,6 +11,30 @@
 
 std::map<int,gmshSurface*> gmshSurface::allGmshSurfaces;
 
+SPoint2 gmshSurface::parFromPoint(double x, double y, double z)
+{
+  Msg::Error("Parametric coordinate computation not implemented for this type of surface");
+  return SPoint2();
+}
+
+SVector3 gmshSurface::normal(const SPoint2 &param) const
+{
+  Msg::Error("Normal computation not implemented for this type of surface");
+  return SVector3();
+}
+
+Pair<SVector3, SVector3> gmshSurface::firstDer(const SPoint2 &param)
+{
+  Msg::Error("First derivative not implemented for this type of surface");
+  return Pair<SVector3, SVector3>();
+}
+
+double gmshSurface::getMetricEigenvalue(const SPoint2 &)
+{
+  Msg::Error("Metric eigenvalue not implemented for this type of surface");
+  return 0;
+}
+
 gmshSurface *gmshSphere::NewSphere(int iSphere, double x, double y, double z, double r)
 {
   gmshSphere *sph = new gmshSphere(x, y, z, r);
@@ -55,7 +63,6 @@ SPoint3 gmshSphere::point(double par1, double par2) const
   const double x = xc + r * sin(par2) * cos(par1);
   const double y = yc + r * sin(par2) * sin(par1);
   const double z = zc - r * cos(par2); 
-  // printf("%g %g - %g %g %g\n",par1,par2,x,y,z);
   return SPoint3(x, y, z);
 }
 
@@ -78,10 +85,10 @@ SPoint3 gmshPolarSphere::point(double parA, double parB) const
   //at the center of the sphere 
   //parA=2rx/(r+z) parB=2ry/(r+z)
   double rp2 = parA * parA + parB * parB;
-        SPoint3 p(2*parA/(1+rp2),2*parB/(1+rp2),(rp2-1)/(rp2+1));
-        p*=-r;
-        p+=o;
-        return p;
+  SPoint3 p(2*parA/(1+rp2),2*parB/(1+rp2),(rp2-1)/(rp2+1));
+  p *= -r;
+  p += o;
+  return p;
 }
 
 gmshSurface *gmshParametricSurface::NewParametricSurface(int iSurf, char *valX,
@@ -132,3 +139,9 @@ SPoint3 gmshParametricSurface::point(double par1, double par2) const
   return SPoint3(x, y, z);
 #endif
 }
+
+Range<double> gmshParametricSurface::parBounds(int i) const
+{
+  Msg::Error("Parameter bounds not available for parametric surface");
+  return Range<double>(0., 0.);
+}
