@@ -1,23 +1,7 @@
-// $Id: Entity.cpp,v 1.84 2008-04-17 18:21:11 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <string.h>
 #include "GmshUI.h"
@@ -392,6 +376,18 @@ void Draw_Vector(int Type, int Fill,
     glVertex3d(x + dx, y + dy, z + dz);
     glEnd();
     break;
+  case 6:
+    if(relHeadRadius){
+      glBegin(GL_POINTS);
+      glVertex3d(x + dx, y + dy, z + dz);
+      glEnd();
+    }
+    glBegin(GL_LINES);
+    glVertex3d(x + dx, y + dy, z + dz);
+    //glColor4ubv((GLubyte *) & CTX.color.bg);
+    glVertex3d(x, y, z);
+    glEnd();
+    break;
   case 2:
     Draw_SimpleVector(1, Fill, relHeadRadius, relStemLength, relStemRadius,
                       x, y, z, dx, dy, dz, length, light);
