@@ -1,23 +1,7 @@
-// $Id: Geom.cpp,v 1.156 2008-03-20 11:44:07 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "GmshUI.h"
 #include "Draw.h"
@@ -29,7 +13,7 @@
 
 extern Context_T CTX;
 
-void drawBBox(GEntity *e)
+static void drawBBox(GEntity *e)
 {
   return;
   glColor4ubv((GLubyte *) & CTX.color.fg);
@@ -486,11 +470,6 @@ void Draw_Geom()
                                 CTX.max[0], CTX.max[1], CTX.max[2],
                                 CTX.clip_plane[i][0], CTX.clip_plane[i][1], 
                                 CTX.clip_plane[i][2], CTX.clip_plane[i][3]);
-    if(CTX.mesh.use_cut_plane)
-      Draw_PlaneInBoundingBox(CTX.min[0], CTX.min[1], CTX.min[2],
-                              CTX.max[0], CTX.max[1], CTX.max[2],
-                              CTX.mesh.cut_planea, CTX.mesh.cut_planeb, 
-                              CTX.mesh.cut_planec, CTX.mesh.cut_planed);
   }
   
   if(CTX.axes){
