@@ -1,24 +1,9 @@
-// $Id: Post.cpp,v 1.168 2008-06-07 17:20:47 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
+#include <math.h>
 #include <algorithm>
 #include "Message.h"
 #include "GmshUI.h"
@@ -41,9 +26,9 @@ extern Context_T CTX;
 
 #define NMAX 20
 
-void saturate(int nb, double val[NMAX][9], double vmin, double vmax, 
-              int i0=0, int i1=1, int i2=2, int i3=3, 
-              int i4=4, int i5=5, int i6=6, int i7=7)
+static void saturate(int nb, double val[NMAX][9], double vmin, double vmax, 
+		     int i0=0, int i1=1, int i2=2, int i3=3, 
+		     int i4=4, int i5=5, int i6=6, int i7=7)
 {
   int id[8] = {i0, i1, i2, i3, i4, i5, i6, i7};
   for(int i = 0; i < nb; i++){
@@ -52,7 +37,7 @@ void saturate(int nb, double val[NMAX][9], double vmin, double vmax,
   }
 }
 
-SVector3 normal3(double xyz[NMAX][3], int i0=0, int i1=1, int i2=2)
+static SVector3 normal3(double xyz[NMAX][3], int i0=0, int i1=1, int i2=2)
 {
   SVector3 t1(xyz[i1][0] - xyz[i0][0], 
               xyz[i1][1] - xyz[i0][1],
@@ -65,7 +50,7 @@ SVector3 normal3(double xyz[NMAX][3], int i0=0, int i1=1, int i2=2)
   return n;
 }
 
-SVector3 getPointNormal(PView *p, double v)
+static SVector3 getPointNormal(PView *p, double v)
 {
   PViewOptions *opt = p->getOptions();
   SVector3 n(0., 0., 0.);
@@ -79,8 +64,8 @@ SVector3 getPointNormal(PView *p, double v)
   return n;
 }
 
-void getLineNormal(PView *p, double x[2], double y[2], double z[2],
-                   double *v, SVector3 n[2], bool computeNormal)
+static void getLineNormal(PView *p, double x[2], double y[2], double z[2],
+			  double *v, SVector3 n[2], bool computeNormal)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -123,9 +108,9 @@ void getLineNormal(PView *p, double x[2], double y[2], double z[2],
   }
 }
 
-bool getExternalValues(PView *p, int index, int ient, int iele, int numNodes, 
-                       int numComp, double val[NMAX][9], 
-                       int &numComp2, double val2[NMAX][9])
+static bool getExternalValues(PView *p, int index, int ient, int iele, 
+			      int numNodes, int numComp, double val[NMAX][9], 
+			      int &numComp2, double val2[NMAX][9])
 {
   PViewOptions *opt = p->getOptions();
 
@@ -167,8 +152,8 @@ bool getExternalValues(PView *p, int index, int ient, int iele, int numNodes,
   return false;
 }
 
-void applyGeneralRaise(PView *p, int numNodes, int numComp, 
-                       double vals[NMAX][9], double xyz[NMAX][3])
+static void applyGeneralRaise(PView *p, int numNodes, int numComp, 
+			      double vals[NMAX][9], double xyz[NMAX][3])
 {
   PViewOptions *opt = p->getOptions();
 
@@ -195,8 +180,9 @@ void applyGeneralRaise(PView *p, int numNodes, int numComp,
   }
 }
 
-void changeCoordinates(PView *p, int ient, int iele, int numNodes, int numEdges, 
-                       int numComp, double xyz[NMAX][3], double val[NMAX][9])
+static void changeCoordinates(PView *p, int ient, int iele, int numNodes, 
+			      int numEdges, int numComp, double xyz[NMAX][3], 
+			      double val[NMAX][9])
 {
   PViewOptions *opt = p->getOptions();
 
@@ -278,16 +264,56 @@ void changeCoordinates(PView *p, int ient, int iele, int numNodes, int numEdges,
   }
 }
 
-void addOutlinePoint(PView *p, double xyz[NMAX][3], unsigned int color, bool pre,
-                     int i0=0)
+static double evalClipPlane(int clip, double x, double y, double z)
+{
+  return CTX.clip_plane[clip][0] * x + CTX.clip_plane[clip][1] * y + 
+    CTX.clip_plane[clip][2] * z + CTX.clip_plane[clip][3];
+}
+
+static double intersectClipPlane(int clip, int numNodes, double xyz[NMAX][3])
+{
+  double val = evalClipPlane(clip, xyz[0][0], xyz[0][1], xyz[0][2]);
+  for(int i = 1; i < numNodes; i++){
+    if(val * evalClipPlane(clip, xyz[i][0], xyz[i][1], xyz[i][2]) <= 0)
+      return 0.; // the element intersects the cut plane
+  }
+  return val;
+}
+
+static bool isElementVisible(int index, int dim, int numNodes, double xyz[NMAX][3])
+{
+  if(!CTX.clip_whole_elements) return true;
+  bool hidden = false;
+  for(int clip = 0; clip < 6; clip++){
+    if(CTX.clip[clip] & (1 << (2 + index))){
+      if(dim < 3 && CTX.clip_only_volume){
+      }
+      else{
+	double d = intersectClipPlane(clip, numNodes, xyz);
+	if(dim == 3 && CTX.clip_only_draw_intersecting_volume && d){
+	  hidden = true;
+	  break;
+	}
+	else if(d < 0){
+	  hidden = true;
+	  break;
+	}
+      }
+    }
+  }
+  return !hidden;
+}
+
+static void addOutlinePoint(PView *p, double xyz[NMAX][3], unsigned int color, 
+			    bool pre, int i0=0)
 {
   if(pre) return;
   SVector3 n = getPointNormal(p, 1.);
   p->va_points->add(&xyz[i0][0], &xyz[i0][1], &xyz[i0][2], &n, &color, 0, true);
 }
 
-void addScalarPoint(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre,
-                    int i0=0, bool unique=false)
+static void addScalarPoint(PView *p, double xyz[NMAX][3], double val[NMAX][9],
+			   bool pre, int i0=0, bool unique=false)
 {
   if(pre) return;
 
@@ -303,8 +329,8 @@ void addScalarPoint(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre
   }
 }
 
-void addOutlineLine(PView *p, double xyz[NMAX][3], unsigned int color, bool pre,
-                    int i0=0, int i1=1)
+static void addOutlineLine(PView *p, double xyz[NMAX][3], unsigned int color,
+			   bool pre, int i0=0, int i1=1)
 {
   if(pre) return;
 
@@ -320,8 +346,8 @@ void addOutlineLine(PView *p, double xyz[NMAX][3], unsigned int color, bool pre,
   p->va_lines->add(x, y, z, n, col, 0, true);
 }
 
-void addScalarLine(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre,
-                   int i0=0, int i1=1, bool unique=false)
+static void addScalarLine(PView *p, double xyz[NMAX][3], double val[NMAX][9],
+			  bool pre, int i0=0, int i1=1, bool unique=false)
 {
   if(pre) return;
 
@@ -399,8 +425,8 @@ void addScalarLine(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre,
   }
 }
 
-void addOutlineTriangle(PView *p, double xyz[NMAX][3], unsigned int color, bool pre,
-                        int i0=0, int i1=1, int i2=2)
+static void addOutlineTriangle(PView *p, double xyz[NMAX][3], unsigned int color, 
+			       bool pre, int i0=0, int i1=1, int i2=2)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -425,8 +451,9 @@ void addOutlineTriangle(PView *p, double xyz[NMAX][3], unsigned int color, bool
   }
 }
 
-void addScalarTriangle(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre,
-                       int i0=0, int i1=1, int i2=2, bool unique=false, bool skin=false)
+static void addScalarTriangle(PView *p, double xyz[NMAX][3], double val[NMAX][9], 
+			      bool pre, int i0=0, int i1=1, int i2=2,
+			      bool unique=false, bool skin=false)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -542,8 +569,8 @@ void addScalarTriangle(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool
   }
 }
 
-void addOutlineQuadrangle(PView *p, double xyz[NMAX][3], unsigned int color, bool pre,
-                          int i0=0, int i1=1, int i2=2, int i3=3)
+static void addOutlineQuadrangle(PView *p, double xyz[NMAX][3], unsigned int color, 
+				 bool pre, int i0=0, int i1=1, int i2=2, int i3=3)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -568,8 +595,9 @@ void addOutlineQuadrangle(PView *p, double xyz[NMAX][3], unsigned int color, boo
   }
 }
 
-void addScalarQuadrangle(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre,
-                         int i0=0, int i1=1, int i2=2, int i3=3, bool unique=false)
+static void addScalarQuadrangle(PView *p, double xyz[NMAX][3], double val[NMAX][9], 
+				bool pre, int i0=0, int i1=1, int i2=2, int i3=3,
+				bool unique=false)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -588,15 +616,16 @@ void addScalarQuadrangle(PView *p, double xyz[NMAX][3], double val[NMAX][9], boo
     addScalarTriangle(p, xyz, val, pre, it[i][0], it[i][1], it[i][2], unique);
 }
 
-void addOutlineTetrahedron(PView *p, double xyz[NMAX][3], unsigned int color, bool pre)
+static void addOutlineTetrahedron(PView *p, double xyz[NMAX][3], unsigned int color, 
+				  bool pre)
 {
   const int it[4][3] = {{0, 2, 1}, {0, 1, 3}, {0, 3, 2}, {3, 1, 2}};
   for(int i = 0; i < 4; i++)
     addOutlineTriangle(p, xyz, color, pre, it[i][0], it[i][1], it[i][2]);
 }
 
-void addScalarTetrahedron(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre,
-                          int i0=0, int i1=1, int i2=2, int i3=3)
+static void addScalarTetrahedron(PView *p, double xyz[NMAX][3], double val[NMAX][9], 
+				 bool pre, int i0=0, int i1=1, int i2=2, int i3=3)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -650,7 +679,8 @@ void addScalarTetrahedron(PView *p, double xyz[NMAX][3], double val[NMAX][9], bo
   }
 }
 
-void addOutlineHexahedron(PView *p, double xyz[NMAX][3], unsigned int color, bool pre)
+static void addOutlineHexahedron(PView *p, double xyz[NMAX][3], unsigned int color,
+				 bool pre)
 {
   const int iq[6][4] = {{0, 3, 2, 1}, {0, 1, 5, 4}, {0, 4, 7, 3},
                         {1, 2, 6, 5}, {2, 3, 7, 6}, {4, 5, 6, 7}};
@@ -660,7 +690,8 @@ void addOutlineHexahedron(PView *p, double xyz[NMAX][3], unsigned int color, boo
                          iq[i][2], iq[i][3]);
 }
 
-void addScalarHexahedron(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre)
+static void addScalarHexahedron(PView *p, double xyz[NMAX][3], double val[NMAX][9],
+				bool pre)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -681,7 +712,8 @@ void addScalarHexahedron(PView *p, double xyz[NMAX][3], double val[NMAX][9], boo
     addScalarTetrahedron(p, xyz, val, pre, is[i][0], is[i][1], is[i][2], is[i][3]);
 }
 
-void addOutlinePrism(PView *p, double xyz[NMAX][3], unsigned int color, bool pre)
+static void addOutlinePrism(PView *p, double xyz[NMAX][3], unsigned int color, 
+			    bool pre)
 {
   const int iq[3][4] = {{0, 1, 4, 3}, {0, 3, 5, 2}, {1, 2, 5, 4}};
   const int it[2][3] = {{0, 2, 1}, {3, 4, 5}};
@@ -692,7 +724,8 @@ void addOutlinePrism(PView *p, double xyz[NMAX][3], unsigned int color, bool pre
     addOutlineTriangle(p, xyz, color, pre, it[i][0], it[i][1], it[i][2]);
 }
 
-void addScalarPrism(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre)
+static void addScalarPrism(PView *p, double xyz[NMAX][3], double val[NMAX][9],
+			   bool pre)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -714,7 +747,8 @@ void addScalarPrism(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre
     addScalarTetrahedron(p, xyz, val, pre, is[i][0], is[i][1], is[i][2], is[i][3]);
 }
 
-void addOutlinePyramid(PView *p, double xyz[NMAX][3], unsigned int color, bool pre)
+static void addOutlinePyramid(PView *p, double xyz[NMAX][3], unsigned int color,
+			      bool pre)
 {
   const int it[4][3] = {{0, 1, 4}, {3, 0, 4}, {1, 2, 4}, {2, 3, 4}};
 
@@ -723,7 +757,8 @@ void addOutlinePyramid(PView *p, double xyz[NMAX][3], unsigned int color, bool p
     addOutlineTriangle(p, xyz, color, pre, it[i][0], it[i][1], it[i][2]);
 }
 
-void addScalarPyramid(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool pre)
+static void addScalarPyramid(PView *p, double xyz[NMAX][3], double val[NMAX][9],
+			     bool pre)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -743,7 +778,7 @@ void addScalarPyramid(PView *p, double xyz[NMAX][3], double val[NMAX][9], bool p
     addScalarTetrahedron(p, xyz, val, pre, is[i][0], is[i][1], is[i][2], is[i][3]);
 }
 
-void addOutlineElement(PView *p, int numEdges, double xyz[NMAX][3], bool pre)
+static void addOutlineElement(PView *p, int numEdges, double xyz[NMAX][3], bool pre)
 {
   PViewOptions *opt = p->getOptions();
   switch(numEdges){
@@ -758,8 +793,8 @@ void addOutlineElement(PView *p, int numEdges, double xyz[NMAX][3], bool pre)
   }
 }
 
-void addScalarElement(PView *p, int numEdges, double xyz[NMAX][3],
-                      double val[NMAX][9], bool pre)
+static void addScalarElement(PView *p, int numEdges, double xyz[NMAX][3],
+			     double val[NMAX][9], bool pre)
 {
   switch(numEdges){
   case 0: addScalarPoint(p, xyz, val, pre); break;
@@ -773,8 +808,9 @@ void addScalarElement(PView *p, int numEdges, double xyz[NMAX][3],
   }
 }
 
-void addVectorElement(PView *p, int ient, int iele, int numNodes, int numEdges, 
-                      double xyz[NMAX][3], double val[NMAX][9], bool pre)
+static void addVectorElement(PView *p, int ient, int iele, int numNodes, 
+			     int numEdges, double xyz[NMAX][3], double val[NMAX][9], 
+			     bool pre)
 {
   // use adaptive data if available
   PViewData *data = p->getData(true);
@@ -875,8 +911,8 @@ void addVectorElement(PView *p, int ient, int iele, int numNodes, int numEdges,
   }
 }
 
-void addTensorElement(PView *p, int numNodes, int numEdges, double xyz[NMAX][3],
-                      double val[NMAX][9], bool pre)
+static void addTensorElement(PView *p, int numNodes, int numEdges,
+			     double xyz[NMAX][3], double val[NMAX][9], bool pre)
 {
   PViewOptions *opt = p->getOptions();
 
@@ -887,7 +923,7 @@ void addTensorElement(PView *p, int numNodes, int numEdges, double xyz[NMAX][3],
   }
 }
 
-void addElementsInArrays(PView *p, bool preprocessNormalsOnly)
+static void addElementsInArrays(PView *p, bool preprocessNormalsOnly)
 {
   // use adaptive data if available
   PViewData *data = p->getData(true);
@@ -910,7 +946,9 @@ void addElementsInArrays(PView *p, bool preprocessNormalsOnly)
           data->getValue(opt->TimeStep, ent, i, j, k, val[j][k]);
       }
       changeCoordinates(p, ent, i, numNodes, numEdges, numComp, xyz, val);
-      
+      int dim = data->getDimension(opt->TimeStep, ent, i);
+      if(!isElementVisible(p->getIndex(), dim, numNodes, xyz)) continue;
+
       for(int j = 0; j < numNodes; j++)
         opt->TmpBBox += SPoint3(xyz[j][0], xyz[j][1], xyz[j][2]);
       
@@ -945,7 +983,7 @@ void addElementsInArrays(PView *p, bool preprocessNormalsOnly)
   }
 }
 
-void drawArrays(PView *p, VertexArray *va, GLint type, bool useNormalArray)
+static void drawArrays(PView *p, VertexArray *va, GLint type, bool useNormalArray)
 {
   if(!va) return;
 
@@ -959,11 +997,22 @@ void drawArrays(PView *p, VertexArray *va, GLint type, bool useNormalArray)
       float *p = va->getVertexArray(3 * i);
       glColor4ubv((GLubyte *)va->getColorArray(4 * i));
       double f = 1.;
-      if(opt->PointType == 2){
+      if(opt->PointType > 1){
         char *n = va->getNormalArray(3 * i);
         f = char2float(*n);
       }
-      Draw_Sphere(opt->PointSize * f, p[0], p[1], p[2], opt->Light);
+      if(opt->PointType == 2){
+	int s = (int)(opt->PointSize * f);
+	if(s){
+	  glPointSize(s);
+	  gl2psPointSize(s * CTX.print.eps_point_size_factor);
+	  glBegin(GL_POINTS);
+	  glVertex3d(p[0], p[1], p[2]);
+	  glEnd();
+	}
+      }
+      else
+	Draw_Sphere(opt->PointSize * f, p[0], p[1], p[2], opt->Light);
     }
   }
   else if(type == GL_LINES && opt->LineType > 0){
@@ -1004,7 +1053,7 @@ void drawArrays(PView *p, VertexArray *va, GLint type, bool useNormalArray)
   glDisable(GL_LIGHTING);
 }
 
-void drawVectorArray(PView *p, VertexArray *va)
+static void drawVectorArray(PView *p, VertexArray *va)
 {
   if(!va || va->getNumVerticesPerElement() != 2) return;
 
@@ -1044,7 +1093,7 @@ void drawVectorArray(PView *p, VertexArray *va)
   }
 }
 
-std::string stringValue(int numComp, double d[9], double norm, char *format)
+static std::string stringValue(int numComp, double d[9], double norm, char *format)
 {
   char label[100];
   if(numComp == 1)
@@ -1061,8 +1110,8 @@ std::string stringValue(int numComp, double d[9], double norm, char *format)
   return std::string(label);
 }
 
-void drawNumberGlyphs(PView *p, int numNodes, int numComp, 
-                      double xyz[NMAX][3], double val[NMAX][9])
+static void drawNumberGlyphs(PView *p, int numNodes, int numComp, 
+			     double xyz[NMAX][3], double val[NMAX][9])
 {
   PViewOptions *opt = p->getOptions();
   double d[9] = {0., 0., 0., 0., 0., 0., 0., 0., 0.};
@@ -1106,8 +1155,8 @@ void drawNumberGlyphs(PView *p, int numNodes, int numComp,
   }
 }
 
-void drawNormalVectorGlyphs(PView *p, int numNodes, double xyz[NMAX][3],
-                            double val[NMAX][9])
+static void drawNormalVectorGlyphs(PView *p, int numNodes, double xyz[NMAX][3],
+				   double val[NMAX][9])
 {
   PViewOptions *opt = p->getOptions();
 
@@ -1126,8 +1175,8 @@ void drawNormalVectorGlyphs(PView *p, int numNodes, double xyz[NMAX][3],
               pc[0], pc[1], pc[2], n[0], n[1], n[2], opt->Light);
 }
 
-void drawTangentVectorGlyphs(PView *p, int numNodes, double xyz[NMAX][3],
-                             double val[NMAX][9])
+static void drawTangentVectorGlyphs(PView *p, int numNodes, double xyz[NMAX][3],
+				    double val[NMAX][9])
 {
   PViewOptions *opt = p->getOptions();
 
@@ -1144,7 +1193,7 @@ void drawTangentVectorGlyphs(PView *p, int numNodes, double xyz[NMAX][3],
               pc[0], pc[1], pc[2], t[0], t[1], t[2], opt->Light);
 }
 
-void drawGlyphs(PView *p)
+static void drawGlyphs(PView *p)
 {
   // use adaptive data if available
   PViewData *data = p->getData(true);
@@ -1186,6 +1235,16 @@ class initPView {
   // we try to estimate how many primitives will end up in the vertex
   // arrays, since reallocating the arrays takes a huge amount of time
   // on Windows/Cygwin
+  int _estimateIfClipped(PView *p, int num)
+  {
+    if(CTX.clip_whole_elements && CTX.clip_only_draw_intersecting_volume){
+      for(int clip = 0; clip < 6; clip++){
+	if(CTX.clip[clip] & (1 << (2 + p->getIndex())))
+	  return (int)sqrt((double)num);
+      }
+    }
+    return num;
+  }
   int _estimateNumPoints(PView *p)
   {
     PViewData *data = p->getData(true);
@@ -1219,6 +1278,7 @@ class initPView {
     else if(opt->IntervalsType == PViewOptions::Discrete)
       heuristic = (tris + 2 * quads + 6 * tets + 
                    8 * prisms + 6 * pyrs + 12 * hexas) * 2;
+    heuristic = _estimateIfClipped(p, heuristic);
     return heuristic + 10000;
   }
   int _estimateNumVectors(PView *p)
@@ -1226,6 +1286,7 @@ class initPView {
     PViewData *data = p->getData(true);
     PViewOptions *opt = p->getOptions();
     int heuristic = data->getNumVectors(opt->TimeStep);
+    heuristic = _estimateIfClipped(p, heuristic);
     return heuristic + 1000;
   }
  public :
@@ -1280,7 +1341,7 @@ class initPView {
   }
 };
 
-bool eyeChanged(PView *p)
+static bool eyeChanged(PView *p)
 {
   double zeye = 100 * CTX.lc;
   SPoint3 tmp(CTX.rot[2] * zeye, CTX.rot[6] * zeye, CTX.rot[10] * zeye);
@@ -1313,12 +1374,14 @@ class drawPView {
     else
       glLightModelf(GL_LIGHT_MODEL_TWO_SIDE, GL_FALSE);
     
-    for(int i = 0; i < 6; i++)
-      if(CTX.clip[i] & (1 << (2 + p->getIndex()))) 
-        glEnable((GLenum)(GL_CLIP_PLANE0 + i));
-      else
-        glDisable((GLenum)(GL_CLIP_PLANE0 + i));
-    
+    if(!CTX.clip_whole_elements){
+      for(int i = 0; i < 6; i++)
+	if(CTX.clip[i] & (1 << (2 + p->getIndex())))
+	  glEnable((GLenum)(GL_CLIP_PLANE0 + i));
+	else
+	  glDisable((GLenum)(GL_CLIP_PLANE0 + i));
+    }
+
     if(CTX.alpha && ColorTable_IsAlpha(&opt->CT)){
       if(opt->FakeTransparency){
         // simple additive blending "a la xpost":
