@@ -1,23 +1,7 @@
-// $Id: SelectBuffer.cpp,v 1.22 2008-05-04 08:31:14 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "Message.h"
 #include "GmshUI.h"
@@ -48,7 +32,7 @@ class hitDepthLessThan{
 
 // returns the element at a given position in a vertex array (element
 // pointers are not always stored: returning 0 is not an error)
-MElement *getElement(GEntity *e, int va_type, int index)
+static MElement *getElement(GEntity *e, int va_type, int index)
 {
   switch(va_type){
   case 2: 
