@@ -1,23 +1,7 @@
-// $Id: HighOrder.cpp,v 1.31 2008-06-20 12:15:44 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "HighOrder.h"
 #include "meshGFaceOptimize.h"
@@ -29,6 +13,8 @@
 #include "GmshMatrix.h"
 #include "FunctionSpace.h"
 
+#define SQU(a)      ((a)*(a))
+
 extern Context_T CTX;
 
 // for each pair of vertices (an edge), we build a list of vertices
@@ -503,7 +489,6 @@ void getFaceVertices(GFace *gf,
           }
         }
       }
-      else throw; // not tri or quad
     }
   }  
 }
@@ -603,7 +588,6 @@ void getFaceVertices(GFace *gf, MElement *ele, std::vector<MVertex*> &vf,
           }
         }
       }
-      else throw; // not tri or quad
     }
   }
 }
@@ -646,11 +630,55 @@ void getFaceVertices(GRegion *gr, MElement *ele, std::vector<MVertex*> &vf,
           }
         }
       }
-      else throw; // not tri or quad
     }
   }
 }
 
+
+void getRegionVertices(GRegion *gr, 
+		       MElement *incomplete, 
+		       MElement *ele, 
+		       std::vector<MVertex*> &vr,
+		       bool linear, int nPts = 1)
+{
+
+  Double_Matrix points;
+  int start = 0;
+
+  switch (nPts){
+  case 3 :
+    points = gmshFunctionSpaces::find(MSH_TET_35).points;
+    start = 34;
+    break;
+  case 4 :
+    points = gmshFunctionSpaces::find(MSH_TET_56).points;
+    start = 52;
+    break;
+  default :  
+    return;
+    break;
+  }
+
+  for(int k = start ; k < points.size1() ; k++){
+    MVertex *v;
+    const double t1 = points(k, 0);
+    const double t2 = points(k, 1);
+    const double t3 = points(k, 2);
+    double X(0),Y(0),Z(0);
+    for (int j=0; j<incomplete->getNumVertices(); j++){
+      double sf ; incomplete->getShapeFunction(j,t1,t2,t3,sf);
+      MVertex *vt = incomplete->getVertex(j);
+      X += sf * vt->x();
+      Y += sf * vt->y();
+      Z += sf * vt->z();
+    }
+    v = new MVertex(X,Y,Z, gr);
+    gr->mesh_vertices.push_back(v);
+    vr.push_back(v);
+  }
+}
+
+
 void setHighOrder(GEdge *ge, edgeContainer &edgeVertices, bool linear, 
                   int nbPts = 1)
 {
@@ -737,7 +765,7 @@ void setHighOrder(GRegion *gr, edgeContainer &edgeVertices,
   std::vector<MTetrahedron*> tetrahedra2;
   for(unsigned int i = 0; i < gr->tetrahedra.size(); i++){
     MTetrahedron *t = gr->tetrahedra[i];
-    std::vector<MVertex*> ve,vf;
+    std::vector<MVertex*> ve,vf,vr;
     getEdgeVertices(gr, t, ve, edgeVertices, linear, nPts);
     if (nPts == 1){
       tetrahedra2.push_back
@@ -746,7 +774,11 @@ void setHighOrder(GRegion *gr, edgeContainer &edgeVertices,
     }
     else{
       getFaceVertices(gr, t, vf, faceVertices, linear, nPts);
-      ve.insert(ve.end(), vf.begin(), vf.end());      
+      ve.insert(ve.end(), vf.begin(), vf.end());     
+      MTetrahedronN incpl (t->getVertex(0), t->getVertex(1), t->getVertex(2), t->getVertex(3),
+			   ve, nPts + 1);
+      getRegionVertices(gr, &incpl, t, vr, linear, nPts); 
+      ve.insert(ve.end(), vr.begin(), vr.end());     
       tetrahedra2.push_back
 	(new MTetrahedronN(t->getVertex(0), t->getVertex(1), t->getVertex(2), t->getVertex(3),
 			   ve, nPts + 1));
@@ -913,15 +945,15 @@ static double mesh_functional_distorsion(MTriangle *t, double u, double v)
 {
   // compute uncurved element jacobian d_u x and d_v x
   double mat[2][3];  
-  t->jac(1, 0, 0, 0, 0,mat);
+  t->jac(1, 0, 0, 0, 0, mat);
   double v1[3] = {mat[0][0], mat[0][1], mat[0][2]};
   double v2[3] = {mat[1][0], mat[1][1], mat[1][2]};
   double normal1[3];
   prodve(v1, v2, normal1);
-  double nn = sqrt(DSQR(normal1[0]) + DSQR(normal1[1]) + DSQR(normal1[2]));
+  double nn = sqrt(SQU(normal1[0]) + SQU(normal1[1]) + SQU(normal1[2]));
   
   // compute uncurved element jacobian d_u x and d_v x
-  t->jac(u, v, 0,mat);
+  t->jac(u, v, 0, mat);
   double v1b[3] = {mat[0][0], mat[0][1], mat[0][2]};
   double v2b[3] = {mat[1][0], mat[1][1], mat[1][2]};
   double normal[3];
@@ -940,15 +972,15 @@ void getMinMaxJac (MTriangle *t, double &minJ, double &maxJ)
 {
   double mat[2][3];  
   int n = 3;
-  t->jac(1, 0, 0, 0, 0,mat);
+  t->jac(1, 0, 0, 0, 0, mat);
   double v1[3] = {mat[0][0], mat[0][1], mat[0][2]};
   double v2[3] = {mat[1][0], mat[1][1], mat[1][2]};
   double normal1[3], normal[3];
   prodve(v1, v2, normal1);
-  double nn = sqrt(DSQR(normal1[0]) + DSQR(normal1[1]) + DSQR(normal1[2]));
+  double nn = sqrt(SQU(normal1[0]) + SQU(normal1[1]) + SQU(normal1[2]));
   for(int i = 0; i < n; i++){
     for(int k = 0; k < n - i; k++){
-      t->jac((double)i / (n - 1), (double)k / (n - 1), 0,mat);
+      t->jac((double)i / (n - 1), (double)k / (n - 1), 0, mat);
       double v1b[3] = {mat[0][0], mat[0][1], mat[0][2]};
       double v2b[3] = {mat[1][0], mat[1][1], mat[1][2]};
       prodve(v1b, v2b, normal);
@@ -1063,8 +1095,14 @@ void optimizeNodeLocations(GFace *gf, smoothVertexDataHON &vdN, double eps = .2)
   if(!vdN.v.size()) return;
   double uv[20];
   for (unsigned int i = 0; i < vdN.v.size(); i++){
-    if (!vdN.v[i]->getParameter(0, uv[2 * i])) throw;
-    if (!vdN.v[i]->getParameter(1, uv[2 * i + 1])) throw;
+    if (!vdN.v[i]->getParameter(0, uv[2 * i])){
+      Msg::Error("Node location optimization failed");
+      return;
+    }
+    if (!vdN.v[i]->getParameter(1, uv[2 * i + 1])){
+      Msg::Error("Node location optimization failed");
+      return;
+    }
   }
 
   double F = -smooth_obj_HighOrderN(uv, &vdN);
@@ -1355,7 +1393,7 @@ void printJacobians(GModel *m, const char *nm)
 {
   return;
 
-  const int n = 5;
+  const int n = 15;
   double D[n][n];
   double X[n][n];
   double Y[n][n];
@@ -1371,8 +1409,8 @@ void printJacobians(GModel *m, const char *nm)
           SPoint3 pt;
           double u = (double)i / (n - 1);
           double v = (double)k / (n - 1);         
-          t->pnt(u,v,0, pt);        
-          D[i][k] = mesh_functional_distorsion (t,u,v);
+          t->pnt(u, v, 0, pt);
+          D[i][k] = mesh_functional_distorsion(t, u, v);
           X[i][k] = pt.x();
           Y[i][k] = pt.y();
           Z[i][k] = pt.z();
@@ -1420,9 +1458,14 @@ void SetOrderN(GModel *m, int order, bool linear, bool incomplete)
   //   edges (creating 8-node quads, 20-node hexas, etc., instead of
   //   9-node quads, 27-node hexas, etc.)
 
+#if !defined(HAVE_GSL)
+  Msg::Error("High order mesh generation requires the GSL");
+  return;
+#endif
+
   int nPts = order - 1;
 
-  Msg::StatusBar(1, true, "Meshing second order...");
+  Msg::StatusBar(1, true, "Generating High Order Nodes (q = %d) ...",order);
   double t1 = Cpu();
 
   // first, make sure to remove any existsing second order vertices/elements
