@@ -1,23 +1,7 @@
-// $Id: meshGEdge.cpp,v 1.64 2008-06-07 17:20:48 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <stdlib.h>
 #include "meshGEdge.h"
@@ -30,6 +14,8 @@
 #include "Context.h"
 #include "GModel.h"
 
+#define SQU(a)      ((a)*(a))
+
 extern Context_T CTX;
 
 typedef struct {
@@ -51,7 +37,7 @@ struct xi2lc {
 
 static std::vector<xi2lc> interpLc;
 
-void smoothInterpLc(int nbSmooth)
+static void smoothInterpLc(int nbSmooth)
 {
   for(int j = 0; j < nbSmooth; j++){
     for(int i = 0 ; i < (int)interpLc.size(); i++){               
@@ -65,7 +51,7 @@ void smoothInterpLc(int nbSmooth)
   } 
 }
 
-void printInterpLc(const char *name)
+static void printInterpLc(const char *name)
 {
   FILE *f = fopen(name,"w");
   for(unsigned int i = 0; i < interpLc.size(); i++){              
@@ -75,7 +61,7 @@ void printInterpLc(const char *name)
   fclose(f);
 }
 
-void buildInterpLc(List_T *lcPoints)
+static void buildInterpLc(List_T *lcPoints)
 {
   IntPoint p;
   interpLc.clear();
@@ -85,7 +71,7 @@ void buildInterpLc(List_T *lcPoints)
   }
 }
 
-double F_Lc_usingInterpLc(GEdge *ge, double t)
+static double F_Lc_usingInterpLc(GEdge *ge, double t)
 {
   std::vector<xi2lc>::iterator it = std::lower_bound(interpLc.begin(),
                                                      interpLc.end(), xi2lc(t, 0));
@@ -101,7 +87,7 @@ double F_Lc_usingInterpLc(GEdge *ge, double t)
   return d * l;
 }
 
-double F_Lc_usingInterpLcBis(GEdge *ge, double t)
+static double F_Lc_usingInterpLcBis(GEdge *ge, double t)
 {
   GPoint p = ge->point(t);
   double lc_here;
@@ -120,7 +106,7 @@ double F_Lc_usingInterpLcBis(GEdge *ge, double t)
   return 1 / lc_here;
 }
 
-double F_Lc(GEdge *ge, double t)
+static double F_Lc(GEdge *ge, double t)
 {
   GPoint p = ge->point(t);
   double lc_here;
@@ -141,7 +127,7 @@ double F_Lc(GEdge *ge, double t)
   return d / lc_here;
 }
 
-double F_Transfinite(GEdge *ge, double t)
+static double F_Transfinite(GEdge *ge, double t)
 {
   double val, r;
 
@@ -186,7 +172,7 @@ double F_Transfinite(GEdge *ge, double t)
             / ((double)nbpt * ge->length());
         }
         double b = -a * ge->length() * ge->length() / (4. * (coef - 1.));
-        val = d / (-a * DSQR(t * ge->length() - (ge->length()) * 0.5) + b);
+        val = d / (-a * SQU(t * ge->length() - (ge->length()) * 0.5) + b);
       }
       break;
       
@@ -199,20 +185,20 @@ double F_Transfinite(GEdge *ge, double t)
   return val;
 }
 
-double F_One(GEdge *ge, double t)
+static double F_One(GEdge *ge, double t)
 {
   SVector3 der = ge->firstDer(t) ;
   return norm(der);
 }
 
-double trapezoidal(IntPoint * P1, IntPoint * P2)
+static double trapezoidal(IntPoint * P1, IntPoint * P2)
 {
   return (0.5 * (P1->lc + P2->lc) * (P2->t - P1->t));
 }
 
-void RecursiveIntegration(GEdge *ge, IntPoint * from, IntPoint * to,
-                          double (*f) (GEdge *e, double X), List_T * pPoints,
-                          double Prec, int *depth)
+static void RecursiveIntegration(GEdge *ge, IntPoint * from, IntPoint * to,
+				 double (*f) (GEdge *e, double X), List_T * pPoints,
+				 double Prec, int *depth)
 {
   IntPoint P, p1;
 
@@ -243,9 +229,9 @@ void RecursiveIntegration(GEdge *ge, IntPoint * from, IntPoint * to,
   (*depth)--;
 }
 
-double Integration(GEdge *ge, double t1, double t2, 
-                   double (*f) (GEdge *e, double X),
-                   List_T * pPoints, double Prec)
+static double Integration(GEdge *ge, double t1, double t2, 
+			  double (*f) (GEdge *e, double X),
+			  List_T * pPoints, double Prec)
 {
   IntPoint from, to;
 
@@ -275,19 +261,23 @@ void deMeshGEdge::operator() (GEdge *ge)
     delete ge->lines[i];
   ge->lines.clear();
   ge->deleteVertexArrays();
+  ge->model()->destroyMeshCaches();
 }
 
 void meshGEdge::operator() (GEdge *ge) 
 {  
+  ge->model()->setCurrentMeshEntity(ge);
+
   if(ge->geomType() == GEntity::DiscreteCurve) return;
   if(ge->geomType() == GEntity::BoundaryLayerCurve) return;
+  if(ge->meshAttributes.Method == MESH_NONE) return;
 
   deMeshGEdge dem;
   dem(ge);
 
   if(MeshExtrudedCurve(ge)) return;
 
-  Msg::Info("Meshing curve %d (%s)", ge->tag(),ge->getTypeString().c_str());
+  Msg::Info("Meshing curve %d (%s)", ge->tag(), ge->getTypeString().c_str());
 
   // Create a list of integration points
   List_T *Points = List_Create(10, 10, sizeof(IntPoint));
@@ -303,7 +293,6 @@ void meshGEdge::operator() (GEdge *ge)
   double length = Integration(ge, t_begin, t_end, F_One, Points, 1.e-8 * CTX.lc);
   ge->setLength(length);
 
-
   if(length == 0.0)
     Msg::Debug("Curve %d has a zero length", ge->tag());
   
@@ -316,7 +305,7 @@ void meshGEdge::operator() (GEdge *ge)
     a = 0.;
     N = 1;
   }
-  else if(ge->meshAttributes.Method == TRANSFINI){
+  else if(ge->meshAttributes.Method == MESH_TRANSFINITE){
     a = Integration(ge, t_begin, t_end, F_Transfinite, Points, 1.e-8);
     N = ge->meshAttributes.nbPointsTransfinite;
   }
