@@ -1,23 +1,7 @@
-// $Id: meshGFace.cpp,v 1.136 2008-06-10 08:37:34 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-//
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <stdlib.h>
 #include "meshGFace.h"
@@ -60,7 +44,7 @@ void fourthPoint(double *p1, double *p2, double *p3, double *p4)
   p4[2] = c[2] + R * vz[2];
 }
 
-bool noseam(GFace *gf)
+static bool noseam(GFace *gf)
 {
   std::list<GEdge*> edges = gf->edges();
   std::list<GEdge*>::iterator it = edges.begin();
@@ -73,8 +57,8 @@ bool noseam(GFace *gf)
   return true;
 }
 
-void remeshUnrecoveredEdges(std::set<EdgeToRecover> &edgesNotRecovered, 
-                            std::list<GFace*> &facesToRemesh)
+static void remeshUnrecoveredEdges(std::set<EdgeToRecover> &edgesNotRecovered, 
+				   std::list<GFace*> &facesToRemesh)
 {
   facesToRemesh.clear();
   deMeshGFace dem;
@@ -156,17 +140,17 @@ void remeshUnrecoveredEdges(std::set<EdgeToRecover> &edgesNotRecovered,
   }
 }
 
-bool AlgoDelaunay2D(GFace *gf)
+static bool AlgoDelaunay2D(GFace *gf)
 {
-  if(noseam(gf) && /*gf->getNativeType() == GEntity::GmshModel &&*/ 
-     (CTX.mesh.algo2d == ALGO_2D_DELAUNAY || CTX.mesh.algo2d == ALGO_2D_FRONTAL) /*&& gf->geomType() == GEntity::Plane*/)
+  if(noseam(gf) && (CTX.mesh.algo2d == ALGO_2D_DELAUNAY || 
+		    CTX.mesh.algo2d == ALGO_2D_FRONTAL))
     return true;
   return false;
 }
 
 void computeEdgeLoops(const GFace *gf,
-                      std::vector<MVertex*> &all_mvertices,
-                      std::vector<int> &indices)
+		      std::vector<MVertex*> &all_mvertices,
+		      std::vector<int> &indices)
 {
   std::list<GEdge*> edges = gf->edges();
   std::list<int> ori = gf->orientations();
@@ -196,9 +180,15 @@ void computeEdgeLoops(const GFace *gf,
       v_start = start;
     }
     else{
-      if(it == edges.end ()) throw;
+      if(it == edges.end ()){
+	Msg::Error("Something wrong in edge loop computation");
+	return;
+      }
       v_start = ((*ito) == 1) ? (*it)->getBeginVertex() : (*it)->getEndVertex();
-      if(v_start != v_end) throw;
+      if(v_start != v_end){
+	Msg::Error("Something wrong in edge loop computation");
+	return;
+      }
       v_end = ((*ito) != 1) ? (*it)->getBeginVertex() : (*it)->getEndVertex();
     }
     all_mvertices.push_back(v_start->mesh_vertices[0]);
@@ -230,8 +220,8 @@ void computeElementShapes(GFace *gf, double &worst, double &avg, double &best,
   avg /= nT;
 }
 
-bool recover_medge(BDS_Mesh *m, GEdge *ge, std::set<EdgeToRecover> *e2r, 
-                   std::set<EdgeToRecover> *not_recovered, int pass_)
+static bool recover_medge(BDS_Mesh *m, GEdge *ge, std::set<EdgeToRecover> *e2r, 
+			  std::set<EdgeToRecover> *not_recovered, int pass_)
 {
   BDS_GeomEntity *g = 0;
   if (pass_ == 2){
@@ -329,7 +319,7 @@ bool recover_medge(BDS_Mesh *m, GEdge *ge, std::set<EdgeToRecover> *e2r,
 // Builds An initial triangular mesh that respects the boundaries of
 // the domain, including embedded points and surfaces
 
-bool gmsh2DMeshGenerator(GFace *gf, int RECUR_ITER, bool debug = true)
+static bool gmsh2DMeshGenerator(GFace *gf, int RECUR_ITER, bool debug = true)
 {
   BDS_GeomEntity CLASS_F (1, 2);
   typedef std::set<MVertex*> v_container;
@@ -747,14 +737,14 @@ bool gmsh2DMeshGenerator(GFace *gf, int RECUR_ITER, bool debug = true)
 // case of periodicty, some curves are present 2 times in the wire
 // (seams). Those must be meshed separately
 
-inline double dist2 (const SPoint2 &p1,const SPoint2 &p2)
+static inline double dist2(const SPoint2 &p1, const SPoint2 &p2)
 {
   const double dx = p1.x() - p2.x();
   const double dy = p1.y() - p2.y();
   return dx*dx+dy*dy;
 }
 
-void printMesh1d (int iEdge, int seam, std::vector<SPoint2> &m)
+static void printMesh1d(int iEdge, int seam, std::vector<SPoint2> &m)
 {
   printf("Mesh1D for edge %d seam %d\n", iEdge, seam);
   for (unsigned int i = 0; i < m.size(); i++){
@@ -762,12 +752,12 @@ void printMesh1d (int iEdge, int seam, std::vector<SPoint2> &m)
   }
 }
 
-bool buildConsecutiveListOfVertices(GFace *gf, GEdgeLoop  &gel,
-                                    std::vector<BDS_Point*> &result,
-                                    SBoundingBox3d &bbox, BDS_Mesh *m,
-                                    std::map<BDS_Point*, MVertex*> &recover_map_global,
-                                    int &count, int countTot, double tol,
-                                    bool seam_the_first = false)
+static bool buildConsecutiveListOfVertices(GFace *gf, GEdgeLoop  &gel,
+					   std::vector<BDS_Point*> &result,
+					   SBoundingBox3d &bbox, BDS_Mesh *m,
+					   std::map<BDS_Point*, MVertex*> &recover_map_global,
+					   int &count, int countTot, double tol,
+					   bool seam_the_first = false)
 {
   // for each edge, we build a list of points that are the mapping of
   // the edge points on the face for seams, we build the list for
@@ -986,7 +976,7 @@ bool buildConsecutiveListOfVertices(GFace *gf, GEdgeLoop  &gel,
   return true;
 }
 
-bool gmsh2DMeshGeneratorPeriodic(GFace *gf, bool debug = true)
+static bool gmsh2DMeshGeneratorPeriodic(GFace *gf, bool debug = true)
 {
   std::map<BDS_Point*,MVertex*> recover_map;
 
@@ -1286,6 +1276,7 @@ void deMeshGFace::operator() (GFace *gf)
   for (unsigned int i=0;i<gf->quadrangles.size();i++) delete gf->quadrangles[i];
   gf->quadrangles.clear();
   gf->deleteVertexArrays();
+  gf->model()->destroyMeshCaches();
 
   gf->meshStatistics.status = GFace::PENDING;
   gf->meshStatistics.nbTriangle = gf->meshStatistics.nbEdge = 0;
@@ -1295,6 +1286,8 @@ const int debugSurface = -1;
 
 void meshGFace::operator() (GFace *gf)
 {
+  gf->model()->setCurrentMeshEntity(gf);
+
   if (debugSurface >= 0 && gf->tag() != debugSurface){
     gf->meshStatistics.status = GFace::DONE;
     return;
@@ -1303,6 +1296,7 @@ void meshGFace::operator() (GFace *gf)
   if(gf->geomType() == GEntity::DiscreteSurface) return;
   if(gf->geomType() == GEntity::BoundaryLayerSurface) return;
   if(gf->geomType() == GEntity::ProjectionFace) return;
+  if(gf->meshAttributes.Method == MESH_NONE) return;
 
   // destroy the mesh if it exists
   deMeshGFace dem;
@@ -1345,7 +1339,7 @@ void meshGFace::operator() (GFace *gf)
 }
 
 template<class T>
-bool shouldRevert(MEdge &reference, std::vector<T*> &elements)
+static bool shouldRevert(MEdge &reference, std::vector<T*> &elements)
 {
   for(unsigned int i = 0; i < elements.size(); i++){
     for(int j = 0; j < elements[i]->getNumEdges(); j++){
@@ -1365,6 +1359,8 @@ bool shouldRevert(MEdge &reference, std::vector<T*> &elements)
 
 void orientMeshGFace::operator()(GFace *gf)
 {
+  gf->model()->setCurrentMeshEntity(gf);
+
   if(gf->geomType() == GEntity::ProjectionFace) return;
 
   // surface orientions in OCC are not consistent with the orientation
@@ -1373,7 +1369,7 @@ void orientMeshGFace::operator()(GFace *gf)
 
   // in old versions we did not reorient transfinite surface meshes;
   // we could add the following to provide backward compatibility:
-  // if(gf->meshAttributes.Method == TRANSFINI) return;
+  // if(gf->meshAttributes.Method == MESH_TRANSFINITE) return;
 
   // orients the mesh to match the orientation of the first edge
   std::list<GEdge*> edges = gf->edges();
