@@ -1,23 +1,7 @@
-// $Id: meshGFaceExtruded.cpp,v 1.30 2008-05-06 21:11:48 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <set>
 #include "GModel.h"
@@ -28,8 +12,8 @@
 
 extern Context_T CTX;
 
-void createQuaTri(std::vector<MVertex*> &v, GFace *to,
-                  std::set<std::pair<MVertex*, MVertex*> > *constrainedEdges)
+static void createQuaTri(std::vector<MVertex*> &v, GFace *to,
+			 std::set<std::pair<MVertex*, MVertex*> > *constrainedEdges)
 {
   ExtrudeParams *ep = to->meshAttributes.extrude;
 
@@ -61,9 +45,9 @@ void createQuaTri(std::vector<MVertex*> &v, GFace *to,
   }
 }
 
-void extrudeMesh(GEdge *from, GFace *to,
-                 std::set<MVertex*, MVertexLessThanLexicographic> &pos,
-                 std::set<std::pair<MVertex*, MVertex*> > *constrainedEdges)
+static void extrudeMesh(GEdge *from, GFace *to,
+			std::set<MVertex*, MVertexLessThanLexicographic> &pos,
+			std::set<std::pair<MVertex*, MVertex*> > *constrainedEdges)
 {
   ExtrudeParams *ep = to->meshAttributes.extrude;
 
@@ -122,8 +106,8 @@ void extrudeMesh(GEdge *from, GFace *to,
   }
 }
 
-void copyMesh(GFace *from, GFace *to,
-              std::set<MVertex*, MVertexLessThanLexicographic> &pos)
+static void copyMesh(GFace *from, GFace *to,
+		     std::set<MVertex*, MVertexLessThanLexicographic> &pos)
 {
   ExtrudeParams *ep = to->meshAttributes.extrude;
 
