@@ -1,23 +1,7 @@
-// $Id: meshGFaceOptimize.cpp,v 1.15 2008-03-26 20:32:40 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "meshGFaceOptimize.h"
 #include "qualityMeasures.h"
@@ -27,6 +11,7 @@
 #include "MVertex.h"
 #include "MElement.h"
 #include "BackgroundMesh.h"
+#include "Message.h"
 
 static void setLcsInit(MTriangle *t, std::map<MVertex*, double> &vSizes)
 {
@@ -325,7 +310,8 @@ bool gmshEdgeSwap(std::set<swapquad> &configs, MTri3 *t1, GFace *gf, int iLocalE
     }
     break;
   default :
-    throw;
+    Msg::Error("Unknown swapping criterion");
+    return false;
   }
 
   std::list<MTri3*> cavity;
@@ -453,7 +439,8 @@ bool gmshEdgeSplit(const double lMax, MTri3 *t1, GFace *gf, int iLocalEdge,
   case SPCR_ALLWAYS:
     break;
   default :
-    throw;
+    Msg::Error("Unknown swapping criterion");
+    return false;
   }
 
   gf->mesh_vertices.push_back(vnew);
@@ -584,7 +571,10 @@ bool gmshBuildVertexCavity(MTri3 *t, int iLocalVertex, MVertex **v1,
           return true;
         }
         if (!t) return false;
-        if (t->isDeleted()){ printf("weird\n"); throw; }  
+        if (t->isDeleted()){ 
+	  Msg::Error("Impossible to build vertex cavity");
+	  return false;
+	}  
         cavity.push_back(t);
         for (int j = 0; j < 3; j++){
           if (t->tri()->getVertex(j) !=lastinring && t->tri()->getVertex(j) != *v1){
@@ -596,7 +586,10 @@ bool gmshBuildVertexCavity(MTri3 *t, int iLocalVertex, MVertex **v1,
         break;
       }
     }
-    if (iEdge == -1) { printf("not found\n"); throw; }
+    if (iEdge == -1) {
+      Msg::Error("Impossible to build vertex cavity");
+      return false;
+    }
   }
 }
 
