@@ -1,23 +1,7 @@
-// $Id: meshGFaceTransfinite.cpp,v 1.28 2008-05-06 21:11:48 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <map>
 #include "meshGFace.h"
@@ -30,6 +14,8 @@
 #include "Message.h"
 #include "Numeric.h"
 
+#define SQU(a)      ((a)*(a))
+
 extern Context_T CTX;
 
 /*
@@ -53,7 +39,7 @@ extern Context_T CTX;
 
 int MeshTransfiniteSurface(GFace *gf)
 {
-  if(gf->meshAttributes.Method != TRANSFINI) return 0;
+  if(gf->meshAttributes.Method != MESH_TRANSFINITE) return 0;
 
   Msg::StatusBar(2, true, "Meshing surface %d (transfinite)", gf->tag());
 
@@ -318,12 +304,12 @@ int MeshTransfiniteSurface(GFace *gf)
           MVertex *v31 = tab[i + 1][j - 1];
           MVertex *v32 = tab[i + 1][j    ];
           MVertex *v33 = tab[i + 1][j + 1];
-          double alpha = 0.25 * (DSQR(v23->x() - v21->x()) +
-                                 DSQR(v23->y() - v21->y()) +
-                                 DSQR(v23->z() - v21->z()));
-          double gamma = 0.25 * (DSQR(v32->x() - v12->x()) +
-                                 DSQR(v32->y() - v12->y()) +
-                                 DSQR(v32->z() - v12->z()));
+          double alpha = 0.25 * (SQU(v23->x() - v21->x()) +
+                                 SQU(v23->y() - v21->y()) +
+                                 SQU(v23->z() - v21->z()));
+          double gamma = 0.25 * (SQU(v32->x() - v12->x()) +
+                                 SQU(v32->y() - v12->y()) +
+                                 SQU(v32->z() - v12->z()));
           double beta = 0.0625 * ((v32->x() - v12->x()) * (v23->x() - v21->x()) +
                                   (v32->y() - v12->y()) * (v23->y() - v21->y()) +
                                   (v32->z() - v12->z()) * (v23->z() - v21->z()));
