@@ -1,23 +1,7 @@
-// $Id: meshGRegion.cpp,v 1.54 2008-06-20 12:15:44 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <stdlib.h>
 #include <vector>
@@ -428,6 +412,7 @@ void deMeshGRegion::operator() (GRegion *gr)
     delete gr->pyramids[i];
   gr->pyramids.clear();
   gr->deleteVertexArrays();
+  gr->model()->destroyMeshCaches();
 }
 
 int intersect_line_triangle(double X[3], double Y[3], double Z[3] , 
@@ -555,7 +540,10 @@ void meshNormalsPointOutOfTheRegion(GRegion *gr)
 
 void meshGRegion::operator() (GRegion *gr) 
 {  
+  gr->model()->setCurrentMeshEntity(gr);
+
   if(gr->geomType() == GEntity::DiscreteVolume) return;
+  if(gr->meshAttributes.Method == MESH_NONE) return;
 
   ExtrudeParams *ep = gr->meshAttributes.extrude;
 
@@ -565,10 +553,7 @@ void meshGRegion::operator() (GRegion *gr)
   deMeshGRegion dem;
   dem(gr);
 
-  if(gr->meshAttributes.Method == TRANSFINI){
-    MeshTransfiniteVolume(gr);
-    return;
-  }
+  if(MeshTransfiniteVolume(gr)) return;
   
   std::list<GFace*> faces = gr->faces();
 
@@ -602,10 +587,12 @@ void meshGRegion::operator() (GRegion *gr)
 
 void optimizeMeshGRegionNetgen::operator() (GRegion *gr) 
 {  
+  gr->model()->setCurrentMeshEntity(gr);
+
   if(gr->geomType() == GEntity::DiscreteVolume) return;
   
   // don't optimize transfinite or extruded meshes
-  if(gr->meshAttributes.Method == TRANSFINI) return;
+  if(gr->meshAttributes.Method == MESH_TRANSFINITE) return;
   ExtrudeParams *ep = gr->meshAttributes.extrude;
   if(ep && ep->mesh.ExtrudeMesh && ep->geo.Mode == EXTRUDED_ENTITY) return;
 
@@ -629,10 +616,12 @@ void optimizeMeshGRegionNetgen::operator() (GRegion *gr)
 
 void optimizeMeshGRegionGmsh::operator() (GRegion *gr) 
 {  
+  gr->model()->setCurrentMeshEntity(gr);
+
   if(gr->geomType() == GEntity::DiscreteVolume) return;
   
   // don't optimize extruded meshes
-  if(gr->meshAttributes.Method == TRANSFINI) return;
+  if(gr->meshAttributes.Method == MESH_TRANSFINITE) return;
   ExtrudeParams *ep = gr->meshAttributes.extrude;
   if(ep && ep->mesh.ExtrudeMesh && ep->geo.Mode == EXTRUDED_ENTITY) return;
   
