@@ -1,23 +1,7 @@
-// $Id: meshGRegionExtruded.cpp,v 1.26 2008-05-06 21:11:48 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include <set>
 #include "GModel.h"
@@ -30,7 +14,7 @@
 
 extern Context_T CTX;
 
-void createPriPyrTet(std::vector<MVertex*> &v, GRegion *to)
+static void createPriPyrTet(std::vector<MVertex*> &v, GRegion *to)
 {
   int dup[3];
   int j = 0;
@@ -60,7 +44,7 @@ void createPriPyrTet(std::vector<MVertex*> &v, GRegion *to)
   }
 }
 
-void createHexPri(std::vector<MVertex*> &v, GRegion *to)
+static void createHexPri(std::vector<MVertex*> &v, GRegion *to)
 {
   int dup[4];
   int j = 0;
@@ -86,15 +70,15 @@ void createHexPri(std::vector<MVertex*> &v, GRegion *to)
   }
 }
 
-void createTet(MVertex *v1, MVertex *v2, MVertex *v3, MVertex *v4, GRegion *to)
+static void createTet(MVertex *v1, MVertex *v2, MVertex *v3, MVertex *v4, GRegion *to)
 {
   if(v1 != v2 && v1 != v3 && v1 != v4 && v2 != v3 && v2 != v4 && v3 != v4)
     to->tetrahedra.push_back(new MTetrahedron(v1, v2, v3, v4));
 }
 
-int getExtrudedVertices(MElement *ele, ExtrudeParams *ep, int j, int k, 
-                        std::set<MVertex*, MVertexLessThanLexicographic> &pos,
-                        std::vector<MVertex*> &verts)
+static int getExtrudedVertices(MElement *ele, ExtrudeParams *ep, int j, int k, 
+			       std::set<MVertex*, MVertexLessThanLexicographic> &pos,
+			       std::vector<MVertex*> &verts)
 {
   std::set<MVertex*, MVertexLessThanLexicographic>::iterator itp;
   double x[8], y[8], z[8];
@@ -125,8 +109,8 @@ int getExtrudedVertices(MElement *ele, ExtrudeParams *ep, int j, int k,
   return verts.size();
 }
 
-void extrudeMesh(GFace *from, GRegion *to,
-                 std::set<MVertex*, MVertexLessThanLexicographic> &pos)
+static void extrudeMesh(GFace *from, GRegion *to,
+			std::set<MVertex*, MVertexLessThanLexicographic> &pos)
 {
   ExtrudeParams *ep = to->meshAttributes.extrude;
 
@@ -169,8 +153,8 @@ void extrudeMesh(GFace *from, GRegion *to,
   }
 }
 
-void insertAllVertices(GRegion *gr, 
-                       std::set<MVertex*, MVertexLessThanLexicographic> &pos)
+static void insertAllVertices(GRegion *gr, 
+			      std::set<MVertex*, MVertexLessThanLexicographic> &pos)
 {
   pos.insert(gr->mesh_vertices.begin(), gr->mesh_vertices.end());
   std::list<GFace*> faces = gr->faces();
@@ -193,6 +177,8 @@ void insertAllVertices(GRegion *gr,
 
 void meshGRegionExtruded::operator() (GRegion *gr) 
 {  
+  gr->model()->setCurrentMeshEntity(gr);
+
   if(gr->geomType() == GEntity::DiscreteVolume) return;
 
   ExtrudeParams *ep = gr->meshAttributes.extrude;
@@ -231,31 +217,31 @@ void meshGRegionExtruded::operator() (GRegion *gr)
   MVertexLessThanLexicographic::tolerance = old_tol; 
 }
 
-int edgeExists(MVertex *v1, MVertex *v2, 
-              std::set<std::pair<MVertex*, MVertex*> > &edges)
+static int edgeExists(MVertex *v1, MVertex *v2, 
+		      std::set<std::pair<MVertex*, MVertex*> > &edges)
 {
   std::pair<MVertex*, MVertex*> p(std::min(v1, v2), std::max(v1, v2));
   return edges.count(p);
 }
 
-void createEdge(MVertex *v1, MVertex *v2, 
-              std::set<std::pair<MVertex*, MVertex*> > &edges)
+static void createEdge(MVertex *v1, MVertex *v2, 
+		       std::set<std::pair<MVertex*, MVertex*> > &edges)
 {
   std::pair<MVertex*, MVertex*> p(std::min(v1, v2), std::max(v1, v2));
   edges.insert(p);
 }
 
-void deleteEdge(MVertex *v1, MVertex *v2, 
-              std::set<std::pair<MVertex*, MVertex*> > &edges)
+static void deleteEdge(MVertex *v1, MVertex *v2, 
+		       std::set<std::pair<MVertex*, MVertex*> > &edges)
 {
   std::pair<MVertex*, MVertex*> p(std::min(v1, v2), std::max(v1, v2));
   edges.erase(p);
 }
 
 // subdivide the 3 lateral faces of each prism
-void phase1(GRegion *gr,
-            std::set<MVertex*, MVertexLessThanLexicographic> &pos,
-            std::set<std::pair<MVertex*, MVertex*> > &edges)
+static void phase1(GRegion *gr,
+		   std::set<MVertex*, MVertexLessThanLexicographic> &pos,
+		   std::set<std::pair<MVertex*, MVertex*> > &edges)
 {
   ExtrudeParams *ep = gr->meshAttributes.extrude;
   GFace *from = gr->model()->getFaceByTag(std::abs(ep->geo.Source));
@@ -288,11 +274,11 @@ void phase1(GRegion *gr,
 }
 
 // modify lateral edges to make them "tet-compatible"
-void phase2(GRegion *gr,
-            std::set<MVertex*, MVertexLessThanLexicographic> &pos,
-            std::set<std::pair<MVertex*, MVertex*> > &edges,
-            std::set<std::pair<MVertex*, MVertex*> > &edges_swap,
-            int &swap)
+static void phase2(GRegion *gr,
+		   std::set<MVertex*, MVertexLessThanLexicographic> &pos,
+		   std::set<std::pair<MVertex*, MVertex*> > &edges,
+		   std::set<std::pair<MVertex*, MVertex*> > &edges_swap,
+		   int &swap)
 {
   ExtrudeParams *ep = gr->meshAttributes.extrude;
   GFace *from = gr->model()->getFaceByTag(std::abs(ep->geo.Source));
@@ -356,9 +342,9 @@ void phase2(GRegion *gr,
 }
  
 // create tets
-void phase3(GRegion *gr,
-            std::set<MVertex*, MVertexLessThanLexicographic> &pos,
-            std::set<std::pair<MVertex*, MVertex*> > &edges)
+static void phase3(GRegion *gr,
+		   std::set<MVertex*, MVertexLessThanLexicographic> &pos,
+		   std::set<std::pair<MVertex*, MVertex*> > &edges)
 {
   ExtrudeParams *ep = gr->meshAttributes.extrude;
   GFace *from = gr->model()->getFaceByTag(std::abs(ep->geo.Source));
