@@ -1,26 +1,11 @@
-// $Id: FunctionSpace.cpp,v 1.6 2008-06-10 08:37:34 remacle Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "FunctionSpace.h"
 #include "GmshDefines.h"
+#include "Message.h"
 
 Double_Matrix generatePascalTriangle(int order)
 {
@@ -324,7 +309,7 @@ Double_Matrix gmshGeneratePointsTetrahedron(int order, bool serendip)
   
   Double_Matrix point(nbPoints, 3);
 
-  double overOrder = 1. / order;
+  double overOrder = (order == 0 ? 1. : 1. / order);
 
   point(0, 0) = 0.;
   point(0, 1) = 0.;
@@ -342,25 +327,31 @@ Double_Matrix gmshGeneratePointsTetrahedron(int order, bool serendip)
     point(3, 0) = 0.;
     point(3, 1) = 0.;
     point(3, 2) = order;
+
+    // edges e5 and e6 switched in original version
     
     if (order > 1) {
       for (int k = 0; k < (order - 1); k++) {
         point(4 + k, 0) = k + 1;
-        point(4 + order - 1 + k, 0) = order - 1 - k;
+        point(4 +      order - 1  + k, 0) = order - 1 - k;
         point(4 + 2 * (order - 1) + k, 0) = 0.; 
         point(4 + 3 * (order - 1) + k, 0) = 0.;
-        point(4 + 4 * (order - 1) + k, 0) = order - 1 - k;
-        point(4 + 5 * (order - 1) + k, 0) = 0.;
+        // point(4 + 4 * (order - 1) + k, 0) = order - 1 - k;
+        // point(4 + 5 * (order - 1) + k, 0) = 0.;
+        point(4 + 4 * (order - 1) + k, 0) = 0.;
+        point(4 + 5 * (order - 1) + k, 0) = order - 1 - k;
         
         point(4 + k, 1) = 0.;
-        point(4 + order - 1 + k, 1) = k + 1;
+        point(4 +      order - 1  + k, 1) = k + 1;
         point(4 + 2 * (order - 1) + k, 1) = order - 1 - k; 
         point(4 + 3 * (order - 1) + k, 1) = 0.;
-        point(4 + 4 * (order - 1) + k, 1) = 0.;
-        point(4 + 5 * (order - 1) + k, 1) = order - 1 - k;
+        //         point(4 + 4 * (order - 1) + k, 1) = 0.;
+        //         point(4 + 5 * (order - 1) + k, 1) = order - 1 - k;
+        point(4 + 4 * (order - 1) + k, 1) = order - 1 - k;
+        point(4 + 5 * (order - 1) + k, 1) = 0.;
         
         point(4 + k, 2) = 0.;
-        point(4 + order - 1 + k, 2) = 0.;
+        point(4 +      order - 1  + k, 2) = 0.;
         point(4 + 2 * (order - 1) + k, 2) = 0.; 
         point(4 + 3 * (order - 1) + k, 2) = k + 1;
         point(4 + 4 * (order - 1) + k, 2) = k + 1;
@@ -497,8 +488,10 @@ Double_Matrix gmshGeneratePointsTriangle(int order, bool serendip)
 Double_Matrix generateLagrangeMonomialCoefficients(const Double_Matrix& monomial,
                                                    const Double_Matrix& point) 
 {
-  if (monomial.size1() != point.size1()) throw;
-  if (monomial.size2() != point.size2()) throw;
+  if(monomial.size1() != point.size1() || monomial.size2() != point.size2()){
+    Msg::Fatal("Wrong sizes for Lagrange coefficients generation");
+    return Double_Matrix(1, 1);
+  }
   
   int ndofs = monomial.size1();
   int dim   = monomial.size2();
@@ -517,7 +510,10 @@ Double_Matrix generateLagrangeMonomialCoefficients(const Double_Matrix& monomial
   
   double det = Vandermonde.determinant();
 
-  if (det == 0.0) throw;
+  if (det == 0.0){
+    Msg::Fatal("Vandermonde matrix has zero determinant!?");
+    return Double_Matrix(1, 1);
+  }
 
   Double_Matrix coefficient(ndofs, ndofs);
   
@@ -587,7 +583,7 @@ const gmshFunctionSpace &gmshFunctionSpaces::find(int tag)
     break;
   case MSH_TET_4 :
     F.monomials = generatePascalTetrahedron(1);
-    F.points =    gmshGeneratePointsTetrahedron(5, false);
+    F.points =    gmshGeneratePointsTetrahedron(1, false);
     break;
   case MSH_TET_10 :
     F.monomials = generatePascalTetrahedron(2);
@@ -601,12 +597,23 @@ const gmshFunctionSpace &gmshFunctionSpaces::find(int tag)
     F.monomials = generatePascalTetrahedron(4);
     F.points =    gmshGeneratePointsTetrahedron(4, false);
     break;
+  case MSH_TET_34 :
+    F.monomials = generatePascalSerendipityTetrahedron(4);
+    F.points =    gmshGeneratePointsTetrahedron(4, true);
+    break;
+  case MSH_TET_52 :
+    F.monomials = generatePascalSerendipityTetrahedron(5);
+    F.points =    gmshGeneratePointsTetrahedron(5, true);
+    break;
   case MSH_TET_56 :
     F.monomials = generatePascalTetrahedron(5);
     F.points =    gmshGeneratePointsTetrahedron(5, false);
     break;
   default :
-    throw;
+    Msg::Error("Unknown function space %d: reverting to TET_4", tag);
+    F.monomials = generatePascalTetrahedron(1);
+    F.points =    gmshGeneratePointsTetrahedron(1, false);
+    break;
   }  
   F.coefficients = generateLagrangeMonomialCoefficients(F.monomials, F.points);
   fs.insert(std::make_pair(tag, F));
