@@ -1,27 +1,13 @@
-// $Id: ExtractElements.cpp,v 1.14 2008-05-04 08:31:23 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 
 #include "ExtractElements.h"
 #include "Numeric.h"
 
+#define SQU(a)      ((a)*(a))
+
 StringXNumber ExtractElementsOptions_Number[] = {
   {GMSH_FULLRC, "MinVal", NULL, 0.},
   {GMSH_FULLRC, "MaxVal", NULL, 1.},
@@ -93,7 +79,7 @@ static void extract(List_T *inList, int inNb,
         d += v[0];
         break;
       case 3 : // vector
-        d += sqrt(DSQR(v[0]) + DSQR(v[1]) + DSQR(v[2]));
+        d += sqrt(SQU(v[0]) + SQU(v[1]) + SQU(v[2]));
         break;
       case 9 : // tensor
         d += ComputeVonMises(v);
