@@ -1,23 +1,7 @@
-// $Id: PViewDataList.cpp,v 1.26 2008-06-04 05:32:42 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 //
 // Contributor(s):
 // 
@@ -213,7 +197,13 @@ void PViewDataList::_stat(List_T *D, List_T *C, int nb)
 void PViewDataList::_stat(List_T *list, int nbcomp, int nbelm, int nbnod, int nbedg)
 {
   // compute statistics for element lists
-  if(!nbelm) return;
+  if(!nbelm) return;  
+
+  if(haveInterpolationScheme()){
+    std::vector<List_T *> is;
+    if(getInterpolationScheme(nbedg, is) == 4)
+      nbnod = List_Nbr(is[2]);
+  }
 
   int nbval = nbcomp * nbnod;
 
@@ -267,6 +257,12 @@ void PViewDataList::_stat(List_T *list, int nbcomp, int nbelm, int nbnod, int nb
 void PViewDataList::_setLast(int ele, int dim, int nbnod, int nbcomp, int nbedg,
                              List_T *list, int nblist)
 {
+  if(haveInterpolationScheme()){
+    std::vector<List_T *> is;
+    if(getInterpolationScheme(nbedg, is) == 4)
+      nbnod = List_Nbr(is[2]);
+  }
+
   _lastDimension = dim;
   _lastNumNodes = nbnod;
   _lastNumComponents = nbcomp;
