@@ -1,23 +1,7 @@
-// $Id: PViewDataListIO.cpp,v 1.20 2008-05-04 08:31:24 geuzaine Exp $
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
 //
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
 //
 // Contributor(s):
 // 
@@ -28,6 +12,7 @@
 #include "Numeric.h"
 #include "Message.h"
 #include "Context.h"
+#include "adaptiveData.h"
 
 extern Context_T CTX;
 
@@ -318,6 +303,11 @@ static void writeTextPOS(FILE *fp, int nbc, int nb, List_T *TD, List_T *TC)
 
 bool PViewDataList::writePOS(std::string fileName, bool binary, bool parsed, bool append)
 {
+
+  if ( _adaptive ){
+    return _adaptive->getData()->writePOS (fileName,binary,parsed,append);
+  }
+
   FILE *fp = fopen(fileName.c_str(), 
                    append ? (binary ? "ab" : "a") : (binary ? "wb" : "w"));
   if(!fp){
@@ -338,7 +328,10 @@ bool PViewDataList::writePOS(std::string fileName, bool binary, bool parsed, boo
 
   if(!parsed){
     fprintf(fp, "$View /* %s */\n", getName().c_str());
-    fprintf(fp, "%s ", str);
+    if (strlen(str) == 0)
+      fprintf(fp, "noname ");
+    else
+      fprintf(fp, "%s ", str);
     fprintf(fp, "%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d %d %d "
             "%d %d %d %d %d %d %d %d %d %d %d %d\n",
             List_Nbr(Time),
