@@ -1,30 +1,17 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _SHAPE_FUNCTIONS_H_
 #define _SHAPE_FUNCTIONS_H_
 
-// Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
-// 
-// Please report all bugs and problems to <gmsh@geuz.org>.
-
 #include "Numeric.h"
 #include "Message.h"
 
-#define ONE  (1. + 1.e-6)
-#define ZERO (-1.e-6)
+#define ONE     (1. + 1.e-6)
+#define ZERO    (-1.e-6)
+#define SQU(a)  ((a)*(a))
 
 class element{
 protected:
@@ -72,9 +59,9 @@ public:
         prodve(a, b, c);
         jac[2][0] = c[0]; jac[2][1] = c[1]; jac[2][2] = c[2]; 
       }
-      return sqrt(SQR(jac[0][0] * jac[1][1] - jac[0][1] * jac[1][0]) +
-                  SQR(jac[0][2] * jac[1][0] - jac[0][0] * jac[1][2]) +
-                  SQR(jac[0][1] * jac[1][2] - jac[0][2] * jac[1][1]));
+      return sqrt(SQU(jac[0][0] * jac[1][1] - jac[0][1] * jac[1][0]) +
+                  SQU(jac[0][2] * jac[1][0] - jac[0][0] * jac[1][2]) +
+                  SQU(jac[0][1] * jac[1][2] - jac[0][2] * jac[1][1]));
     case 1:
       for(int i = 0; i < getNumNodes(); i++) {
         getGradShapeFunction(i, u, v, w, s);
@@ -94,7 +81,7 @@ public:
         jac[1][0] = b[0]; jac[1][1] = b[1]; jac[1][2] = b[2]; 
         jac[2][0] = c[0]; jac[2][1] = c[1]; jac[2][2] = c[2]; 
       }
-      return sqrt(SQR(jac[0][0])+SQR(jac[0][1])+SQR(jac[0][2]));
+      return sqrt(SQU(jac[0][0])+SQU(jac[0][1])+SQU(jac[0][2]));
     default:
       return 1.;
     }
@@ -225,7 +212,7 @@ public:
       double wn = uvw[2] +
         inv[0][2] * (xyz[0] - xn) + inv[1][2] * (xyz[1] - yn) + inv[2][2] * (xyz[2] - zn) ;
       
-      error = sqrt(SQR(un - uvw[0]) + SQR(vn - uvw[1]) + SQR(wn - uvw[2]));
+      error = sqrt(SQU(un - uvw[0]) + SQU(vn - uvw[1]) + SQU(wn - uvw[2]));
       uvw[0] = un;
       uvw[1] = vn;
       uvw[2] = wn;
@@ -240,7 +227,7 @@ public:
     for(int i = 0; i < getNumEdges(); i++){
       int n1, n2;
       getEdge(i, n1, n2);
-      double d = sqrt(SQR(_x[n1]-_x[n2]) + SQR(_y[n1]-_y[n2]) + SQR(_z[n1]-_z[n2]));
+      double d = sqrt(SQU(_x[n1]-_x[n2]) + SQU(_y[n1]-_y[n2]) + SQU(_z[n1]-_z[n2]));
       if(d > max) max = d;
     }
     return max;
@@ -890,16 +877,16 @@ public:
       switch(num) {
       case 0  : s[0] = 0.25 * ( -(1.-v) + v*w/(1.-w) ) ;
                 s[1] = 0.25 * ( -(1.-u) + u*w/(1.-w) ) ;
-                s[2] = 0.25 * ( -1.     + u*v/SQR(1.-w) ) ; break ;
+                s[2] = 0.25 * ( -1.     + u*v/SQU(1.-w) ) ; break ;
       case 1  : s[0] = 0.25 * (  (1.-v) + v*w/(1.-w) ) ;
                 s[1] = 0.25 * ( -(1.+u) + u*w/(1.-w) ) ;
-                s[2] = 0.25 * ( -1.     + u*v/SQR(1.-w) ) ; break ;
+                s[2] = 0.25 * ( -1.     + u*v/SQU(1.-w) ) ; break ;
       case 2  : s[0] = 0.25 * (  (1.+v) + v*w/(1.-w) ) ;
                 s[1] = 0.25 * (  (1.+u) + u*w/(1.-w) ) ;
-                s[2] = 0.25 * ( -1.     + u*v/SQR(1.-w) ) ; break ;
+                s[2] = 0.25 * ( -1.     + u*v/SQU(1.-w) ) ; break ;
       case 3  : s[0] = 0.25 * ( -(1.+v) + v*w/(1.-w) ) ;
                 s[1] = 0.25 * (  (1.-u) + u*w/(1.-w) ) ;
-                s[2] = 0.25 * ( -1.     + u*v/SQR(1.-w) ) ; break ;
+                s[2] = 0.25 * ( -1.     + u*v/SQU(1.-w) ) ; break ;
       case 4  : s[0] = 0. ; 
                 s[1] = 0. ;
                 s[2] = 1. ; break ;
@@ -939,5 +926,6 @@ class elementFactory{
 
 #undef ONE
 #undef ZERO
+#undef SQU
 
 #endif
