@@ -1,3 +1,8 @@
+// Gmsh - Copyright (C) 1997-2008 C. Geuzaine, J.-F. Remacle
+//
+// See the LICENSE.txt file for license information. Please report all
+// bugs and problems to <gmsh@geuz.org>.
+
 #ifndef _GMSH_EMBEDDED_H_
 #define _GMSH_EMBEDDED_H_
 
@@ -12,6 +17,7 @@ public:
     hide_unselected = 0;
     geom.tolerance = 1.e-6;
     mesh.reverse_all_normals = 1;
+    mesh.second_order_experimental = 0;
     pick_elements = 0;
   }
   double lc;
@@ -22,6 +28,7 @@ public:
   } geom;
   struct{
     int reverse_all_normals;
+    int second_order_experimental;
   } mesh;
   unsigned int PACK_COLOR(int,int,int,int){ return 0; }
   int UNPACK_RED(unsigned int){ return 0; }
